@@ -31,7 +31,7 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-$canDo = BlogHelper::getActions('entry');
+$canDo = BlogHelperPermissions::getActions('entry');
 
 JToolBarHelper::title(JText::_('COM_BLOG_TITLE'), 'blog.png');
 if ($canDo->get('core.admin'))
@@ -77,44 +77,57 @@ function submitbutton(pressbutton)
 
 <form action="index.php" method="post" name="adminForm" id="adminForm">
 	<fieldset id="filter-bar">
-		<label for="filter_search"><?php echo JText::_('JSEARCH_FILTER'); ?>:</label>
-		<input type="text" name="search" id="filter_search" value="<?php echo $this->escape($this->filters['search']); ?>" placeholder="<?php echo JText::_('COM_BLOG_FILTER_SEARCH_PLACEHOLDER'); ?>" />
+		<div class="col width-50 fltlft">
+			<label for="filter_search"><?php echo JText::_('JSEARCH_FILTER'); ?>:</label>
+			<input type="text" name="search" id="filter_search" value="<?php echo $this->escape($this->filters['search']); ?>" placeholder="<?php echo JText::_('COM_BLOG_FILTER_SEARCH_PLACEHOLDER'); ?>" />
 
-		<?php if ($this->filters['scope'] == 'group') { ?>
-				<?php
-				$filters = array();
-				$filters['authorized'] = 'admin';
-				$filters['fields'] = array('cn','description','published','gidNumber','type');
-				$filters['type'] = array(1,3);
-				$filters['sortby'] = 'description';
-				$groups = \Hubzero\User\Group::find($filters);
+			<?php if ($this->filters['scope'] == 'group') { ?>
+				<label for="filter_scope_id"><?php echo JText::_('COM_BLOG_SCOPE_GROUP'); ?>:</label>
+				<select name="scope_id" id="filter_scope_id">
+					<?php
+					$groups = \Hubzero\User\Group::find(array(
+						'authorized' => 'admin',
+						'fields'     => array('cn','description','published','gidNumber','type'),
+						'type'       => array(1,3),
+						'sortby'     => 'description'
+					));
 
-				$html  = '<label for="filter_group_id">' . JText::_('COM_BLOG_SCOPE_GROUP') . ':</label> '."\n";
-				$html .= '<select name="group_id" id="filter_group_id">'."\n";
-				$html .= '<option value="0"';
-				if ($this->filters['group_id'] == 0)
-				{
-					$html .= ' selected="selected"';
-				}
-				$html .= '>'.JText::_('JNONE').'</option>'."\n";
-				if ($groups)
-				{
-					foreach ($groups as $group)
+					$html  = '<option value="0"';
+					if ($this->filters['scope_id'] == 0)
 					{
-						$html .= ' <option value="'.$group->gidNumber.'"';
-						if ($this->filters['group_id'] == $group->gidNumber)
-						{
-							$html .= ' selected="selected"';
-						}
-						$html .= '>' . $this->escape(stripslashes($group->description)) . '</option>'."\n";
+						$html .= ' selected="selected"';
 					}
-				}
-				$html .= '</select>'."\n";
-				echo $html;
-				?>
-		<?php } ?>
-		<input type="submit" value="<?php echo JText::_('COM_BLOG_GO'); ?>" />
-		<button type="button" onclick="$('#filter_search').val('');this.form.submit();"><?php echo JText::_('JSEARCH_FILTER_CLEAR'); ?></button>
+					$html .= '>' . JText::_('JNONE') . '</option>' . "\n";
+					if ($groups)
+					{
+						foreach ($groups as $group)
+						{
+							$html .= ' <option value="' . $group->gidNumber . '"';
+							if ($this->filters['scope_id'] == $group->gidNumber)
+							{
+								$html .= ' selected="selected"';
+							}
+							$html .= '>' . $this->escape(stripslashes($group->description)) . '</option>' . "\n";
+						}
+					}
+					echo $html;
+					?>
+				</select>
+			<?php } ?>
+
+			<input type="submit" value="<?php echo JText::_('COM_BLOG_GO'); ?>" />
+			<button type="button" onclick="$('#filter_search').val('');$('#filter-state').val('');this.form.submit();"><?php echo JText::_('JSEARCH_FILTER_CLEAR'); ?></button>
+		</div>
+		<div class="col width-50 fltrt">
+			<label for="filter-state"><?php echo JText::_('COM_BLOG_FIELD_STATE'); ?>:</label>
+			<select name="state" id="filter-state" onchange="this.form.submit();">
+				<option value=""<?php if ($this->filters['state'] == '') { echo ' selected="selected"'; } ?>><?php echo JText::_('COM_BLOG_ALL_STATES'); ?></option>
+				<option value="public"<?php if ($this->filters['state'] == 'public') { echo ' selected="selected"'; } ?>><?php echo JText::_('COM_BLOG_FIELD_STATE_PUBLIC'); ?></option>
+				<option value="registered"<?php if ($this->filters['state'] == 'registered') { echo ' selected="selected"'; } ?>><?php echo JText::_('COM_BLOG_FIELD_STATE_REGISTERED'); ?></option>
+				<option value="private"<?php if ($this->filters['state'] == 'private') { echo ' selected="selected"'; } ?>><?php echo JText::_('COM_BLOG_FIELD_STATE_PRIVATE'); ?></option>
+				<option value="trashed"<?php if ($this->filters['state'] == 'trashed') { echo ' selected="selected"'; } ?>><?php echo JText::_('COM_BLOG_FIELD_STATE_TRASHED'); ?></option>
+			</select>
+		</div>
 	</fieldset>
 	<div class="clr"></div>
 
@@ -128,9 +141,9 @@ function submitbutton(pressbutton)
 				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_BLOG_COL_STATE', 'state', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
 				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_BLOG_COL_CREATED', 'created', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
 				<th scope="col" colspan="2"><?php echo JHTML::_('grid.sort', 'COM_BLOG_COL_COMMENTS', 'comments', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
-			<?php if ($this->filters['scope'] == 'group') { ?>
-				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_BLOG_COL_GROUP', 'group_id', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
-			<?php } ?>
+				<?php if ($this->filters['scope'] == 'group') { ?>
+					<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_BLOG_COL_GROUP', 'scope_id', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
+				<?php } ?>
 			</tr>
 		</thead>
 		<tfoot>
@@ -142,9 +155,9 @@ function submitbutton(pressbutton)
 <?php
 $k = 0;
 $i = 0;
-$config	= JFactory::getConfig();
-$now	= JFactory::getDate();
-$db		= JFactory::getDBO();
+$config = JFactory::getConfig();
+$now    = JFactory::getDate();
+$db     = JFactory::getDBO();
 
 $nullDate = $db->getNullDate();
 
@@ -202,11 +215,11 @@ foreach ($this->rows as $row)
 	{
 		if ($row->get('publish_down') == $nullDate)
 		{
-			$times .= '<br />' . JText::_('COM_BLOG_FINiSH') . ': ' . JText::_('COM_BLOG_NO_EXPIRY');
+			$times .= '<br />' . JText::_('COM_BLOG_FINISH') . ': ' . JText::_('COM_BLOG_NO_EXPIRY');
 		}
 		else
 		{
-			$times .= '<br />' . JText::_('COM_BLOG_FINiSH') . ': ' . $publish_down->toSql();
+			$times .= '<br />' . JText::_('COM_BLOG_FINISH') . ': ' . $publish_down->toSql();
 		}
 	}
 
@@ -231,30 +244,30 @@ foreach ($this->rows as $row)
 					<?php echo $row->get('id'); ?>
 				</td>
 				<td>
-				<?php if ($canDo->get('core.edit')) { ?>
-					<a href="index.php?option=<?php echo $this->option ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=edit&amp;id=<?php echo $row->get('id'); ?>">
-						<?php echo $this->escape(stripslashes($row->get('title'))); ?>
-					</a>
-				<?php } else { ?>
-					<span>
-						<?php echo $this->escape(stripslashes($row->get('title'))); ?>
-					</span>
-				<?php } ?>
+					<?php if ($canDo->get('core.edit')) { ?>
+						<a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=edit&id=' . $row->get('id')); ?>">
+							<?php echo $this->escape(stripslashes($row->get('title'))); ?>
+						</a>
+					<?php } else { ?>
+						<span>
+							<?php echo $this->escape(stripslashes($row->get('title'))); ?>
+						</span>
+					<?php } ?>
 				</td>
 				<td>
 					<?php echo $this->escape(stripslashes($row->get('name'))); ?>
 				</td>
 				<td>
 					<span class="editlinktip hasTip" title="<?php echo JText::_('COM_BLOG_PUBLISH_INFO');?>::<?php echo $times; ?>">
-					<?php if ($canDo->get('core.edit.state')) { ?>
-						<a class="state <?php echo $cls; ?>" href="index.php?option=<?php echo $this->option ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=<?php echo $task; ?>&amp;id=<?php echo $row->get('id'); ?>&amp;<?php echo JUtility::getToken(); ?>=1">
-							<span><?php echo $alt; ?></span>
-						</a>
-					<?php } else { ?>
-						<span class="state <?php echo $cls; ?>">
-							<span><?php echo $alt; ?></span>
-						</span>
-					<?php } ?>
+						<?php if ($canDo->get('core.edit.state')) { ?>
+							<a class="state <?php echo $cls; ?>" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=' . $task . '&id=' . $row->get('id') . '&' . JUtility::getToken() . '=1'); ?>">
+								<span><?php echo $alt; ?></span>
+							</a>
+						<?php } else { ?>
+							<span class="state <?php echo $cls; ?>">
+								<span><?php echo $alt; ?></span>
+							</span>
+						<?php } ?>
 					</span>
 				</td>
 				<td>
@@ -263,28 +276,28 @@ foreach ($this->rows as $row)
 					</time>
 				</td>
 				<td>
-					<a class="state <?php echo $cls2; ?>" href="index.php?option=<?php echo $this->option ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=setcomments&amp;state=<?php echo $state; ?>&amp;id=<?php echo $row->get('id'); ?>&amp;<?php echo JUtility::getToken(); ?>=1">
+					<a class="state <?php echo $cls2; ?>" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=setcomments&state=' . $state . '&id=' . $row->get('id') . '&' . JUtility::getToken() . '=1'); ?>">
 						<span><?php echo $calt; ?></span>
 					</a>
 				</td>
 				<td>
-				<?php if ($canDo->get('core.edit')) { ?>
-					<a class="comment" href="index.php?option=<?php echo $this->option ?>&amp;controller=comments&amp;entry_id=<?php echo $row->get('id'); ?>">
-						<?php echo JText::sprintf('COM_BLOG_COMMENTS', $row->get('comments')); ?>
-					</a>
-				<?php } else { ?>
-					<span class="comment">
-						<?php echo JText::sprintf('COM_BLOG_COMMENTS', $row->get('comments')); ?>
-					</span>
+					<?php if ($canDo->get('core.edit')) { ?>
+						<a class="comment" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=comments&entry_id=' . $row->get('id')); ?>">
+							<?php echo JText::sprintf('COM_BLOG_COMMENTS', $row->get('comments')); ?>
+						</a>
+					<?php } else { ?>
+						<span class="comment">
+							<?php echo JText::sprintf('COM_BLOG_COMMENTS', $row->get('comments')); ?>
+						</span>
+					<?php } ?>
+				</td>
+				<?php if ($this->filters['scope'] == 'group') { ?>
+					<td>
+						<span>
+							<?php echo $this->escape($row->get('scope_id')); ?>
+						</span>
+					</td>
 				<?php } ?>
-				</td>
-			<?php if ($this->filters['scope'] == 'group') { ?>
-				<td>
-					<span>
-						<?php echo $this->escape($row->get('group_id')); ?>
-					</span>
-				</td>
-			<?php } ?>
 			</tr>
 <?php
 	$i++;
