@@ -30,37 +30,38 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-$text = ($this->task == 'edit' ? JText::_('Edit') : JText::_('New'));
+$text = ($this->task == 'edit' ? JText::_('JACTION_EDIT') : JText::_('JACTION_CREATE'));
 
 $canDo = CoursesHelper::getActions();
 
-JToolBarHelper::title(JText::_('COM_COURSES').': ' . $text . ' ' . JText::_('Offering'), 'courses.png');
-if ($canDo->get('core.edit')) 
+JToolBarHelper::title(JText::_('COM_COURSES').': ' . JText::_('COM_COURSES_OFFERING') . ': ' . $text, 'courses.png');
+if ($canDo->get('core.edit'))
 {
+	JToolBarHelper::apply();
 	JToolBarHelper::save();
+	JToolBarHelper::spacer();
 }
 JToolBarHelper::cancel();
-
+JToolBarHelper::spacer();
+JToolBarHelper::help('offering');
 
 $base = str_replace('/administrator', '', JURI::base(true));
 
 $this->css();
 ?>
 <script type="text/javascript">
-function submitbutton(pressbutton) 
+function submitbutton(pressbutton)
 {
 	var form = document.adminForm;
-	
+
 	if (pressbutton == 'cancel') {
 		submitform(pressbutton);
 		return;
 	}
-	
+
 	// form field validation
-	if ($('field-alias').value == '') {
-		alert('<?php echo JText::_('COM_COURSES_ERROR_MISSING_INFORMATION'); ?>');
-	} else if ($('field-title').value == '') {
-		alert('<?php echo JText::_('COM_COURSES_ERROR_MISSING_INFORMATION'); ?>');
+	if ($('field-title').value == '') {
+		alert('<?php echo JText::_('COM_COURSES_ERROR_MISSING_TITLE'); ?>');
 	} else {
 		submitform(pressbutton);
 	}
@@ -72,91 +73,78 @@ function submitbutton(pressbutton)
 <form action="index.php" method="post" name="adminForm" id="item-form">
 	<div class="col width-60 fltlft">
 		<fieldset class="adminform">
-			<legend><span><?php echo JText::_('COM_COURSES_DETAILS'); ?></span></legend>
-			
+			<legend><span><?php echo JText::_('JDETAILS'); ?></span></legend>
+
 			<input type="hidden" name="fields[id]" value="<?php echo $this->row->get('id'); ?>" />
 			<input type="hidden" name="fields[course_id]" value="<?php echo $this->row->get('course_id'); ?>" />
 			<input type="hidden" name="course" value="<?php echo $this->row->get('course_id'); ?>" />
 			<input type="hidden" name="option" value="<?php echo $this->option; ?>" />
 			<input type="hidden" name="controller" value="<?php echo $this->controller; ?>">
 			<input type="hidden" name="task" value="save" />
-			
-			<table class="admintable">
-				<tbody>
-					<tr>
-						<td>
-							<label for="field-title"><?php echo JText::_('COM_COURSES_TITLE'); ?>: <span class="required"><?php echo JText::_('required'); ?></span></label><br />
-							<input type="text" name="fields[title]" id="field-title" value="<?php echo $this->escape(stripslashes($this->row->get('title'))); ?>" />
-						</td>
-					</tr>
-					<tr>
-						<td>
-							<label for="field-alias"><?php echo JText::_('Alias'); ?>:</label><br />
-							<input type="text" name="fields[alias]" id="field-alias" value="<?php echo $this->escape(stripslashes($this->row->get('alias'))); ?>" />
-							<span class="hint">Only numbers, letters, dashes, and underscores allowed. If no alias is provided, one will be generated form the title.</span>
-						</td>
-					</tr>
-				</tbody>
-			</table>
+
+			<div class="input-wrap">
+				<label for="field-title"><?php echo JText::_('COM_COURSES_FIELD_TITLE'); ?>: <span class="required"><?php echo JText::_('JOPTION_REQUIRED'); ?></span></label><br />
+				<input type="text" name="fields[title]" id="field-title" value="<?php echo $this->escape(stripslashes($this->row->get('title'))); ?>" />
+			</div>
+			<div class="input-wrap" data-hint="<?php echo JText::_('COM_COURSES_FIELD_ALIAS_HINT'); ?>">
+				<label for="field-alias"><?php echo JText::_('COM_COURSES_FIELD_ALIAS'); ?>:</label><br />
+				<input type="text" name="fields[alias]" id="field-alias" value="<?php echo $this->escape(stripslashes($this->row->get('alias'))); ?>" />
+				<span class="hint"><?php echo JText::_('COM_COURSES_FIELD_ALIAS_HINT'); ?></span>
+			</div>
 		</fieldset>
 
 		<fieldset class="adminform">
-			<legend><span><?php echo JText::_('Publishing'); ?></span></legend>
-			
-			<table class="admintable">
-				<tbody>
-					<tr>
-						<td colspan="2">
-							<label for="field-state"><?php echo JText::_('State'); ?>: <span class="required"><?php echo JText::_('required'); ?></span></label></label><br />
-							<select name="fields[state]" id="field-state">
-								<option value="0"<?php if ($this->row->get('state') == 0) { echo ' selected="selected"'; } ?>><?php echo JText::_('Unpublished'); ?></option>
-								<option value="1"<?php if ($this->row->get('state') == 1) { echo ' selected="selected"'; } ?>><?php echo JText::_('Published'); ?></option>
-								<option value="2"<?php if ($this->row->get('state') == 2) { echo ' selected="selected"'; } ?>><?php echo JText::_('Deleted'); ?></option>
-							</select>
-						</td>
-					</tr>
-					<tr>
-						<td colspan="2">
-							<span class="hint">The following values are optional. If no <strong>start date</strong> is set, the offering will be available immediately upon being published.</span>
-						</td>
-					</tr>
-					<tr>
-						<td>
-							<label for="publish_up">Offering starts:</label><br />
-							<?php echo JHTML::_('calendar', $this->row->get('publish_up'), 'fields[publish_up]', 'publish_up', "%Y-%m-%d", array('class' => 'inputbox calendar-field')); ?>
-							<span class="hint">Format: YYYY-MM-DD hh:mm:ss</span>
-						</td>
-						<td>
-							<label for="publish_down">Offering ends:</label><br />
-							<?php echo JHTML::_('calendar', $this->row->get('publish_down'), 'fields[publish_down]', 'publish_down', "%Y-%m-%d", array('class' => 'inputbox calendar-field')); ?>
-							<span class="hint">Format: YYYY-MM-DD hh:mm:ss</span>
-						</td>
-					</tr>
-				</tbody>
-			</table>
+			<legend><span><?php echo JText::_('COM_COURSES_FIELDSET_PUBLISHING'); ?></span></legend>
+
+			<div class="input-wrap">
+				<label for="field-state"><?php echo JText::_('COM_COURSES_FIELD_STATE'); ?>: <span class="required"><?php echo JText::_('JOPTION_REQUIRED'); ?></span></label><br />
+				<select name="fields[state]" id="field-state">
+					<option value="0"<?php if ($this->row->get('state') == 0) { echo ' selected="selected"'; } ?>><?php echo JText::_('COM_COURSES_UNPUBLISHED'); ?></option>
+					<option value="1"<?php if ($this->row->get('state') == 1) { echo ' selected="selected"'; } ?>><?php echo JText::_('COM_COURSES_PUBLISHED'); ?></option>
+					<option value="2"<?php if ($this->row->get('state') == 2) { echo ' selected="selected"'; } ?>><?php echo JText::_('COM_COURSES_TRASHED'); ?></option>
+				</select>
+			</div>
+
+			<p><?php echo JText::_('COM_COURSES_OFFERING_START_END_HINT'); ?></p>
+
+			<div class="col width-50 fltlft">
+				<div class="input-wrap" data-hint="YYYY-MM-DD HH:mm:ss">
+					<label for="publish_up"><?php echo JText::_('COM_COURSES_FIELD_STARTS'); ?>:</label><br />
+					<?php echo JHTML::_('calendar', ($this->row->get('publish_up') != '0000-00-00 00:00:00' ? $this->row->get('publish_up') : ''), 'fields[publish_up]', 'publish_up'); ?>
+					<span class="hint"><?php echo JText::_('COM_COURSES_FIELD_STARTS_HINT'); ?></span>
+				</div>
+			</div>
+			<div class="col width-50 fltrt">
+				<div class="input-wrap" data-hint="YYYY-MM-DD HH:mm:ss">
+					<label for="publish_down"><?php echo JText::_('COM_COURSES_FIELD_ENDS'); ?>:</label><br />
+					<?php echo JHTML::_('calendar', ($this->row->get('publish_down') != '0000-00-00 00:00:00' ? $this->row->get('publish_down') : ''), 'fields[publish_down]', 'publish_down'); ?>
+					<span class="hint"><?php echo JText::_('COM_COURSES_FIELD_ENDS_HINT'); ?></span>
+				</div>
+			</div>
+			<div class="clr"></div>
 		</fieldset>
 	</div>
 	<div class="col width-40 fltrt">
 		<table class="meta">
 			<tbody>
 				<tr>
-					<th><?php echo JText::_('Course ID'); ?></th>
+					<th><?php echo JText::_('COM_COURSES_FIELD_COURSE_ID'); ?></th>
 					<td><?php echo $this->escape($this->row->get('course_id')); ?></td>
 				</tr>
 				<tr>
-					<th><?php echo JText::_('Offering ID'); ?></th>
+					<th><?php echo JText::_('COM_COURSES_FIELD_OFFERING_ID'); ?></th>
 					<td><?php echo $this->escape($this->row->get('id')); ?></td>
 				</tr>
 			<?php if ($this->row->get('created')) { ?>
 				<tr>
-					<th><?php echo JText::_('Created'); ?></th>
+					<th><?php echo JText::_('COM_COURSES_FIELD_CREATED'); ?></th>
 					<td><?php echo $this->escape($this->row->get('created')); ?></td>
 				</tr>
 			<?php } ?>
 			<?php if ($this->row->get('created_by')) { ?>
 				<tr>
-					<th><?php echo JText::_('Creator'); ?></th>
-					<td><?php 
+					<th><?php echo JText::_('COM_COURSES_FIELD_CREATOR'); ?></th>
+					<td><?php
 					$creator = JUser::getInstance($this->row->get('created_by'));
 					echo $this->escape(stripslashes($creator->get('name'))); ?></td>
 				</tr>
@@ -165,10 +153,10 @@ function submitbutton(pressbutton)
 		</table>
 
 		<fieldset class="adminform">
-			<legend><span><?php echo JText::_('IMAGE'); ?></span></legend>
+			<legend><span><?php echo JText::_('COM_COURSES_LOGO'); ?></span></legend>
 
 			<?php
-			if ($this->row->exists()) 
+			if ($this->row->exists())
 			{
 				$logo = $this->row->params('logo');
 				?>
@@ -179,11 +167,11 @@ function submitbutton(pressbutton)
 						</noscript>
 					</div>
 				</div>
-					<?php 
+					<?php
 					$width  = 0;
 					$height = 0;
 					$this_size = 0;
-					if ($logo) 
+					if ($logo)
 					{
 						$path = $this->row->logo('path');
 
@@ -204,34 +192,32 @@ function submitbutton(pressbutton)
 					<table class="formed">
 						<tbody>
 							<tr>
-								<th><?php echo JText::_('File'); ?>:</th>
+								<th><?php echo JText::_('COM_COURSES_FILE'); ?>:</th>
 								<td>
-									<span id="img-name"><?php echo $this->row->params('logo', '[ none ]'); ?></span>
+									<span id="img-name"><?php echo $this->row->params('logo', JText::_('COM_COURSES_NONE')); ?></span>
 								</td>
 								<td>
-									<a id="img-delete" <?php echo $logo ? '' : 'style="display: none;"'; ?> href="index.php?option=<?php echo $this->option; ?>&amp;controller=logo&amp;tmpl=component&amp;task=remove&amp;currentfile=<?php echo $logo; ?>&amp;type=offering&amp;id=<?php echo $this->row->get('id'); ?>&amp;<?php echo JUtility::getToken(); ?>=1" title="<?php echo JText::_('Delete'); ?>">[ x ]</a>
+									<a id="img-delete" <?php echo $logo ? '' : 'style="display: none;"'; ?> href="index.php?option=<?php echo $this->option; ?>&amp;controller=logo&amp;tmpl=component&amp;task=remove&amp;currentfile=<?php echo $logo; ?>&amp;type=offering&amp;id=<?php echo $this->row->get('id'); ?>&amp;<?php echo JUtility::getToken(); ?>=1" title="<?php echo JText::_('COM_COURSES_DELETE'); ?>">[ x ]</a>
 								</td>
 							</tr>
 							<tr>
-								<th><?php echo JText::_('Size'); ?>:</th>
+								<th><?php echo JText::_('COM_COURSES_PICTURE_SIZE'); ?>:</th>
 								<td><span id="img-size"><?php echo \Hubzero\Utility\Number::formatBytes($this_size); ?></span></td>
 								<td></td>
 							</tr>
 							<tr>
-								<th><?php echo JText::_('Width'); ?>:</th>
+								<th><?php echo JText::_('COM_COURSES_PICTURE_WIDTH'); ?>:</th>
 								<td><span id="img-width"><?php echo $width; ?></span> px</td>
 								<td></td>
 							</tr>
 							<tr>
-								<th><?php echo JText::_('Height'); ?>:</th>
+								<th><?php echo JText::_('COM_COURSES_PICTURE_HEIGHT'); ?>:</th>
 								<td><span id="img-height"><?php echo $height; ?></span> px</td>
 								<td></td>
 							</tr>
 						</tbody>
 					</table>
 
-					<script type="text/javascript" src="<?php echo $base; ?>/media/system/js/jquery.js"></script>
-					<script type="text/javascript" src="<?php echo $base; ?>/media/system/js/jquery.noconflict.js"></script>
 					<script type="text/javascript" src="<?php echo $base; ?>/media/system/js/jquery.fileuploader.js"></script>
 					<script type="text/javascript">
 					String.prototype.nohtml = function () {
@@ -241,9 +227,7 @@ function submitbutton(pressbutton)
 							return this + '&no_html=1';
 						}
 					};
-					jQuery(document).ready(function(jq){
-						var $ = jq;
-
+					jQuery(document).ready(function($){
 						if ($("#ajax-uploader").length) {
 							var uploader = new qq.FileUploader({
 								element: $("#ajax-uploader")[0],
@@ -251,9 +235,9 @@ function submitbutton(pressbutton)
 								multiple: true,
 								debug: true,
 								template: '<div class="qq-uploader">' +
-											'<div class="qq-upload-button"><span>Click or drop file</span></div>' + 
-											'<div class="qq-upload-drop-area"><span>Click or drop file</span></div>' +
-											'<ul class="qq-upload-list"></ul>' + 
+											'<div class="qq-upload-button"><span><?php echo JText::_('COM_COURSES_UPLOAD_CLICK_OR_DROP'); ?></span></div>' +
+											'<div class="qq-upload-drop-area"><span><?php echo JText::_('COM_COURSES_UPLOAD_CLICK_OR_DROP'); ?></span></div>' +
+											'<ul class="qq-upload-list"></ul>' +
 										   '</div>',
 								onComplete: function(id, file, response) {
 									if (response.success) {
@@ -291,6 +275,22 @@ function submitbutton(pressbutton)
 			?>
 		</fieldset>
 
+		<?php $params = new JRegistry($this->row->get('params')); ?>
+
+		<fieldset class="adminform offeringparams">
+			<legend><?php echo JText::_('COM_COURSES_FIELDSET_PARAMS'); ?></legend>
+			<div class="input-wrap">
+				<label for="params-progress-calculation"><?php echo JText::_('COM_COURSES_PROGRESS_CALCULATION'); ?>:</label><br />
+				<select name="params[progress_calculation]" id="params-progress-calculation">
+					<option value=""<?php echo ($params->get('progress_calculation', '') == '') ? 'selected="selected"' : '' ?>><?php echo JText::_('COM_COURSES_PROGRESS_CALCULATION_INHERIT'); ?></option>
+					<option value="all"<?php echo ($params->get('progress_calculation', '') == 'all') ? 'selected="selected"' : '' ?>><?php echo JText::_('COM_COURSES_PROGRESS_CALCULATION_ALL'); ?></option>
+					<option value="graded"<?php echo ($params->get('progress_calculation', '') == 'graded') ? 'selected="selected"' : '' ?>><?php echo JText::_('COM_COURSES_PROGRESS_CALCULATION_GRADED'); ?></option>
+					<option value="videos"<?php echo ($params->get('progress_calculation', '') == 'videos') ? 'selected="selected"' : '' ?>><?php echo JText::_('COM_COURSES_PROGRESS_CALCULATION_VIDEOS'); ?></option>
+					<option value="manual"<?php echo ($params->get('progress_calculation', '') == 'manual') ? 'selected="selected"' : '' ?>><?php echo JText::_('COM_COURSES_PROGRESS_CALCULATION_MANUAL'); ?></option>
+				</select>
+			</div>
+		</fieldset>
+
 		<?php
 			JPluginHelper::importPlugin('courses');
 			$dispatcher = JDispatcher::getInstance();
@@ -306,13 +306,13 @@ function submitbutton(pressbutton)
 						JPATH_ROOT . DS . 'plugins' . DS . 'courses' . DS . $plugin['name'] . DS . $plugin['name'] . '.xml'
 					);
 					$out = $param->render('params', 'onOfferingEdit');
-					if (!$out) 
+					if (!$out)
 					{
 						continue;
 					}
 					?>
 					<fieldset class="adminform eventparams" id="params-<?php echo $plugin['name']; ?>">
-						<legend><?php echo JText::sprintf('%s Parameters', $plugin['title']); ?></legend>
+						<legend><?php echo JText::sprintf('COM_COURSES_FIELDSET_PARAMETERS', $plugin['title']); ?></legend>
 						<?php echo $out; ?>
 					</fieldset>
 					<?php
