@@ -556,7 +556,7 @@ jQuery(document).ready(function($){
 												</td>
 												<td><label for="dates_<?php echo $i; ?>_<?php echo $j; ?>_assetgroup_<?php echo $z; ?>_assetgroup_<?php echo $j; ?>_publish_up"><?php echo JText::_('COM_COURSES_TO'); ?></label></th>
 												<td>
-													<input type="text" name="dates[<?php echo $i; ?>][<?php echo $z; ?>][<?php echo $j; ?>][publish_down]" id="dates_<?php echo $i; ?>_assetgroup_<?php echo $z; ?>_assetgroup_<?php echo $j; ?>_publish_down" class="datetime-field" value="<?php echo (!$ag->get('publish_down') || $ag->get('publish_down') == $agt->get('publish_down') || $ag->get('publish_down') == $nullDate ? '' : JHTML::_('date', $ag->get('publish_down'), 'Y-m-d H:i:s')); ?>" />
+													<input type="text" name="dates[<?php echo $i; ?>][asset_group][<?php echo $z; ?>][asset_group][<?php echo $j; ?>][publish_down]" id="dates_<?php echo $i; ?>_assetgroup_<?php echo $z; ?>_assetgroup_<?php echo $j; ?>_publish_down" class="datetime-field" value="<?php echo (!$ag->get('publish_down') || $ag->get('publish_down') == $agt->get('publish_down') || $ag->get('publish_down') == $nullDate ? '' : JHTML::_('date', $ag->get('publish_down'), 'Y-m-d H:i:s')); ?>" />
 												</td>
 											</tr>
 
@@ -774,10 +774,14 @@ jQuery(document).ready(function($){
 										<option value="passport"<?php if ($this->badge->get('provider_name', 'passport') == 'passport') { echo ' selected="selected"'; } ?>>Passport</option>
 									</select>
 								</td>
+							</tr>
 							<tr class="badge-field-toggle">
 								<th class="key"><label for="badge-criteria"><?php echo JText::_('COM_COURSES_FIELD_BADGE_CRITERIA'); ?>:</label></th>
 								<td>
-									<textarea name="badge[criteria]" id="badge-criteria" rows="6" cols="50"><?php echo $this->escape(stripslashes($this->badge->get('criteria_text'))); ?></textarea>
+									<?php
+										$editor = JFactory::getEditor();
+										echo $editor->display('badge[criteria]', $this->escape(stripslashes($this->badge->get('criteria_text'))), '100%', '200px', '', '', false, 'badge-criteria');
+									?>
 								</td>
 							</tr>
 						</tbody>
@@ -801,10 +805,14 @@ jQuery(document).ready(function($){
 								<td>
 									<?php echo $this->escape(stripslashes($this->badge->get('provider_name'))); ?>
 								</td>
+							</tr>
 							<tr class="badge-field-toggle">
 								<th class="key"><label for="badge-criteria"><?php echo JText::_('COM_COURSES_FIELD_BADGE_CRITERIA'); ?>:</label></th>
 								<td>
-									<textarea name="badge[criteria]" id="badge-criteria" rows="6" cols="50"><?php echo $this->escape(stripslashes($this->badge->get('criteria_text'))); ?></textarea>
+									<?php
+										$editor = JFactory::getEditor();
+										echo $editor->display('badge[criteria]', $this->escape(stripslashes($this->badge->get('criteria_text'))), '100%', '200px', '', '', false, 'badge-criteria');
+									?>
 									<a target="_blank" href="/courses/badge/<?php echo $this->badge->get('id'); ?>/criteria"><?php echo JText::_('COM_COURSES_FIELD_BADGE_CRITERIA'); ?></a>
 								</td>
 							</tr>
