@@ -38,7 +38,7 @@ class JobsControllerTypes extends \Hubzero\Component\AdminController
 {
 	/**
 	 * Display a list of types
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function displayTask()
@@ -46,35 +46,35 @@ class JobsControllerTypes extends \Hubzero\Component\AdminController
 		// Get configuration
 		$app = JFactory::getApplication();
 		$config = JFactory::getConfig();
-		
+
 		$this->view->filters = array();
 
 		// Get paging variables
 		$this->view->filters['limit']    = $app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.limit', 
-			'limit', 
-			$config->getValue('config.list_limit'), 
+			$this->_option . '.' . $this->_controller . '.limit',
+			'limit',
+			$config->getValue('config.list_limit'),
 			'int'
 		);
 		$this->view->filters['start']    = $app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.limitstart', 
-			'limitstart', 
-			0, 
+			$this->_option . '.' . $this->_controller . '.limitstart',
+			'limitstart',
+			0,
 			'int'
 		);
-		
+
 		// Get sorting variables
 		$this->view->filters['sort']     = trim($app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.sort', 
-			'filter_order', 
+			$this->_option . '.' . $this->_controller . '.sort',
+			'filter_order',
 			'id'
 		));
 		$this->view->filters['sort_Dir'] = trim($app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.sortdir', 
-			'filter_order_Dir', 
+			$this->_option . '.' . $this->_controller . '.sortdir',
+			'filter_order_Dir',
 			'ASC'
 		));
-		
+
 		// Instantiate an object
 		$jt = new JobType($this->database);
 
@@ -83,39 +83,39 @@ class JobsControllerTypes extends \Hubzero\Component\AdminController
 		$this->view->total = count($this->view->rows);
 
 		// Load default types if none found
-		if (!$this->view->total) 
+		if (!$this->view->total)
 		{
 			$default = array(
 				array(
 					'id' => 0,
-					'category' => ucfirst(JText::_('Full-time'))
+					'category' => ucfirst(JText::_('COM_JOBS_CATEGORY_FULLTIME'))
 				),
 				array(
 					'id' => 0,
-					'category' => ucfirst(JText::_('Part-time'))
+					'category' => ucfirst(JText::_('COM_JOBS_CATEGORY_PARTTIME'))
 				),
 				array(
 					'id' => 0,
-					'category' => ucfirst(JText::_('Contract'))
+					'category' => ucfirst(JText::_('COM_JOBS_CATEGORY_CONTRACT'))
 				),
 				array(
 					'id' => 0,
-					'category' => ucfirst(JText::_('Internship'))
+					'category' => ucfirst(JText::_('COM_JOBS_CATEGORY_INTERNSHIP'))
 				),
 				array(
 					'id' => 0,
-					'category' => ucfirst(JText::_('Temporary'))
+					'category' => ucfirst(JText::_('COM_JOBS_CATEGORY_TEMPORARY'))
 				)
 			);
 
 			foreach ($default as $d)
 			{
-				if (!$jt->bind($d)) 
+				if (!$jt->bind($d))
 				{
 					$this->setError($jt->getError());
 					return false;
 				}
-				if (!$jt->store()) 
+				if (!$jt->store())
 				{
 					$this->setError($jt->getError());
 					return false;
@@ -130,13 +130,13 @@ class JobsControllerTypes extends \Hubzero\Component\AdminController
 		// initiate paging
 		jimport('joomla.html.pagination');
 		$this->view->pageNav = new JPagination(
-			$this->view->total, 
-			$this->view->filters['start'], 
+			$this->view->total,
+			$this->view->filters['start'],
 			$this->view->filters['limit']
 		);
 
 		// Set any errors
-		if ($this->getError()) 
+		if ($this->getError())
 		{
 			foreach ($this->getErrors() as $error)
 			{
@@ -151,7 +151,7 @@ class JobsControllerTypes extends \Hubzero\Component\AdminController
 	/**
 	 * Create a new type
 	 * Displays the edit form
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function addTask()
@@ -161,32 +161,30 @@ class JobsControllerTypes extends \Hubzero\Component\AdminController
 
 	/**
 	 * Edit a type
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function editTask($row=null)
 	{
 		JRequest::setVar('hidemainmenu', 1);
 
-		$this->view->setLayout('edit');
-
 		if (is_object($row))
 		{
 			$this->view->row = $row;
 		}
-		else 
+		else
 		{
 			// Incoming (expecting an array)
 			$id = JRequest::getVar('id', array(0));
-			$id = (is_array($id)) ? $id[0] : 0;
-			
+			$id = (is_array($id)) ? $id[0] : $id;
+
 			// Load the object
 			$this->view->row = new JobType($this->database);
 			$this->view->row->load($id);
 		}
 
 		// Set any errors
-		if ($this->getError()) 
+		if ($this->getError())
 		{
 			foreach ($this->getErrors() as $error)
 			{
@@ -195,12 +193,12 @@ class JobsControllerTypes extends \Hubzero\Component\AdminController
 		}
 
 		// Output the HTML
-		$this->view->display();
+		$this->view->setLayout('edit')->display();
 	}
 
 	/**
 	 * Save type
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function saveTask()
@@ -210,7 +208,7 @@ class JobsControllerTypes extends \Hubzero\Component\AdminController
 
 		// Initiate extended database class
 		$row = new JobType($this->database);
-		if (!$row->bind($_POST)) 
+		if (!$row->bind($_POST))
 		{
 			$this->addComponentMessage($row->getError(), 'error');
 			$this->editTask($row);
@@ -218,7 +216,7 @@ class JobsControllerTypes extends \Hubzero\Component\AdminController
 		}
 
 		// Store new content
-		if (!$row->store()) 
+		if (!$row->store())
 		{
 			$this->addComponentMessage($row->getError(), 'error');
 			$this->editTask($row);
@@ -228,13 +226,13 @@ class JobsControllerTypes extends \Hubzero\Component\AdminController
 		// Redirect
 		$this->setRedirect(
 			'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-			JText::_('Type successfully saved')
+			JText::_('COM_JOBS_ITEM_SAVED')
 		);
 	}
 
 	/**
 	 * Remove type
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function removeTask()
@@ -244,13 +242,14 @@ class JobsControllerTypes extends \Hubzero\Component\AdminController
 
 		// Incoming (expecting an array)
 		$ids = JRequest::getVar('id', array());
+		$ids = (!is_array($ids) ? array($ids) : $ids);
 
 		// Ensure we have an ID to work with
-		if (empty($ids)) 
+		if (empty($ids))
 		{
 			$this->setRedirect(
 				'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-				JText::_('No type selected'),
+				JText::_('COM_JOBS_ERROR_NO_ITEM_SELECTED'),
 				'error'
 			);
 			return;
@@ -267,10 +266,10 @@ class JobsControllerTypes extends \Hubzero\Component\AdminController
 		// Redirect
 		$this->setRedirect(
 			'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-			JText::_('Type(s) successfully removed')
+			JText::sprintf('COM_JOBS_ITEMS_REMOVED', count($ids))
 		);
 	}
-	
+
 	/**
 	 * Cancel a task (redirects to default task)
 	 *
