@@ -1,6 +1,6 @@
 <?php
 /**
- * @copyright	Copyright (C) 2005 - 2013 Open Source Matters, Inc. All rights reserved.
+ * @copyright	Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
  * @license		GNU General Public License version 2 or later; see LICENSE.txt
  */
 
@@ -159,12 +159,12 @@ class MediaModelManager extends JModelLegacy
 		list($path) = $mkData(new SplFileInfo($base));
 
 		foreach (new RecursiveIteratorIterator(new RecursiveDirectoryIterator($base), RecursiveIteratorIterator::SELF_FIRST) as $file) {
-			// skip hidden files
-			if (substr($file->getFileName(), 0, 1) == '.') {
+			// skip hidden files and non-directories
+			if (substr($file->getFileName(), 0, 1) == '.' || !$file->isDir()) {
 				continue;
 			}
 			list($data, $rel, $parent) = $mkData($file);
-	
+
 			// find a place to put the node by walking through parents
 			$pos =& $path;
 			if (($parents = explode(DIRECTORY_SEPARATOR, $parent))) {
