@@ -36,46 +36,11 @@ defined('_JEXEC') or die('Restricted access');
  */
 class MembersAssociation extends JTable
 {
-	/**
-	 * varchar(50) Primary Key
-	 *
-	 * @var integer
-	 */
-	var $subtable = NULL;
-
-	/**
-	 * int(11)
-	 *
-	 * @var integer
-	 */
-	var $subid    = NULL;
-
-	/**
-	 * int(11)
-	 *
-	 * @var integer
-	 */
-	var $authorid = NULL;
-
-	/**
-	 * int(11)
-	 *
-	 * @var integer
-	 */
-	var $ordering = NULL;
-
-	/**
-	 * varchar(50)
-	 *
-	 * @var string
-	 */
-	var $role     = NULL;
-
 	/**
 	 * Constructor
 	 *
-	 * @param      object &$db JDatabase
-	 * @return     void
+	 * @param   object  &$db  JDatabase
+	 * @return  void
 	 */
 	public function __construct(&$db)
 	{
@@ -85,7 +50,7 @@ class MembersAssociation extends JTable
 	/**
 	 * Validate data
 	 *
-	 * @return     boolean True if data is valid
+	 * @return  boolean  True if data is valid
 	 */
 	public function check()
 	{
@@ -107,15 +72,12 @@ class MembersAssociation extends JTable
 	/**
 	 * Delete records for a user
 	 *
-	 * @param      integer $id User ID
-	 * @return     boolean True on success
+	 * @param   integer  $id  User ID
+	 * @return  boolean  True on success
 	 */
 	public function deleteAssociations($id=NULL)
 	{
-		if (!$id)
-		{
-			$id = $this->authorid;
-		}
+		$id = $id ?: $this->authorid;
 
 		$this->_db->setQuery("DELETE FROM $this->_tbl WHERE authorid=" . $this->_db->Quote($id));
 		if (!$this->_db->query())
