@@ -32,7 +32,7 @@ class PollViewPolls extends JView
 		$option = 'com_poll';
 		$mainframe = JFactory::getApplication();
 
-		$db					=& JFactory::getDBO();
+		$db					= JFactory::getDBO();
 		$filter_order		= $mainframe->getUserStateFromRequest( "$option.filter_order",		'filter_order',		'm.id',	'cmd' );
 		$filter_order_Dir	= $mainframe->getUserStateFromRequest( "$option.filter_order_Dir",	'filter_order_Dir',	'',		'word' );
 		$filter_state		= $mainframe->getUserStateFromRequest( "$option.filter_state",		'filter_state',		'',		'word' );
@@ -60,7 +60,7 @@ class PollViewPolls extends JView
 		}
 		if ($search)
 		{
-			$where[] = 'LOWER(m.title) LIKE '.$db->Quote( '%'.$db->getEscaped( $search, true ).'%', false );
+			$where[] = 'LOWER(m.title) LIKE '.$db->Quote('%'. $search . '%');
 		}
 
 		$where 		= ( count( $where ) ? ' WHERE ' . implode( ' AND ', $where ) : '' );
@@ -113,7 +113,9 @@ class PollViewPolls extends JView
 		// search filter
 		$lists['search']= $search;
 
-		$this->assignRef('user',		JFactory::getUser());
+		$user = JFactory::getUser();
+
+		$this->assignRef('user',		$user);
 		$this->assignRef('lists',		$lists);
 		$this->assignRef('items',		$rows);
 		$this->assignRef('pagination',	$pagination);
