@@ -45,7 +45,7 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 	{
 		$task = JRequest::getVar('task', '');
 		$plugin = JRequest::getVar('plugin', '');
-		if ($plugin && $task && $task != 'manage') //!isset($this->_taskMap[$task]))
+		if ($plugin && $task && $task != 'manage')
 		{
 			JRequest::setVar('action', $task);
 			JRequest::setVar('task', 'manage');
@@ -58,7 +58,7 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 
 	/**
 	 * List resource types
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function displayTask()
@@ -91,7 +91,7 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 			'filter_order_Dir',
 			'ASC'
 		));
-		
+
 		$this->view->filters['state']    = $app->getUserStateFromRequest(
 			$this->_option . '.' . $this->_controller . '.state',
 			'state',
@@ -108,87 +108,64 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 		$where = array();
 		$this->client = JRequest::getWord('filter_client', 'site');
 
-		if ($this->client == 'admin') 
+		if ($this->client == 'admin')
 		{
 			$where[] = 'p.client_id = 1';
 			$client_id = 1;
-		} 
-		else 
+		}
+		else
 		{
 			$where[] = 'p.client_id = 0';
 			$where[] = 'p.folder = ' . $this->database->Quote($this->_folder);
 			$client_id = 0;
 		}
 
-		if ($this->view->filters['search']) 
+		if ($this->view->filters['search'])
 		{
-			$where[] = 'LOWER(p.name) LIKE ' . $this->database->Quote('%' . $this->database->getEscaped($this->view->filters['search'], true) . '%', false);
+			$where[] = 'LOWER(p.name) LIKE ' . $this->database->Quote('%' . $this->view->filters['search'] . '%');
 		}
-		if ($this->view->filters['state']) 
+		if ($this->view->filters['state'])
 		{
-			if ($this->view->filters['state'] == 'P') 
+			if ($this->view->filters['state'] == 'P')
 			{
 				$where[] = 'p.published = 1';
-			} 
-			else if ($this->view->filters['state'] == 'U') 
+			}
+			else if ($this->view->filters['state'] == 'U')
 			{
 				$where[] = 'p.published = 0';
 			}
 		}
-		if (version_compare(JVERSION, '1.6', 'ge')) 
-		{
-			$where[] = 'p.type = ' . $this->database->Quote('plugin');
-		}
+		$where[] = 'p.type = ' . $this->database->Quote('plugin');
 
 		$where   = (count($where) ? ' WHERE ' . implode(' AND ', $where) : '');
 		$orderby = ' ORDER BY ' . $this->view->filters['sort'] . ' ' . $this->view->filters['sort_Dir'] . ', p.ordering ASC';
 
 		// get the total number of records
-		if (version_compare(JVERSION, '1.6', 'lt')) 
-		{
-			$query = 'SELECT COUNT(*)'
-				. ' FROM #__plugins AS p'
-				. $where;
-		}
-		else 
-		{
-			$query = 'SELECT COUNT(*)'
-				. ' FROM #__extensions AS p'
-				. $where;
-		}
+		$query = 'SELECT COUNT(*)'
+			. ' FROM #__extensions AS p'
+			. $where;
+
 		$this->database->setQuery($query);
 		$this->view->total = $this->database->loadResult();
 
 		jimport('joomla.html.pagination');
 		$this->view->pagination = new JPagination(
-			$this->view->total, 
-			$this->view->filters['start'], 
+			$this->view->total,
+			$this->view->filters['start'],
 			$this->view->filters['limit']
 		);
 
-		if (version_compare(JVERSION, '1.6', 'lt')) 
-		{
-			$query = 'SELECT p.*, u.name AS editor, g.name AS groupname'
-				. ' FROM #__plugins AS p'
-				. ' LEFT JOIN #__users AS u ON u.id = p.checked_out'
-				. ' LEFT JOIN #__groups AS g ON g.id = p.access'
-				. $where
-				. ' GROUP BY p.id'
-				. $orderby;
-		}
-		else 
-		{
-			$query = 'SELECT p.extension_id AS id, p.enabled As published, p.*, u.name AS editor, g.title AS groupname'
-				. ' FROM #__extensions AS p'
-				. ' LEFT JOIN #__users AS u ON u.id = p.checked_out'
-				. ' LEFT JOIN #__viewlevels AS g ON g.id = p.access'
-				. $where
-				. ' GROUP BY p.extension_id'
-				. $orderby;
-		}
+		$query = 'SELECT p.extension_id AS id, p.enabled As published, p.*, u.name AS editor, g.title AS groupname'
+			. ' FROM #__extensions AS p'
+			. ' LEFT JOIN #__users AS u ON u.id = p.checked_out'
+			. ' LEFT JOIN #__viewlevels AS g ON g.id = p.access'
+			. $where
+			. ' GROUP BY p.extension_id'
+			. $orderby;
+
 		$this->database->setQuery($query, $this->view->pagination->limitstart, $this->view->pagination->limit);
 		$this->view->rows = $this->database->loadObjectList();
-		if ($this->database->getErrorNum()) 
+		if ($this->database->getErrorNum())
 		{
 			JError::raiseError(500, $this->database->stderr());
 			return false;
@@ -197,7 +174,7 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 		$lang = JFactory::getLanguage();
 		if ($this->view->rows)
 		{
-			foreach ($this->view->rows as &$item) 
+			foreach ($this->view->rows as &$item)
 			{
 				$source = JPATH_PLUGINS . '/' . $item->folder . '/' . $item->element;
 				$extension = 'plg_' . $item->folder . '_' . $item->element;
@@ -235,7 +212,7 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 
 	/**
 	 * Edit a type
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function manageTask()
@@ -248,29 +225,29 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 			// Redirect
 			$this->setRedirect(
 				'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-				JText::_('Please select a plugin to manage.')
+				JText::_('COM_RESOURCES_ERROR_NO_PLUGIN_SELECTED')
 			);
 		}
 
 		// Get related plugins
 		JPluginHelper::importPlugin('resources', $plugin);
 		$dispatcher = JDispatcher::getInstance();
-		
+
 		// Show related content
 		$out = $dispatcher->trigger(
-			'onManage', 
+			'onManage',
 			array(
-				$this->_option, 
+				$this->_option,
 				$this->_controller,
 				JRequest::getVar('action', 'default')
 			)
 		);
-		
+
 		$this->view->html = '';
-		
-		if (count($out) > 0) 
+
+		if (count($out) > 0)
 		{
-			foreach ($out as $o) 
+			foreach ($out as $o)
 			{
 				$this->view->html .= $o;
 			}
@@ -300,141 +277,26 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 			'index.php?option=' . $this->_option . '&controller=' . $this->_controller
 		);
 	}
-	
-	/**
-	 * Create a new plugin
-	 * 
-	 * @return     void
-	 */
-	public function addTask()
-	{
-		$this->editTask();
-	}
-	
+
 	/**
 	 * Edit a plugin
-	 * 
+	 *
 	 * @param      object $row JPluginTable
 	 * @return     void
 	 */
 	public function editTask($row = null)
 	{
-		JRequest::setVar('hidemainmenu', 1);
-		
-		$this->view->setLayout('edit');
-		
-		$client = JRequest::getWord('client', 'site');
-		
-		if (is_object($row))
-		{
-			$this->view->row = $row;
-		}
-		else 
-		{
-			$cid = JRequest::getVar('cid', array(0), '', 'array');
-			JArrayHelper::toInteger($cid, array(0));
-			
-			$this->view->row = JTable::getInstance('plugin');
+		$cid = JRequest::getVar('cid', array(0), '', 'array');
+		JArrayHelper::toInteger($cid, array(0));
 
-			// load the row from the db table
-			$this->view->row->load($cid[0]);
-		}
-		
-		// Is this entry checked out?
-		if ($this->view->row->isCheckedOut($this->juser->get('id')))
-		{
-			$this->setRedirect(
-				'index.php?option=' . $this->_option . '&controller=' . $this->_controller . '&client=' . $client, 
-				JText::sprintf('DESCBEINGEDITTED', JText::_('The plugin'), $this->view->row->title), 
-				'error'
-			);
-			return;
-		}
-		
-		$this->view->lists = array();
-		
-		// get list of groups
-		if ($this->view->row->access == 99 || $this->view->row->client_id == 1) 
-		{
-			$this->view->lists['access'] = 'Administrator<input type="hidden" name="access" value="99" />';
-		} 
-		else 
-		{
-			// build the html select list for the group access
-			$this->view->lists['access'] = JHTML::_('list.accesslevel', $this->view->row);
-		}
-		
-		if ($cid[0])
-		{
-			$this->view->row->checkout($this->juser->get('id'));
-
-			$lang = JFactory::getLanguage();
-			$lang->load('plg_' . trim($this->view->row->folder) . '_' . trim($this->view->row->element), JPATH_ADMINISTRATOR);
-
-			$data = JApplicationHelper::parseXMLInstallFile(JPATH_SITE . DS . 'plugins' . DS  .$this->view->row->folder . DS . $this->view->row->element . '.xml');
-
-			$this->view->row->description = $data['description'];
-
-		} 
-		else 
-		{
-			$this->view->row->folder 		= $this->_folder;
-			$this->view->row->ordering 		= 999;
-			$this->view->row->published 	= 1;
-			$this->view->row->description 	= '';
-		}
-		
-		if ($this->view->row->ordering > -10000 && $this->view->row->ordering < 10000)
-		{
-			// build the html select list for ordering
-			$query = 'SELECT ordering AS value, name AS text'
-				. ' FROM #__plugins'
-				. ' WHERE folder = '.$this->database->Quote($this->_folder)
-				. ' AND published > 0'
-				. ' AND '. ($client == 'admin' ? "client_id='1'" : "client_id='0'")
-				. ' AND ordering > -10000'
-				. ' AND ordering < 10000'
-				. ' ORDER BY ordering'
-			;
-			$order = JHTML::_('list.genericordering',  $query);
-			
-			$this->view->lists['ordering'] = JHTML::_('select.genericlist', $order, 'ordering', 'class="inputbox" size="1"', 'value', 'text', intval($this->view->row->ordering));
-		} 
-		else 
-		{
-			$this->view->lists['ordering'] = '<input type="hidden" name="ordering" value="' . $this->view->row->ordering . '" />' . JText::_('This plugin cannot be reordered');
-		}
-
-		$this->view->lists['published'] = JHTML::_('select.booleanlist', 'published', 'class="inputbox"', $this->view->row->published);
-
-		$paramsClass = 'JParameter';
-		if (version_compare(JVERSION, '1.6', 'ge'))
-		{
-			$paramsClass = 'JRegistry';
-		}
-
-		$this->view->params = new $paramsClass(
-			$this->view->row->params, 
-			JApplicationHelper::getPath('plg_xml', $this->view->row->folder . DS . $this->view->row->element), 
-			'plugin'
+		$this->setRedirect(
+			'index.php?option=com_plugins&task=plugin.edit&extension_id=' . $cid[0] . '&component=resources'
 		);
-
-		// Set any errors
-		if ($this->getError())
-		{
-			foreach ($this->getErrors() as $error)
-			{
-				$this->view->setError($error);
-			}
-		}
-
-		// Output the HTML
-		$this->view->display();
 	}
-	
+
 	/**
 	 * Save changes to a plugin
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function saveTask()
@@ -445,45 +307,38 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 		$client = JRequest::getWord('filter_client', 'site');
 
 		// Bind data
-		if (version_compare(JVERSION, '1.6', 'lt')) 
-		{
-			$row = JTable::getInstance('plugin');
-		}
-		else
-		{
-			$row = JTable::getInstance('extension');
-		}
-		if (!$row->bind(JRequest::get('post'))) 
+		$row = JTable::getInstance('extension');
+		if (!$row->bind(JRequest::get('post')))
 		{
 			$this->addComponentMessage($row->getError(), 'error');
 			$this->view->setLayout('edit');
 			$this->editTask($row);
 			return;
 		}
-		
+
 		// Check content
-		if (!$row->check()) 
+		if (!$row->check())
 		{
 			$this->addComponentMessage($row->getError(), 'error');
 			$this->view->setLayout('edit');
 			$this->editTask($row);
 			return;
 		}
-		
+
 		// Store content
-		if (!$row->store()) 
+		if (!$row->store())
 		{
 			$this->addComponentMessage($row->getError(), 'error');
 			$this->view->setLayout('edit');
 			$this->editTask($row);
 			return;
 		}
-		
+
 		$row->checkin();
 		$row->reorder(
-			'folder = ' . $this->database->Quote($row->folder) . ' 
-			AND ordering > -10000 
-			AND ordering < 10000 
+			'folder = ' . $this->database->Quote($row->folder) . '
+			AND ordering > -10000
+			AND ordering < 10000
 			AND (' . ($client == 'admin' ? "client_id=1" : "client_id=0") . ')'
 		);
 
@@ -491,35 +346,35 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 		{
 			case 'apply':
 				$this->setRedirect(
-					'index.php?option=' . $this->_option . '&controller=' . $this->_controller . '&client=' . $client . '&task=edit&cid[]=' . $row->id, 
-					JText::sprintf('Successfully Saved changes to Plugin', $row->name)
+					'index.php?option=' . $this->_option . '&controller=' . $this->_controller . '&client=' . $client . '&task=edit&cid[]=' . $row->id,
+					JText::sprintf('COM_RESOURCES_PLUGINS_ITEM_SAVED', $row->name)
 				);
 			break;
 
 			case 'save':
 			default:
-				$msg = JText::sprintf('Successfully Saved Plugin', $row->name);
+				$msg = JText::sprintf('COM_RESOURCES_PLUGINS_ITEM_SAVED', $row->name);
 				$this->setRedirect(
-					'index.php?option=' . $this->_option . '&controller=' . $this->_controller . '&client=' . $client, 
+					'index.php?option=' . $this->_option . '&controller=' . $this->_controller . '&client=' . $client,
 					$msg
 				);
 			break;
 		}
 	}
-	
+
 	/**
 	 * Calls stateTask to publish entries
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function publishTask()
 	{
 		$this->stateTask(1);
 	}
-	
+
 	/**
 	 * Calls stateTask to unpublish entries
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function unpublishTask()
@@ -529,7 +384,7 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 
 	/**
 	 * Set the state of a plugin
-	 * 
+	 *
 	 * @param      integer $access Access level to set
 	 * @return     void
 	 */
@@ -541,35 +396,26 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 		// Incoming
 		$id = JRequest::getVar('id', array(0), '', 'array');
 		JArrayHelper::toInteger($id, array(0));
-		
+
 		$client = JRequest::getWord('filter_client', 'site');
 
-		if (count($id) < 1) 
+		if (count($id) < 1)
 		{
-			$action = $state ? JText::_('publish') : JText::_('unpublish');
+			$action = $state ? JText::_('COM_RESOURCES_PUBLISH') : JText::_('COM_RESOURCES_UNPUBLISH');
 			$this->setRedirect(
 				'index.php?option=' . $this->_option . '&controller=' . $this->_controller . '&client=' . $client,
-				JText::_('Select a plugin to ' . $action),
+				JText::sprintf('COM_RESOURCES_ERROR_SELECT_TO', $action),
 				'error'
 			);
 			return;
 		}
 
-		if (version_compare(JVERSION, '1.6', 'lt')) 
-		{
-			$query = 'UPDATE #__plugins SET published = '.(int) $state
-				. ' WHERE id IN (' . implode(',', $id) . ')'
-				. ' AND (checked_out = 0 OR (checked_out = '.(int) $this->juser->get('id').'))';
-		}
-		else 
-		{
-			$query = "UPDATE #__extensions SET enabled = ".(int) $state
-				. " WHERE extension_id IN (" . implode(',', $id) . ")"
-				. " AND `type`='plugin' AND (checked_out = 0 OR (checked_out = ". (int) $this->juser->get('id') . "))";
-		}
+		$query = "UPDATE #__extensions SET enabled = ".(int) $state
+			. " WHERE extension_id IN (" . implode(',', $id) . ")"
+			. " AND `type`='plugin' AND (checked_out = 0 OR (checked_out = ". (int) $this->juser->get('id') . "))";
 
 		$this->database->setQuery($query);
-		if (!$this->database->query()) 
+		if (!$this->database->query())
 		{
 			$this->setRedirect(
 				'index.php?option=' . $this->_option . '&controller=' . $this->_controller . '&client=' . $client,
@@ -579,16 +425,9 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 			return;
 		}
 
-		if (count($id) == 1) 
+		if (count($id) == 1)
 		{
-			if (version_compare(JVERSION, '1.6', 'lt'))
-			{
-				$row = JTable::getInstance('plugin');
-			}
-			else
-			{
-				$row = JTable::getInstance('extension');
-			}
+			$row = JTable::getInstance('extension');
 			$row->checkin($id[0]);
 		}
 
@@ -599,7 +438,7 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 
 	/**
 	 * Reorder a plugin up
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function orderupTask()
@@ -609,7 +448,7 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 
 	/**
 	 * Reorder a plugin down
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function orderdownTask()
@@ -619,7 +458,7 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 
 	/**
 	 * Reorder a plugin
-	 * 
+	 *
 	 * @param      integer $access Access level to set
 	 * @return     void
 	 */
@@ -636,23 +475,16 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 		$client = JRequest::getWord('filter_client', 'site');
 
 		// Currently Unsupported
-		if ($client == 'admin') 
+		if ($client == 'admin')
 		{
 			$where = "client_id = 1";
-		} 
-		else 
-		{
-			$where = "client_id = 0";
-		}
-		
-		if (version_compare(JVERSION, '1.6', 'lt')) 
-		{
-			$row = JTable::getInstance('plugin');
 		}
 		else
 		{
-			$row = JTable::getInstance('extension');
+			$where = "client_id = 0";
 		}
+
+		$row = JTable::getInstance('extension');
 		$row->load($uid);
 		$row->move($inc, 'folder='.$this->database->Quote($row->folder).' AND ordering > -10000 AND ordering < 10000 AND ('.$where.')');
 
@@ -663,27 +495,27 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 
 	/**
 	 * Set the state of an article to 'public'
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function accesspublicTask()
 	{
 		return $this->accessTask(1);
 	}
-	
+
 	/**
 	 * Set the state of an article to 'registered'
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function accessregisteredTask()
 	{
 		return $this->accessTask(2);
 	}
-	
+
 	/**
 	 * Set the state of an article to 'special'
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function accessspecialTask()
@@ -693,7 +525,7 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 
 	/**
 	 * Set the access of a plugin
-	 * 
+	 *
 	 * @param      integer $access Access level to set
 	 * @return     void
 	 */
@@ -707,21 +539,14 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 		JArrayHelper::toInteger($cid, array(0));
 
 		// Load the object
-		if (version_compare(JVERSION, '1.6', 'lt')) 
-		{
-			$row = JTable::getInstance('plugin');
-		}
-		else
-		{
-			$row = JTable::getInstance('extension');
-		}
+		$row = JTable::getInstance('extension');
 		$row->load($cid[0]);
 
 		// Set the access
 		$row->access = $access;
 
 		// Check data
-		if (!$row->check()) 
+		if (!$row->check())
 		{
 			$this->setRedirect(
 				'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
@@ -730,9 +555,9 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 			);
 			return;
 		}
-		
+
 		// Store data
-		if (!$row->store()) 
+		if (!$row->store())
 		{
 			$this->setRedirect(
 				'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
@@ -750,7 +575,7 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 
 	/**
 	 * Save the ordering for an array of plugins
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function saveorderTask()
@@ -765,14 +590,8 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 		$order = JRequest::getVar('order', array(0), 'post', 'array');
 		JArrayHelper::toInteger($order, array(0));
 
-		if (version_compare(JVERSION, '1.6', 'lt')) 
-		{
-			$row = JTable::getInstance('plugin');
-		}
-		else
-		{
-			$row = JTable::getInstance('extension');
-		}
+		$row = JTable::getInstance('extension');
+
 		$conditions = array();
 
 		// update ordering values
@@ -782,7 +601,7 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 			if ($row->ordering != $order[$i])
 			{
 				$row->ordering = $order[$i];
-				if (!$row->store()) 
+				if (!$row->store())
 				{
 					$this->setRedirect(
 						'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
@@ -796,7 +615,7 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 				$found = false;
 				foreach ($conditions as $cond)
 				{
-					if ($cond[1] == $condition) 
+					if ($cond[1] == $condition)
 					{
 						$found = true;
 						break;
@@ -807,7 +626,7 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 		}
 
 		// execute updateOrder for each group
-		foreach ($conditions as $cond) 
+		foreach ($conditions as $cond)
 		{
 			$row->load($cond[0]);
 			$row->reorder($cond[1]);
@@ -816,7 +635,7 @@ class ResourcesControllerPlugins extends \Hubzero\Component\AdminController
 		// Set the redirect
 		$this->setRedirect(
 			'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-			JText::_('New ordering saved')
+			JText::_('COM_RESOURCES_ORDERING_SAVED')
 		);
 	}
 }
