@@ -30,13 +30,13 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-JToolBarHelper::title(JText::_('Support').': '.JText::_('ACL'), 'support.png');
+JToolBarHelper::title(JText::_('COM_SUPPORT') . ': ' . JText::_('COM_SUPPORT_ACL'), 'support.png');
 JToolBarHelper::deleteList();
 JToolBarHelper::spacer();
-JToolBarHelper::help('acl.html', true);
+JToolBarHelper::help('acl');
 ?>
 <script type="text/javascript">
-function submitbutton(pressbutton) 
+function submitbutton(pressbutton)
 {
 	var form = document.adminForm;
 	if (pressbutton == 'cancel') {
@@ -54,12 +54,12 @@ function submitbutton(pressbutton)
 * @param The number of box to 'check'
 * @param An alternative field name
 */
-function checkAllOptions() 
+function checkAllOptions()
 {
 	var f = document.adminForm;
 	var c = f.toggleOpt.checked;
-	console.log(f.toggle);
-	$$('.chk').each(function(el){
+
+	$('.chk').each(function(i, el){
 		el.checked = c;
 	});
 }
@@ -73,23 +73,23 @@ function checkAllOptions()
 				<th> </th>
 				<th> </th>
 				<th> </th>
-				<th colspan="3"><?php echo JText::_('Tickets'); ?></th>
-				<th colspan="2"><?php echo JText::_('Comments'); ?></th>
-				<th colspan="2"><?php echo JText::_('Private Comments'); ?></th>
+				<th colspan="3"><?php echo JText::_('COM_SUPPORT_COL_TICKETS'); ?></th>
+				<th colspan="2"><?php echo JText::_('COM_SUPPORT_COL_COMMENTS'); ?></th>
+				<th colspan="2"><?php echo JText::_('COM_SUPPORT_COL_PRIVATE_COMMENTS'); ?></th>
 				<th> </th>
 			</tr>
 			<tr>
 				<th><input type="checkbox" name="toggle" value="" onclick="checkAll(<?php echo count($this->rows);?>);" /></th>
-				<th><?php echo JText::_('SUPPORT_COL_ID'); ?></th>
-				<th><?php echo JText::_('Object'); ?></th>
-				<th><?php echo JText::_('Model'); ?></th>
-				<th><?php echo JText::_('Read'); ?></th>
-				<th><?php echo JText::_('Update'); ?></th>
-				<th><?php echo JText::_('Delete'); ?></th>
-				<th><?php echo JText::_('Create'); ?></th>
-				<th><?php echo JText::_('Read'); ?></th>
-				<th><?php echo JText::_('Create'); ?></th>
-				<th><?php echo JText::_('Read'); ?></th>
+				<th><?php echo JText::_('COM_SUPPORT_COL_ID'); ?></th>
+				<th><?php echo JText::_('COM_SUPPORT_COL_OBJECT'); ?></th>
+				<th><?php echo JText::_('COM_SUPPORT_COL_MODEL'); ?></th>
+				<th><?php echo JText::_('COM_SUPPORT_COL_READ'); ?></th>
+				<th><?php echo JText::_('COM_SUPPORT_COL_UPDATE'); ?></th>
+				<th><?php echo JText::_('COM_SUPPORT_COL_DELETE'); ?></th>
+				<th><?php echo JText::_('COM_SUPPORT_COL_CREATE'); ?></th>
+				<th><?php echo JText::_('COM_SUPPORT_COL_READ'); ?></th>
+				<th><?php echo JText::_('COM_SUPPORT_COL_CREATE'); ?></th>
+				<th><?php echo JText::_('COM_SUPPORT_COL_READ'); ?></th>
 				<th> </th>
 			</tr>
 		</thead>
@@ -100,15 +100,15 @@ function checkAllOptions()
 					<input type="hidden" name="aro[id]" id="aro_id" value="" />
 				</td>
 				<td>
-					<label for="aro_foreign_key">Alias or ID:</label>
+					<label for="aro_foreign_key"><?php echo JText::_('COM_SUPPORT_ACL_ALIAS_ID'); ?>:</label>
 					<input type="text" name="aro[foreign_key]" id="aro_foreign_key" size="20" value="" />
 				</td>
 				<td>
 					<select name="aro[model]" id="aro_model">
-						<option value="user"><?php echo JText::_('user'); ?></option>
-						<option value="group"><?php echo JText::_('group'); ?></option>
+						<option value="user"><?php echo JText::_('COM_SUPPORT_ACL_USER'); ?></option>
+						<option value="group"><?php echo JText::_('COM_SUPPORT_ACL_GROUP'); ?></option>
 					</select>
-					<input type="checkbox" name="toggleOpt" value="" onclick="checkAllOptions();" /> <abbr title="<?php echo JText::_('Check all options'); ?>"><?php echo JText::_('All'); ?></abbr>
+					<input type="checkbox" name="toggleOpt" value="" onclick="checkAllOptions();" /> <abbr title="<?php echo JText::_('COM_SUPPORT_CHECK_ALL'); ?>"><?php echo JText::_('COM_SUPPORT_COL_ALL'); ?></abbr>
 				</td>
 				<td>
 					<input type="hidden" name="map[tickets][id]" value="0" />
@@ -158,9 +158,9 @@ for ($i=0, $n=count($this->rows); $i < $n; $i++)
 	$row = &$this->rows[$i];
 
 	$sql = "SELECT m.*, r.model AS aro_model, r.foreign_key AS aro_foreign_key, r.alias AS aro_alias, c.model AS aco_model, c.foreign_key AS aco_foreign_key
-	FROM #__support_acl_aros_acos AS m 
-	LEFT JOIN #__support_acl_aros AS r ON m.aro_id=r.id 
-	LEFT JOIN #__support_acl_acos AS c ON m.aco_id=c.id 
+	FROM #__support_acl_aros_acos AS m
+	LEFT JOIN #__support_acl_aros AS r ON m.aro_id=r.id
+	LEFT JOIN #__support_acl_acos AS c ON m.aco_id=c.id
 	WHERE r.foreign_key=$row->foreign_key AND r.model='$row->model'
 	ORDER BY aro_foreign_key, aro_model";
 	$this->database->setQuery($sql);
@@ -196,112 +196,104 @@ for ($i=0, $n=count($this->rows); $i < $n; $i++)
 				<td style="text-align:center;"><?php echo $row->id; ?></td>
 				<td><?php echo $row->alias; ?> (<?php echo $row->foreign_key; ?>)</td>
 				<td><?php echo $row->model; ?></td>
-				
 				<td style="text-align:center;">
-					<?php 
-					$cimg = 'publish_x.png';
-					$calt = JText::_('no');
+					<?php
+					$calt = JText::_('JNO');
 					$cls = 'unpublish';
-					if ($data['tickets']['read']) {
-						$cimg = 'publish_g.png';
-						$calt = JText::_('yes');
+					if ($data['tickets']['read'])
+					{
+						$calt = JText::_('JYES');
 						$cls = 'publish';
 					}
 					?>
 					<a class="state <?php echo $cls; ?>" href="index.php?option=<?php echo $this->option; ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=update&amp;id=<?php echo $data['tickets']['id']; ?>&amp;action=read&amp;value=<?php echo $data['tickets']['read'] ? '0' : '1' ?>&amp;<?php //echo JUtility::getToken(); ?>vfd=1">
-						<span><img src="images/<?php echo $cimg;?>" width="16" height="16" border="0" alt="<?php echo $calt; ?>" /></span>
+						<span><?php echo $calt; ?></span>
 					</a>
 				</td>
 				<td style="text-align:center;">
-					<?php 
-					$cimg = 'publish_x.png';
-					$calt = JText::_('no');
+					<?php
+					$calt = JText::_('JNO');
 					$cls = 'unpublish';
-					if ($data['tickets']['update']) {
-						$cimg = 'publish_g.png';
-						$calt = JText::_('yes');
+					if ($data['tickets']['update'])
+					{
+						$calt = JText::_('JYES');
 						$cls = 'publish';
 					}
 					?>
 					<a class="state <?php echo $cls; ?>" href="index.php?option=<?php echo $this->option; ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=update&amp;id=<?php echo $data['tickets']['id']; ?>&amp;action=update&amp;value=<?php echo $data['tickets']['update'] ? '0' : '1' ?>&amp;<?php //echo JUtility::getToken(); ?>vfd=1">
-						<span><img src="images/<?php echo $cimg;?>" width="16" height="16" border="0" alt="<?php echo $calt; ?>" /></span>
+						<span><?php echo $calt; ?></span>
 					</a>
 				</td>
 				<td style="text-align:center;">
-					<?php 
-					$cimg = 'publish_x.png';
-					$calt = JText::_('no');
+					<?php
+					$calt = JText::_('JNO');
 					$cls = 'unpublish';
-					if ($data['tickets']['delete']) {
-						$cimg = 'publish_g.png';
-						$calt = JText::_('yes');
+					if ($data['tickets']['delete'])
+					{
+						$calt = JText::_('JYES');
 						$cls = 'publish';
 					}
 					?>
 					<a class="state <?php echo $cls; ?>" href="index.php?option=<?php echo $this->option; ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=update&amp;id=<?php echo $data['tickets']['id']; ?>&amp;action=delete&amp;value=<?php echo $data['tickets']['delete'] ? '0' : '1' ?>&amp;<?php //echo JUtility::getToken(); ?>vfd=1">
-						<span><img src="images/<?php echo $cimg;?>" width="16" height="16" border="0" alt="<?php echo $calt; ?>" /></span>
+						<span><?php echo $calt; ?></span>
 					</a>
 				</td>
 
 				<td style="text-align:center;">
-					<?php 
-					$cimg = 'publish_x.png';
-					$calt = JText::_('no');
+					<?php
+					$calt = JText::_('JNO');
 					$cls = 'unpublish';
-					if ($data['comments']['create']) {
-						$cimg = 'publish_g.png';
-						$calt = JText::_('yes');
+					if ($data['comments']['create'])
+					{
+						$calt = JText::_('JYES');
 						$cls = 'publish';
 					}
 					?>
 					<a class="state <?php echo $cls; ?>" href="index.php?option=<?php echo $this->option; ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=update&amp;id=<?php echo $data['comments']['id']; ?>&amp;action=create&amp;value=<?php echo $data['comments']['create'] ? '0' : '1' ?>&amp;<?php //echo JUtility::getToken(); ?>vfd=1">
-						<span><img src="images/<?php echo $cimg;?>" width="16" height="16" border="0" alt="<?php echo $calt; ?>" /></span>
+						<span><?php echo $calt; ?></span>
 					</a>
 				</td>
 				<td style="text-align:center;">
-					<?php 
-					$cimg = 'publish_x.png';
-					$calt = JText::_('no');
+					<?php
+					$calt = JText::_('JNO');
 					$cls = 'unpublish';
-					if ($data['comments']['read']) {
-						$cimg = 'publish_g.png';
-						$calt = JText::_('yes');
+					if ($data['comments']['read'])
+					{
+						$calt = JText::_('JYES');
 						$cls = 'publish';
 					}
 					?>
 					<a class="state <?php echo $cls; ?>" href="index.php?option=<?php echo $this->option; ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=update&amp;id=<?php echo $data['comments']['id']; ?>&amp;action=read&amp;value=<?php echo $data['comments']['read'] ? '0' : '1' ?>&amp;<?php //echo JUtility::getToken(); ?>vfd=1">
-						<span><img src="images/<?php echo $cimg;?>" width="16" height="16" border="0" alt="<?php echo $calt; ?>" /></span>
+						<span><?php echo $calt; ?></span>
 					</a>
 				</td>
 
 				<td style="text-align:center;">
-					<?php 
-					$cimg = 'publish_x.png';
-					$calt = JText::_('no');
+					<?php
+					$calt = JText::_('JNO');
 					$cls = 'unpublish';
-					if ($data['private_comments']['create']) {
-						$cimg = 'publish_g.png';
-						$calt = JText::_('yes');
+					if ($data['private_comments']['create'])
+					{
+						$calt = JText::_('JYES');
 						$cls = 'publish';
 					}
 					?>
 					<a class="state <?php echo $cls; ?>" href="index.php?option=<?php echo $this->option; ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=update&amp;id=<?php echo $data['private_comments']['id']; ?>&amp;action=create&amp;value=<?php echo $data['private_comments']['create'] ? '0' : '1' ?>&amp;<?php //echo JUtility::getToken(); ?>vfd=1">
-						<span><img src="images/<?php echo $cimg;?>" width="16" height="16" border="0" alt="<?php echo $calt; ?>" /></span>
+						<span><?php echo $calt; ?></span>
 					</a>
 				</td>
 				<td style="text-align:center;">
-					<?php 
-					$cimg = 'publish_x.png';
-					$calt = JText::_('no');
+					<?php
+					$calt = JText::_('JNO');
 					$cls = 'unpublish';
-					if ($data['private_comments']['read']) {
-						$cimg = 'publish_g.png';
-						$calt = JText::_('yes');
+					if ($data['private_comments']['read'])
+					{
+						$calt = JText::_('JYES');
 						$cls = 'publish';
 					}
 					?>
 					<a class="state <?php echo $cls; ?>" href="index.php?option=<?php echo $this->option; ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=update&amp;id=<?php echo $data['private_comments']['id']; ?>&amp;action=read&amp;value=<?php echo $data['private_comments']['read'] ? '0' : '1' ?>&amp;<?php //echo JUtility::getToken(); ?>vfd=1">
-						<span><img src="images/<?php echo $cimg;?>" width="16" height="16" border="0" alt="<?php echo $calt; ?>" /></span>
+						<span><?php echo $calt; ?></span>
 					</a>
 				</td>
 				<td> </td>
