@@ -30,7 +30,7 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-$canDo = WishlistHelper::getActions('component');
+$canDo = WishlistHelperPermissions::getActions('component');
 
 JToolBarHelper::title(JText::_('COM_WISHLIST') . ': ' . JText::_('COM_WISHLIST_WISHES'), 'wishlist.png');
 if ($canDo->get('core.edit.state'))
@@ -53,6 +53,8 @@ if ($canDo->get('core.delete'))
 }
 JToolBarHelper::spacer();
 JToolBarHelper::help('wishes');
+
+$this->css();
 ?>
 <script type="text/javascript">
 function submitbutton(pressbutton)
@@ -109,11 +111,11 @@ function submitbutton(pressbutton)
 				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_WISHLIST_WISH_ID', 'id', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
 				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_WISHLIST_TITLE', 'subject', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
 				<?php if (!$this->wishlist->id) { ?>
-				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_WISHLIST_WISHLIST_ID', 'wishlist', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
+					<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_WISHLIST_WISHLIST_ID', 'wishlist', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
 				<?php } ?>
 				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_WISHLIST_PROPOSED_BY', 'proposed_by', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
 				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_WISHLIST_PROPOSED', 'proposed', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
-				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_WISHLIST_STATE', 'status', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
+				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_WISHLIST_STATUS', 'status', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
 				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_WISHLIST_ACCESS', 'private', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
 				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_WISHLIST_COMMENTS', 'comments', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
 			</tr>
@@ -132,20 +134,40 @@ for ($i=0, $n=count($this->rows); $i < $n; $i++)
 	switch ($row->status)
 	{
 		case 1:
-			$class = 'publish';
-			$task = 'unpublish';
-			$alt = JText::_('COM_WISHLIST_PUBLISHED');
+			$class = 'granted';
+			$task = 'pending';
+			$alt = JText::_('COM_WISHLIST_STATUS_GRANTED');
 		break;
 		case 2:
-			$class = 'expire';
-			$task = 'publish';
-			$alt = JText::_('COM_WISHLIST_TRASHED');
+			$class = 'trashed';
+			$task = 'grant';
+			$alt = JText::_('COM_WISHLIST_STATUS_DELETED');
+		break;
+		case 3:
+			$class = 'rejected';
+			$task = 'pending';
+			$alt = JText::_('COM_WISHLIST_STATUS_REJECTED');
+		break;
+		case 4:
+			$class = 'withdrawn';
+			$task = 'pending';
+			$alt = JText::_('COM_WISHLIST_STATUS_WITHDRAWN');
+		break;
+		case 6:
+			$class = 'accepted';
+			$task = 'grant';
+			$alt = JText::_('COM_WISHLIST_STATUS_WITHDRAWN');
+		break;
+		case 7:
+			$class = 'flagged';
+			$task = 'pending';
+			$alt = JText::_('COM_WISHLIST_STATUS_WITHDRAWN');
 		break;
 		case 0:
 		default;
-			$class = 'unpublish';
-			$task = 'publish';
-			$alt = JText::_('COM_WISHLIST_UNPUBLISHED');
+			$class = 'pending';
+			$task = 'grant';
+			$alt = JText::_('COM_WISHLIST_STATUS_PENDING');
 		break;
 	}
 
@@ -164,14 +186,14 @@ for ($i=0, $n=count($this->rows); $i < $n; $i++)
 ?>
 			<tr class="<?php echo "row$k"; ?>">
 				<td>
-					<input type="checkbox" name="id[]" id="cb<?php echo $i;?>" value="<?php echo $row->id ?>" onclick="isChecked(this.checked, this);" />
+					<input type="checkbox" name="id[]" id="cb<?php echo $i; ?>" value="<?php echo $row->id; ?>" onclick="isChecked(this.checked, this);" />
 				</td>
 				<td>
 					<?php echo $row->id; ?>
 				</td>
 				<td>
 					<?php if ($canDo->get('core.edit')) { ?>
-						<a href="index.php?option=<?php echo $this->option ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=edit&amp;id=<?php echo $row->id; ?>">
+						<a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=edit&id=' . $row->id); ?>">
 							<span><?php echo $this->escape(stripslashes($row->subject)); ?></span>
 						</a>
 					<?php } else { ?>
@@ -193,7 +215,7 @@ for ($i=0, $n=count($this->rows); $i < $n; $i++)
 				</td>
 				<td>
 					<?php if ($canDo->get('core.edit.state')) { ?>
-						<a class="state <?php echo $class; ?>" href="index.php?option=<?php echo $this->option ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=<?php echo $task;?>&amp;id=<?php echo $row->id; ?>&amp;<?php echo JUtility::getToken(); ?>=1" title="<?php echo JText::sprintf('COM_WISHLIST_SET_TASK',$task);?>">
+						<a class="state <?php echo $class; ?>" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=' . $task . '&id=' . $row->id . '&' . JUtility::getToken() . '=1'); ?>" title="<?php echo JText::sprintf('COM_WISHLIST_SET_TASK', $task); ?>">
 							<span><?php echo $alt; ?></span>
 						</a>
 					<?php } else { ?>
@@ -204,7 +226,7 @@ for ($i=0, $n=count($this->rows); $i < $n; $i++)
 				</td>
 				<td>
 					<?php if ($canDo->get('core.edit.state')) { ?>
-						<a href="index.php?option=<?php echo $this->option ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=<?php echo $task_access; ?>&amp;id=<?php echo $row->id; ?>&amp;<?php echo JUtility::getToken(); ?>=1" class="<?php echo $color_access; ?>" title="<?php echo JText::_('COM_WISHLIST_CHANGE_ACCESS'); ?>">
+						<a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=' . $task_access . '&id=' . $row->id . '&' . JUtility::getToken() . '=1'); ?>" class="<?php echo $color_access; ?>" title="<?php echo JText::_('COM_WISHLIST_CHANGE_ACCESS'); ?>">
 							<?php echo $groupname; ?>
 						</a>
 					<?php } else { ?>
