@@ -34,6 +34,7 @@ defined('_JEXEC') or die( 'Restricted access' );
 $this->css();
 
 $total = $this->closed + $this->open;
+
 ?>
 <div class="<?php echo $this->module->module; ?>">
 	<table class="stats-overview">
@@ -51,12 +52,16 @@ $total = $this->closed + $this->open;
 			<?php } ?>
 			<tr>
 				<td class="closed">
-					<a href="index.php?option=com_answers&amp;filterby=closed" title="<?php echo JText::_('MOD_ANSWERS_CLOSED_TITLE'); ?>"><?php echo $this->escape($this->closed); ?></a>
-					<span><?php echo JText::_('MOD_ANSWERS_CLOSED'); ?></span>
+					<a href="index.php?option=com_answers&amp;filterby=closed" title="<?php echo JText::_('MOD_ANSWERS_CLOSED_TITLE'); ?>">
+						<?php echo $this->escape($this->closed); ?>
+						<span><?php echo JText::_('MOD_ANSWERS_CLOSED'); ?></span>
+					</a>
 				</td>
 				<td class="asked">
-					<a href="index.php?option=com_answers&amp;filterby=open" title="<?php echo JText::_('MOD_ANSWERS_ASKED_TITLE'); ?>"><?php echo $this->escape($this->open); ?></a>
-					<span><?php echo JText::_('MOD_ANSWERS_ASKED'); ?></span>
+					<a href="index.php?option=com_answers&amp;filterby=open" title="<?php echo JText::_('MOD_ANSWERS_ASKED_TITLE'); ?>">
+						<?php echo $this->escape($this->open); ?>
+						<span><?php echo JText::_('MOD_ANSWERS_ASKED'); ?></span>
+					</a>
 				</td>
 			</tr>
 		</tbody>
