@@ -31,22 +31,8 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-$option = JRequest::getCmd('option', 'com_answers');
-
-if (version_compare(JVERSION, '1.6', 'lt'))
-{
-	$jacl = JFactory::getACL();
-	$jacl->addACL($option, 'manage', 'users', 'super administrator');
-	$jacl->addACL($option, 'manage', 'users', 'administrator');
-	$jacl->addACL($option, 'manage', 'users', 'manager');
-}
-
 require_once(JPATH_COMPONENT_SITE . DS . 'models' . DS . 'question.php');
-include_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_support' . DS . 'tables' . DS . 'reportabuse.php');
-require_once(JPATH_COMPONENT_ADMINISTRATOR . DS . 'tables' . DS . 'log.php');
-require_once(JPATH_COMPONENT_ADMINISTRATOR . DS . 'tables' . DS . 'questionslog.php');
 require_once(JPATH_COMPONENT_SITE . DS . 'helpers' . DS . 'economy.php');
-require_once(JPATH_COMPONENT_SITE . DS . 'helpers' . DS . 'member.php');
 
 $controllerName = JRequest::getCmd('controller', JRequest::getCmd('view', 'questions'));
 if (!file_exists(JPATH_COMPONENT_SITE . DS . 'controllers' . DS . $controllerName . '.php'))
