@@ -34,15 +34,15 @@ defined('_JEXEC') or die( 'Restricted access' );
 $juri = JURI::getInstance();
 $jconfig = JFactory::getConfig();
 
-if ($this->question->isOpen() && !$this->question->isReported()) 
+if ($this->question->isOpen() && !$this->question->isReported())
 {
 	$status = 'open';
-} 
-else if ($this->question->isReported()) 
+}
+else if ($this->question->isReported())
 {
 	$status = 'underreview';
-} 
-else 
+}
+else
 {
 	$status = 'closed';
 }
@@ -56,21 +56,18 @@ Content-type: text/plain;charset=utf-8
 <?php
 if ($this->plaintext)
 {
-	echo $this->plaintext; 
+	echo $this->plaintext;
 }
 else
 {
-	$eview = new JView(array(
-		'name'   => 'emails',
-		'layout' => 'question_plaintext'
-	));
-	$eview->option   = $this->option;
-	$eview->sitename = $this->sitename;
-	$eview->juser    = $this->juser;
-	$eview->question = $this->question;
-	$eview->id       = $this->id;
-	$eview->boundary = $this->boundary;
-	$eview->link     = $link;
+	$eview = $this->view('question_plaintext')
+			     ->set('option', $this->option)
+			     ->set('sitename', $this->sitename)
+			     ->set('juser', $this->juser)
+			     ->set('question', $this->question)
+			     ->set('id', $this->id)
+			     ->set('boundary', $this->boundary)
+			     ->set('link', $link);
 
 	echo $eview->loadTemplate();
 }
