@@ -33,17 +33,16 @@ defined('_JEXEC') or die( 'Restricted access' );
 
 $states = Cart_Helper::getUsStates();
 
+$this->css();
 ?>
 
-<div id="content-header">
+<header id="content-header">
 	<h2>Checkout: shipping information</h2>
-</div>
+</header>
 
-<section class="main">
+<section class="main section">
 	<div class="section-inner">
-	
 		<?php
-				
 		$errors = $this->getError();
 		if (!empty($errors))
 		{
@@ -51,73 +50,63 @@ $states = Cart_Helper::getUsStates();
 			{
 				echo '<p class="error">' . $error . '</p>';
 			}
-		}	
-		
+		}
 		?>
-		
 		<div class="grid">
 			<div class="col span6">
-			
 				<h2>Shipping address</h2>
-			
+
 				<form name="cartShippingInfo" id="cartShippingInfo" method="post" class="hubForm">
-				
 					<label for="shippingToFirst">First name:
-					<input type="text" name="shippingToFirst" id="shippingToFirst" value="<?php echo JRequest::getVar('shippingToFirst', false, 'post'); ?>" />
+						<input type="text" name="shippingToFirst" id="shippingToFirst" value="<?php echo JRequest::getVar('shippingToFirst', false, 'post'); ?>" />
 					</label>
-					
+
 					<label for="shippingToLast">Last name:
-					<input type="text" name="shippingToLast" id="shippingToLast" value="<?php echo JRequest::getVar('shippingToLast', false, 'post'); ?>" />
-					</label> 
-					
+						<input type="text" name="shippingToLast" id="shippingToLast" value="<?php echo JRequest::getVar('shippingToLast', false, 'post'); ?>" />
+					</label>
+
 					<label for="shippingAddress">Shipping address:
-					<input type="text" name="shippingAddress" id="shippingAddress" value="<?php echo JRequest::getVar('shippingAddress', false, 'post'); ?>" />
-					</label> 
-					
+						<input type="text" name="shippingAddress" id="shippingAddress" value="<?php echo JRequest::getVar('shippingAddress', false, 'post'); ?>" />
+					</label>
+
 					<label for="shippingCity">City:
-					<input type="text" name="shippingCity" id="shippingCity" value="<?php echo JRequest::getVar('shippingCity', false, 'post'); ?>" />
-					</label> 
-					
+						<input type="text" name="shippingCity" id="shippingCity" value="<?php echo JRequest::getVar('shippingCity', false, 'post'); ?>" />
+					</label>
+
 					<label for="shippingZip">Zip:
-					<input type="text" name="shippingZip" id="shippingZip" value="<?php echo JRequest::getVar('shippingZip', false, 'post'); ?>" />
-					</label> 
-					
+						<input type="text" name="shippingZip" id="shippingZip" value="<?php echo JRequest::getVar('shippingZip', false, 'post'); ?>" />
+					</label>
+
 					<label for="shippingState">State:
-					<select name="shippingState" id="shippingState">
-						<option value=""> -- please select -- </option>
-						<?php
-							foreach ($states as $abbr => $state)
-							{
-								echo '<option value="' . $abbr . '"';
-								if (JRequest::getVar('shippingState', false, 'post') == $abbr)
+						<select name="shippingState" id="shippingState">
+							<option value=""> -- please select -- </option>
+							<?php
+								foreach ($states as $abbr => $state)
 								{
-									echo ' selected';
+									echo '<option value="' . $abbr . '"';
+									if (JRequest::getVar('shippingState', false, 'post') == $abbr)
+									{
+										echo ' selected';
+									}
+									echo '>' . $state . '</option>';
 								}
-								echo '>' . $state . '</option>';
-							}
-						?>
-					</select>
-					</label> 
-					
-					
+							?>
+						</select>
+					</label>
+
 					<label for="saveAddress"><input type="checkbox" name="saveAddress" id="saveAddress" /> Save this address?</label>
-										
+
 					<p class="submit">
 						<input type="submit" value="Next" name="submitShippingInfo" id="submitShippingInfo" class="btn" />
 					</p>
-				
 				</form>
-			
 			</div>
 			<div class="col span6 omega">
-				
-				
 				<?php
-				
 				if (!empty($this->savedShippingAddresses))
 				{
 					echo '<h2>Select saved address</h2>';
-					
+
 					foreach ($this->savedShippingAddresses as $address)
 					{
 						echo '<div class="cartSection">';
@@ -126,17 +115,16 @@ $states = Cart_Helper::getUsStates();
 						echo $address->saAddress . '<br>';
 						echo $address->saCity . ', ' . $address->saState . ' ' . $address->saZip;
 						echo '</p>';
-						
+
 						echo '<a href="';
 						echo JRoute::_('index.php?option=com_cart/checkout/shipping/select/' . $address->saId);
 						echo '">';
 						echo 'Ship to this address';
 						echo '</a>';
-						
-						echo '</div>';	
+
+						echo '</div>';
 					}
 				}
-				
 				?>
 			</div>
 		</div>
