@@ -35,25 +35,25 @@ setlocale(LC_MONETARY, 'en_US.UTF-8');
 
 ?>
 
-<div id="content-header">
+<header id="content-header">
 	<h2>Pretend payment page</h2>
-</div>
+</header>
 
-<section>
+<section class="main section">
 	<div class="section-inner">
 		<p>Imagine you have a lot of money and free to spend it. He is it, the pretend pay page. Just hit the 'Pay' button.</p>
 
 		<form action="" id="frm" method="post">
-		
+
 		<?php
 			foreach($_POST as $k => $v)
 			{
 				echo '<input type="hidden" name="' . $k . '" value="' . $v . '"></input>';
 			}
 		?>
-		
+
 		<input type="hidden" name="dummypay" value="1"></input>
-		
+
 		<input type="submit" value="Pay">
 		</form>
 	</div>
