@@ -56,6 +56,13 @@ class CronModelJob extends \Hubzero\Base\Model
 	 */
 	protected $_tbl_name = 'CronTableJob';
 
+	/**
+	 * Cron expression
+	 *
+	 * @var object
+	 */
+	private $_expression = NULL;
+
 	/**
 	 * JProfiler
 	 *
