@@ -799,8 +799,8 @@ class EventsControllerEvents extends \Hubzero\Component\SiteController
 		$categories = $this->_getCategories();
 
 		// Get tags on this event
-		$rt = new EventsTags($this->database);
-		$tags = $rt->get_tag_cloud(0, 0, $row->id);
+		$rt = new EventsModelTags($row->id);
+		$tags = $rt->render();
 
 		// Set the page title
 		$document = JFactory::getDocument();
@@ -1423,8 +1423,7 @@ class EventsControllerEvents extends \Hubzero\Component\SiteController
 			// Yes - edit mode
 
 			// Are they authorized to make edits?
-			if (!$this->_authorize($row->created_by)
-				&& !($this->juser->get('id') == $row->created_by))
+			if (!$this->_authorize($row->created_by))
 			{
 				// Not authorized - redirect
 				$this->_redirect = JRoute::_('index.php?option=' . $this->_option);
@@ -1577,8 +1576,12 @@ class EventsControllerEvents extends \Hubzero\Component\SiteController
 		$times['registerby_pm'] = $registerby_pm;
 
 		// Get tags on this event
-		$rt = new EventsTags($this->database);
-		$lists['tags'] = $rt->get_tag_string($row->id, 0, 0, NULL, 0, 1);
+		$lists['tags'] = '';
+		if ($row->id)
+		{
+			$rt = new EventsModelTags($row->id);
+			$lists['tags'] = $rt->render('string');
+		}
 
 		// get tags passed from failed save
 		if (isset($this->tags))
@@ -1664,9 +1667,7 @@ class EventsControllerEvents extends \Hubzero\Component\SiteController
 		$event = new EventsEvent($this->database);
 		$event->load($id);
 
-		// Are they authorized to delete this event? Do they own it? Own it!
-		if (!$this->_authorize($event->created_by)
-			&& !($this->juser->get('id') == $event->created_by))
+		if (!$this->_authorize($event->created_by))
 		{
 			$this->_redirect = JRoute::_('index.php?option=' . $this->_option);
 			return;
@@ -1688,8 +1689,8 @@ class EventsControllerEvents extends \Hubzero\Component\SiteController
 		$er->deleteRespondents($id);
 
 		// Delete tags on this event
-		$rt = new EventsTags($this->database);
-		$rt->remove_all_tags($id);
+		$rt = new EventsModelTags($id);
+		$rt->removeAll();
 
 		// Load the event's category and update the count
 		$category = new EventsCategory($this->database);
@@ -1955,8 +1956,8 @@ class EventsControllerEvents extends \Hubzero\Component\SiteController
 		$row->checkin();
 
 		// Save the tags
-		$rt = new EventsTags($this->database);
-		$rt->tag_object($this->juser->get('id'), $row->id, $tags, 1, 0);
+		$rt = new EventsModelTags($row->id);
+		$rt->setTags($tags, $this->juser->get('id'));
 
 		$jconfig = JFactory::getConfig();
 
