@@ -24,7 +24,7 @@
  *
  * @package   hubzero-cms
  * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
- * @license   GNU General Public License, version 2 (GPLv2) 
+ * @license   GNU General Public License, version 2 (GPLv2)
  */
 
 // No direct access
@@ -32,245 +32,245 @@ defined('_JEXEC') or die('Restricted access');
 
 /**
  * Short description for 'EventsRespondent'
- * 
+ *
  * Long description (if any) ...
  */
 class EventsRespondent extends JTable
 {
 	/**
 	 * Description for 'id'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $id = NULL;
 
 	/**
 	 * Description for 'event_id'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $event_id = NULL;
 
 	/**
 	 * Description for 'registered'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $registered = NULL;
 
 	/**
 	 * Description for 'first_name'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $first_name = NULL;
 
 	/**
 	 * Description for 'last_name'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $last_name = NULL;
 
 	/**
 	 * Description for 'affiliation'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $affiliation = NULL;
 
 	/**
 	 * Description for 'title'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $title = NULL;
 
 	/**
 	 * Description for 'city'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $city = NULL;
 
 	/**
 	 * Description for 'state'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $state = NULL;
 
 	/**
 	 * Description for 'zip'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $zip = NULL;
 
 	/**
 	 * Description for 'country'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $country = NULL;
 
 	/**
 	 * Description for 'telephone'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $telephone = NULL;
 
 	/**
 	 * Description for 'fax'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $fax = NULL;
 
 	/**
 	 * Description for 'email'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $email = NULL;
 
 	/**
 	 * Description for 'website'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $website = NULL;
 
 	/**
 	 * Description for 'position_description'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $position_description = NULL;
 
 	/**
 	 * Description for 'highest_degree'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $highest_degree = NULL;
 
 	/**
 	 * Description for 'gender'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $gender = NULL;
 
 	/**
 	 * Description for 'disability_needs'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $disability_needs = NULL;
 
 	/**
 	 * Description for 'dietary_needs'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $dietary_needs = NULL;
 
 	/**
 	 * Description for 'attending_dinner'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $attending_dinner = NULL;
 
 	/**
 	 * Description for 'abstract'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $abstract = NULL;
 
 	/**
 	 * Description for 'comment'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $comment = NULL;
 
 	/**
 	 * Description for 'arrival'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $arrival = NULL;
 
 	/**
 	 * Description for 'departure'
-	 * 
+	 *
 	 * @var unknown
 	 */
 	public $departure = NULL;
 
 	/**
 	 * Description for 'filters'
-	 * 
+	 *
 	 * @var mixed
 	 */
 	private $filters      = array();
 
 	/**
 	 * Description for 'order'
-	 * 
+	 *
 	 * @var string
 	 */
 	private $order        = NULL;
 
 	/**
 	 * Description for 'order_desc'
-	 * 
+	 *
 	 * @var string
 	 */
 	private $order_desc   = NULL;
 
 	/**
 	 * Description for 'search_terms'
-	 * 
+	 *
 	 * @var string
 	 */
 	private $search_terms = '';
 
 	/**
 	 * Description for 'limit'
-	 * 
+	 *
 	 * @var mixed
 	 */
 	private $limit        = 0;
 
 	/**
 	 * Description for 'offset'
-	 * 
+	 *
 	 * @var mixed
 	 */
 	private $offset       = 0;
 
 	/**
 	 * Short description for 'getRacialIdentification'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      unknown $resp_id Parameter description (if any) ...
 	 * @return     mixed Return description (if any) ...
 	 */
 	public static function getRacialIdentification($resp_id)
 	{
-		$dbh =& JFactory::getDBO();
-		if (is_array($resp_id)) 
+		$dbh = JFactory::getDBO();
+		if (is_array($resp_id))
 		{
 			$dbh->setQuery('SELECT respondent_id, group_concat(concat(race, coalesce(concat(\'(\', tribal_affiliation, \')\'), \'\')) separator \', \') AS identification FROM #__events_respondent_race_rel WHERE respondent_id IN (' . implode(', ', array_map('intval', $resp_id)) . ') GROUP BY respondent_id');
 			return $dbh->loadAssocList('respondent_id');
-		} 
-		else 
+		}
+		else
 		{
 			$dbh->setQuery('SELECT group_concat(concat(race, coalesce(concat(\'(\', tribal_affiliation, \')\'), \'\')) separator \', \') FROM #__events_respondent_race_rel WHERE respondent_id = ' . intval($resp_id) . ' GROUP BY respondent_id');
 			return $dbh->loadResult();
@@ -279,9 +279,9 @@ class EventsRespondent extends JTable
 
 	/**
 	 * Short description for 'getSearchTerms'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @return     string Return description (if any) ...
 	 */
 	public function getSearchTerms()
@@ -291,9 +291,9 @@ class EventsRespondent extends JTable
 
 	/**
 	 * Short description for 'getOrdering'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @return     string Return description (if any) ...
 	 */
 	public function getOrdering()
@@ -303,9 +303,9 @@ class EventsRespondent extends JTable
 
 	/**
 	 * Short description for 'getPaginator'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @return     mixed Return description (if any) ...
 	 */
 	public function getPaginator()
@@ -316,9 +316,9 @@ class EventsRespondent extends JTable
 
 	/**
 	 * Short description for '__construct'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      array $filters Parameter description (if any) ...
 	 * @return     void
 	 * @throws Exception  Exception description (if any) ...
@@ -328,39 +328,39 @@ class EventsRespondent extends JTable
 	{
 		parent::__construct('#__events_respondents', 'id', JFactory::getDBO());
 
-		if (array_key_exists('sortby', $filters)) 
+		if (array_key_exists('sortby', $filters))
 		{
-			if (preg_match('/(registered|name|special|id)(?:\ (ASC|DESC))?/', $filters['sortby'], $match)) 
+			if (preg_match('/(registered|name|special|id)(?:\ (ASC|DESC))?/', $filters['sortby'], $match))
 			{
-				if ($match[1] == 'name') 
+				if ($match[1] == 'name')
 				{
 					$this->order_desc = 'name ' . $match[2];
 					$this->order = ' ORDER BY last_name, first_name';
-				} 
-				else if ($match[1] == 'special') 
+				}
+				else if ($match[1] == 'special')
 				{
 					$this->order_desc = 'special ' . $match[2];
 					$this->order = ' ORDER BY CASE WHEN disability_needs OR dietary_needs IS NOT NULL THEN 1 WHEN comment IS NOT NULL THEN 2 ELSE 3 END ' . $match[2];
-				} 
-				else 
+				}
+				else
 				{
 					$this->order_desc = $filters['sortby'];
 					$this->order = ' ORDER BY ' . $filters['sortby'];
 				}
 				unset($filters['sortby']);
-			} 
-			else 
+			}
+			else
 			{
 				throw new Exception('Invalid sorting criterium: ' . $filters['sortby']);
 			}
 		}
 
-		if (array_key_exists('limit', $filters)) 
+		if (array_key_exists('limit', $filters))
 		{
 			$this->limit  = intval($filters['limit']);
 			$this->offset = array_key_exists('offset', $filters) ? intval($filters['offset']) : 0;
 
-			if (array_key_exists('offset', $filters)) 
+			if (array_key_exists('offset', $filters))
 			{
 				unset($filters['offset']);
 			}
@@ -380,9 +380,9 @@ class EventsRespondent extends JTable
 					$this->filters[] = 'id = ' . intval($val);
 				break;
 				case 'search':
-					if (!empty($val)) 
+					if (!empty($val))
 					{
-						$this->filters[] = 'concat(first_name, \' \', last_name) LIKE \'%' . $this->_db->getEscaped($val) . '%\'';
+						$this->filters[] = "concat(first_name, ' ', last_name) LIKE " . $this->_db->quote($val . '%');
 						$this->searchTerms = htmlentities($val);
 					}
 				break;
@@ -396,16 +396,16 @@ class EventsRespondent extends JTable
 
 	/**
 	 * Short description for 'fetch'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      boolean $bounded Parameter description (if any) ...
 	 * @return     mixed Return description (if any) ...
 	 */
 	public function fetch($bounded = true)
 	{
 		$this->_db->setQuery(
-			'SELECT ' . ($bounded ? '*' : 'COUNT(*)') . " FROM $this->_tbl WHERE " . $this->filters . $this->order . 
+			'SELECT ' . ($bounded ? '*' : 'COUNT(*)') . " FROM $this->_tbl WHERE " . $this->filters . $this->order .
 				($bounded && $this->limit != 0 ? ' LIMIT ' . $this->offset . ', ' . $this->limit : '')
 		);
 		return $bounded ? $this->_db->loadObjectList() : $this->_db->loadResult();
@@ -413,9 +413,9 @@ class EventsRespondent extends JTable
 
 	/**
 	 * Short description for 'getRecords'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @return     unknown Return description (if any) ...
 	 */
 	public function getRecords()
@@ -425,9 +425,9 @@ class EventsRespondent extends JTable
 
 	/**
 	 * Short description for 'getCount'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @return     boolean Return description (if any) ...
 	 */
 	public function getCount()
@@ -437,20 +437,36 @@ class EventsRespondent extends JTable
 
 	/**
 	 * Short description for 'deleteRespondents'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      unknown $event_id Parameter description (if any) ...
 	 * @return     mixed Return description (if any) ...
 	 */
 	public function deleteRespondents($event_id=NULL)
 	{
-		if ($event_id === NULL) 
+		if ($event_id === NULL)
 		{
 			return false;
 		}
 		$this->_db->setQuery("DELETE FROM $this->_tbl WHERE event_id=" . intval($event_id));
 		return $this->_db->loadObjectList();
 	}
+
+	/**
+	 * Check for unique registration per event
+	 *
+	 * @param  string $email
+	 * @param  int $eventId
+	 * @return int
+	 */
+	public static function checkUniqueEmailForEvent($email, $eventId)
+	{
+		$db = JFactory::getDBO();
+		$sql = "SELECT COUNT(*) FROM `#__events_respondents` WHERE `event_id`=" . $db->quote($eventId) . " AND `email`=" .$db->quote($email);
+		$db->setQuery($sql);
+		return $db->loadResult();
+	}
+
 }
 
