@@ -1,8 +1,10 @@
 <?php
 defined('JPATH_BASE') or die();
 
+require 'Inflect.php';
+
 /*
-[!] - (zooley) Added NotFoundError class because PHP was throwing
+[!] - (zooley) Added NotFoundError class because PHP was throwing 
 	fatal error that the class was not found (irony?).
 */
 if (!class_exists('NotFoundError'))
@@ -12,13 +14,14 @@ if (!class_exists('NotFoundError'))
 	}
 }
 
-$base = isset($_SERVER['SCRIPT_URL']) ? $_SERVER['SCRIPT_URL'] : $_SERVER['REDIRECT_SCRIPT_URL'];
+foreach (array('SCRIPT_URL', 'URL', 'REDIRECT_SCRIPT_URL', 'REDIRECT_URL') as $k) {
+	if (isset($_SERVER[$k])) {
+		$base = $_SERVER[$k];
+		break;
+	}
+}
 $basePath = preg_replace('#^'.preg_quote(JPATH_BASE).'#', '', dirname(__FILE__));
 
-$doc = JFactory::getDocument();
-//$doc->addScript('/jquery.js');
-\Hubzero\Document\Assets::addComponentScript('com_hubgraph','resources/hubgraph');
-\Hubzero\Document\Assets::addComponentStylesheet('com_hubgraph','resources/hubgraph.css');
 
 $path = JFactory::getApplication()->getPathway();
 $path->addItem('Search', $base);
@@ -30,6 +33,11 @@ function hgView($view, $args = array())
 	exit();
 }
 
+function p($num, $label)
+{
+	return Inflect::pluralizeIf($num, $label);
+}
+
 function h($str)
 {
 	return htmlentities($str);
@@ -42,7 +50,8 @@ function a($str)
 
 function assertSuperAdmin()
 {
-	if (JFactory::getUser()->usertype != 'Super Administrator') {
+	if (JFactory::getUser()->usertype != 'Super Administrator')
+	{
 		JError::raiseError(405, 'Forbidden');
 	}
 }
@@ -79,23 +88,37 @@ $conf = HubgraphConfiguration::instance();
 $perPage = 40;
 
 try {
-	switch (!defined('HG_INLINE') && isset($_REQUEST['task']) ? $_REQUEST['task'] : 'index') {
+	switch ($task = !defined('HG_INLINE') && isset($_REQUEST['task']) ? $_REQUEST['task'] : 'index') {
 		case 'complete':
 			hgView('complete', array('limit' => 20, 'threshold' => 3, 'tagLimit' => 100));
 		case 'getRelated':
 			hgView('related', $req->getTransportCriteria(array('limit' => 5, 'domain' => $_GET['domain'], 'id' => $_GET['id'])));
-		case 'index':
+		case 'index': case 'page':
 			$results = $req->anyCriteria()
 				? json_decode(HubgraphClient::execView('search', $req->getTransportCriteria(array('limit' => $perPage))), TRUE)
 				: NULL;
-			require 'views/index.html.php';
+			$tags         = $req->getTags();
+			$users        = $req->getContributors();
+			$groups       = $req->getGroup();
+			$domainMap    = $req->getDomainMap();
+			$loggedIn     = (bool)JFactory::getUser()->id;
+			ksort($domainMap);
+
+			if ($task == 'page') {
+				define('HG_AJAX', 1);
+				require 'views/page.html.php';
+				exit();
+			}
+			else {
+				require 'views/index-update.html.php';
+			}
 		break;
 		case 'update':
 			$results = $req->anyCriteria()
 				? json_decode(HubgraphClient::execView('search', $req->getTransportCriteria(array('limit' => $perPage))), TRUE)
 				: NULL;
 			define('HG_AJAX', 1);
-			require 'views/index.html.php';
+			require 'views/index-update.html.php';
 			exit();
 		break;
 		case 'settings':
@@ -114,8 +137,11 @@ try {
 	}
 }
 catch (Exception $ex) {
+	echo $ex->getMessage();
+	exit();
+	error_log($ex->getMessage());
 	if (!defined('HG_INLINE')) {
-		header('Location: '.JRoute::_('index.php?option=com_ysearch' . (isset($_GET['terms']) ? '&terms='.$_GET['terms'] : '')));
+		header('Location: '.JRoute::_('index.php?option=com_search' . (isset($_GET['terms']) ? '&terms='.$_GET['terms'] : '')));
 		exit();
 	}
 }
