@@ -19,17 +19,17 @@ defined('_JEXEC') or die('Restricted access');
 JTable::addIncludePath(JPATH_COMPONENT_ADMINISTRATOR . DS . 'tables');
 
 // Require the base controller
-require_once(JPATH_COMPONENT . DS . 'controller.php');
+require_once(JPATH_COMPONENT_SITE . DS . 'controller.php');
 
 // Require specific controller if requested
-if ($controller = JRequest::getWord('controller', 'poll')) 
+if ($controller = JRequest::getWord('controller', 'poll'))
 {
-	$path = JPATH_COMPONENT . DS . 'controllers' . DS . $controller . '.php';
-	if (file_exists($path)) 
+	$path = JPATH_COMPONENT_SITE . DS . 'controllers' . DS . $controller . '.php';
+	if (file_exists($path))
 	{
 		require_once $path;
-	} 
-	else 
+	}
+	else
 	{
 		$controller = '';
 	}
