@@ -1,24 +1,9 @@
 <?php // no direct access
 defined('_JEXEC') or die('Restricted access'); ?>
 
-<div class="aside">
-	<p>
-		<strong><?php echo JText::_( 'Number of Voters' ); ?></strong><br />
-		<?php echo (isset($this->votes[0])) ? $this->votes[0]->voters : '--'; ?>
-	</p>
-	<p>
-		<strong><?php echo JText::_( 'First Vote' ); ?></strong><br />
-		<?php echo ($this->first_vote) ? $this->escape($this->first_vote) : '--'; ?>
-	</p>
-	<p>
-		<strong><?php echo JText::_( 'Last Vote' ); ?></strong><br />
-		<?php echo ($this->last_vote) ? $this->escape($this->last_vote) : '--'; ?>
-	</p>
-	<p class="warning">This whole thing is wildly inaccurate. Rounding errors, ballot stuffers, dynamic IPs, firewalls. If you're using these numbers to do anything important, you're insane.</p>
-</div><!-- / .aside -->
 <div class="subject">
 <?php if ($this->poll->id) { ?>
-	<table class="pollresults" summary="<?php echo JText::_('Results for this pull'); ?>">
+	<table class="pollresults">
 		<thead>
 			<tr>
 				<th colspan="3" class="sectiontableheader">
@@ -27,7 +12,7 @@ defined('_JEXEC') or die('Restricted access'); ?>
 			</tr>
 		</thead>
 		<tbody>
-	<?php foreach ($this->votes as $vote) : ?> 
+	<?php foreach ($this->votes as $vote) : ?>
 			<tr class="sectiontableentry<?php echo $vote->odd; ?>">
 				<td>
 					<div class="graph">
@@ -46,7 +31,21 @@ defined('_JEXEC') or die('Restricted access'); ?>
 	</table>
 <?php } else { ?>
 	<p>
-		<?php echo JText::_('Select a poll from the list.'); ?>
+		<?php echo JText::_('COM_POLL_SELECT_POLL'); ?>
 	</p>
 <?php } ?>
-</div><!-- / .subject -->
\ No newline at end of file
+</div><!-- / .subject -->
+<aside class="aside">
+	<p>
+		<strong><?php echo JText::_('COM_POLL_NUMBER_OF_VOTERS'); ?></strong><br />
+		<?php echo (isset($this->votes[0])) ? $this->votes[0]->voters : '--'; ?>
+	</p>
+	<p>
+		<strong><?php echo JText::_('COM_POLL_FIRST_VOTE'); ?></strong><br />
+		<?php echo ($this->first_vote) ? $this->escape($this->first_vote) : '--'; ?>
+	</p>
+	<p>
+		<strong><?php echo JText::_('COM_POLL_LAST_VOTE'); ?></strong><br />
+		<?php echo ($this->last_vote) ? $this->escape($this->last_vote) : '--'; ?>
+	</p>
+</aside><!-- / .aside -->
\ No newline at end of file
