@@ -402,6 +402,7 @@ class ProjectsControllerMedia extends \Hubzero\Component\SiteController
 		$this->view->file_path 		= $prefix . $path;
 		$this->view->id 			= $obj->id;
 		$this->view->tempid 		= $tempid;
+		$this->view->alias			= $obj->alias;
 		if ($this->getError())
 		{
 			$this->view->setError( $this->getError() );
@@ -445,4 +446,74 @@ class ProjectsControllerMedia extends \Hubzero\Component\SiteController
 
 		return false;
 	}
+
+	/**
+	 * Show images within projects
+	 *
+	 * @return     void
+	 */
+	public function mediaTask()
+	{
+		// Incoming
+		$media   = trim(JRequest::getVar( 'media', 'thumb' ));
+		$alias 	 = trim(JRequest::getVar( 'alias', '' ));
+		$source	 = NULL;
+		$redirect= false;
+
+		if (!$alias)
+		{
+			return false;
+		}
+
+		// Show project thumbnail
+		if ($media == 'thumb')
+		{
+			$source = ProjectsHtml::getThumbSrc( $alias, '', $this->config );
+		}
+		elseif ($media)
+		{
+			$obj = new Project( $this->database );
+			if (!$obj->loadProject($alias))
+			{
+				return false;
+			}
+
+			if ($media == 'master')
+			{
+				// Public picture
+				$source = ProjectsHtml::getProjectImageSrc( $alias, $obj->picture, $this->config );
+			}
+			else
+			{
+				// Other images are non-public; in 'preview' folder
+				// Check authorization
+				/*
+				if (!$this->_authorize($obj->id))
+				{
+					JError::raiseError( 403, JText::_('ALERTNOTAUTH') );
+					return;
+				}
+				*/
+				$path 	= trim($this->config->get('imagepath', '/site/projects'), DS);
+				$source = $path . DS . $alias . DS . 'preview' . DS . $media;
+				$redirect = true;
+			}
+		}
+
+		if (is_file(JPATH_ROOT . DS . $source))
+		{
+			$xserver = new \Hubzero\Content\Server();
+			$xserver->filename($source);
+			$xserver->serve_inline(JPATH_ROOT . DS . $source);
+			exit;
+		}
+		elseif ($redirect)
+		{
+			$this->setRedirect(
+				JRoute::_('index.php?option=' . $this->_option)
+			);
+		}
+
+		return;
+	}
 }
