@@ -241,11 +241,7 @@ class ProjectsGitHelper extends JObject
 	 */
 	public function gitLogAll ($path = '', $subdir = '')
 	{
-		// Do NOT use - results in memory exhaust on large repos
-		// hotfixed on PURR & NCIP in 1.2.2 - snowwitje
-		$collector = array();
-		return $collector;
-
+		return NULL; // disable
 		chdir($this->_prefix . $path);
 		$exec = ' log --diff-filter=AMR --pretty=format:">>>%ci||%an||%ae||%H||%s" --name-only ' . $subdir;
 
@@ -290,6 +286,10 @@ class ProjectsGitHelper extends JObject
 	 */
 	public function gitLog ($path = '', $file = '', $hash = '', $return = 'date')
 	{
+		if (!is_dir($this->_prefix . $path))
+		{
+			return false;
+		}
 		chdir($this->_prefix . $path);
 		$what = '';
 
@@ -297,7 +297,7 @@ class ProjectsGitHelper extends JObject
 		switch ( $return )
 		{
 			case 'combined':
-				$exec = ' log --diff-filter=AMR --pretty=format:"%ci||%an||%ae||%H||%s" --name-only --max-count=1 ';
+				$exec = ' log --diff-filter=AMR --pretty=format:"%ci||%an||%ae||%H||%s" --name-only ';
 				break;
 
 			case 'date':
@@ -381,6 +381,7 @@ class ProjectsGitHelper extends JObject
 
 			$entry = array();
 			$entry['date']  	= $data[0];
+			$entry['num'] 		= count($out);
 			$entry['author'] 	= $data[1];
 			$entry['email'] 	= $data[2];
 			$entry['hash'] 		= $data[3];
@@ -677,7 +678,7 @@ class ProjectsGitHelper extends JObject
 				$entry['hash'] 		= $data[3];
 				$entry['message']	= $data[4];
 			}
-			elseif ($line != '' && !isset($collector[$line]))
+			elseif (isset($entry) && $line != '' && !isset($collector[$line]))
 			{
 				$collector[$line] = $entry;
 			}
