@@ -149,7 +149,7 @@ class PublicationsCuration extends JObject
 	/**
 	 * Get blocks in order
 	 *
-	 * @param   string  $manifest     Pup type manifest to parse
+	 * @param   string  $manifest     Pub type manifest to parse
 	 * @return  boolean
 	 */
 	public function setBlocks($manifest = NULL)
@@ -622,6 +622,42 @@ class PublicationsCuration extends JObject
 		return true;
 	}
 
+	/**
+	 * Skip requirement
+	 *
+	 * @param   integer  $actor			Actor user ID
+	 * @param   integer  $elementId		Element ID
+	 * @return  boolean
+	 */
+	public function skip ($actor = 0, $elementId = 0)
+	{
+		if (!$this->_blocks || !$this->_block || !$this->_pub)
+		{
+			return false;
+		}
+
+		// Incoming
+		$reason  = urldecode(JRequest::getVar('review', ''));
+
+		if (!trim($reason))
+		{
+			$this->setError('Please provide a reason for skipping requirement');
+			return false;
+		}
+
+		// Record update time
+		$data 				= new stdClass;
+		$data->updated 		= JFactory::getDate()->toSql();
+		$data->updated_by 	= $actor;
+		$data->review_status = 3;
+		$data->update		= stripslashes($reason);
+		$this->saveUpdate($data, $elementId, $this->_blockname, $this->_pub, $this->_blockorder);
+
+		$this->set('_message', 'Your request has been saved');
+
+		return true;
+	}
+
 	/**
 	 * Remove dispute
 	 *
@@ -820,47 +856,57 @@ class PublicationsCuration extends JObject
 				continue;
 			}
 			$autoStatus 		= self::getStatus($block->name, $this->_pub, $sequence);
-			$result->blocks->$sequence = new stdClass();
+			$reviewStatus		= self::getReviewStatus($block->name, $this->_pub, $sequence);
+
+			$result->blocks->$sequence 				= new stdClass();
 			$result->blocks->$sequence->name 		= $block->name;
-			$result->blocks->$sequence->status 		= $autoStatus;
-			$result->blocks->$sequence->review 		= ($this->_pub->state == 5 || $this->_pub->state == 7)
-													? self::getReviewStatus($block->name, $this->_pub, $sequence)
-													: NULL;
 			$result->blocks->$sequence->manifest 	= $block;
 			$result->blocks->$sequence->firstElement= self::getFirstElement($block->name, $this->_pub, $sequence);
-			$reviewStatus							= $result->blocks->$sequence->review;
 
 			if ($autoStatus->status > 0)
 			{
 				$result->lastBlock = $sequence;
 			}
 
-			if (!$result->firstBlock)
-			{
-				if (($reviewStatus && $reviewStatus->status == 0
-					&& !$reviewStatus->lastupdate) || $autoStatus->status == 0)
-				{
-					$result->firstBlock = $sequence;
-				}
-				elseif (!$reviewStatus && $autoStatus->status == 0)
-				{
-					$result->firstBlock = $sequence;
-				}
-			}
-
 			$k++;
 
-			if ($autoStatus->status > 0 &&
-				(!$reviewStatus
-				|| ($reviewStatus->status >= 1 || $reviewStatus->lastupdate))
-			)
+			if (($autoStatus->status > 0 && $reviewStatus->status != 0) || $reviewStatus->status == 1 || $reviewStatus->lastupdate)
 			{
 				$i++;
 			}
-		}
 
-		$nextBlock = $result->lastBlock + 1;
-		$result->nextBlock = isset($this->_blocks->$nextBlock) ? $nextBlock : $result->lastBlock;
+			// Look at both auto and review status to determine if complete
+			if ($reviewStatus)
+			{
+				if ($block->elements)
+				{
+					foreach ($block->elements as $elementId => $element)
+					{
+						if ($autoStatus->elements->$elementId->status == 0 && $reviewStatus->elements->$elementId->status == 2)
+						{
+							$i--;
+							$reviewStatus->status = 2;
+						}
+					}
+				}
+			}
+			// Spot a problem
+			if (!$result->firstBlock)
+			{
+				if ($reviewStatus->status == 0 && !$reviewStatus->lastupdate)
+				{
+					$result->firstBlock = $sequence;
+				}
+				elseif ($reviewStatus->status == 2 && !$reviewStatus->lastupdate && $autoStatus->status == 0)
+				{
+					$result->firstBlock = $sequence;
+				}
+			}
+
+			$result->blocks->$sequence->status 		= $autoStatus;
+			$result->blocks->$sequence->review      = $reviewStatus;
+		}
+		$result->firstBlock = $result->firstBlock ? $result->firstBlock : $sequence;
 
 		// Are all sections complete for submission?
 		$result->complete  = $i == $k ? 1 : 0;
@@ -1301,10 +1347,12 @@ class PublicationsCuration extends JObject
 			$failed 	= 0;
 			$incomplete = 0;
 			$pending 	= 0;
+			$skipped	= 0;
 
 			foreach ($manifest->elements as $elementId => $element)
 			{
 				$props = $block . '-' . $sequence . '-' . $elementId;
+
 				if (!isset($status->elements))
 				{
 					$status->elements = new stdClass();
@@ -1314,7 +1362,8 @@ class PublicationsCuration extends JObject
 				// Store element label (for history tracking)
 				$status->elements->$elementId->label = $element->label;
 
-				if ($status->elements->$elementId->status >= 1 || $status->elements->$elementId->lastupdate)
+				if ($status->elements->$elementId->status >= 1
+					|| $status->elements->$elementId->lastupdate)
 				{
 					$success++;
 				}
@@ -1330,13 +1379,19 @@ class PublicationsCuration extends JObject
 				{
 					$pending++;
 				}
-
+				if ($status->elements->$elementId->status == 3)
+				{
+					$skipped++;
+				}
 				$i++;
 			}
 
-			$success 	    	= $success == $i ? 1 : 0;
-			$status->status 	= $failed > 0 ? 0 : $success;
-			$status->lastupdate = $pending > 0 && $failed == 0 ? true : NULL;
+			// Determine block status based on element status
+			$passed 	    	= ($success == $i || $pub->state == 1) ? 1 : 0;
+			$status->status 	= $failed > 0 ? 0 : $passed;
+			$status->status 	= ($incomplete  && !$failed) ? 2 : $status->status; // unreviewed
+			$status->status 	= ($skipped > 0 && ($skipped + $incomplete) == $i) ? 3 : $status->status; // skipped
+			$status->lastupdate = ($pending > 0 || $skipped > 0) && $passed == 1 ? true : NULL;
 		}
 		else
 		{
@@ -1358,7 +1413,7 @@ class PublicationsCuration extends JObject
 	public function getReviewItemStatus( $props = NULL, $items = NULL )
 	{
 		$status = new PublicationsModelStatus();
-		$status->status 		= 2;
+		$status->status 		= 2; // unreviewed
 		$status->updated_by 	= 0;
 
 		if ($props === NULL || $items === NULL)
@@ -1377,6 +1432,10 @@ class PublicationsCuration extends JObject
 		{
 			$status->status = 1;
 		}
+		elseif ($record->review_status == 3)
+		{
+			$status->status = 3;
+		}
 		elseif ($record->review_status == 2)
 		{
 			$status->status  = 0;
@@ -1389,7 +1448,12 @@ class PublicationsCuration extends JObject
 			$status->lastupdate = $record->updated;
 			$status->updated_by = $record->updated_by;
 		}
-		if ($record->update && $record->updated > $record->reviewed)
+		if ($status->status == 3)
+		{
+			$status->lastupdate = $record->updated;
+			$status->updated_by = $record->updated_by;
+		}
+		if ($record->review_status == 3 || ($record->reviewed && $record->update && strtotime($record->updated) > strtotime($record->reviewed)))
 		{
 			$status->message = $record->update;
 		}
@@ -1416,11 +1480,6 @@ class PublicationsCuration extends JObject
 		$status->authornotice 	= NULL;
 		$status->updated_by		= 0;
 
-		if ($pub->state != 7 && $pub->state != 5)
-		{
-			return $status;
-		}
-
 		if ($elId)
 		{
 			$reviewStatus = $pub->_curationModel->_progress->blocks->$step->review->elements->$elId;
@@ -1437,19 +1496,22 @@ class PublicationsCuration extends JObject
 
 		$status->status 		= $reviewStatus->status;
 		$status->curatornotice 	= $reviewStatus->getError();
-		$status->updated		= $pub->reviewed ? $reviewStatus->lastupdate : NULL;
+		$status->updated		= $pub->state != 1 ? $reviewStatus->lastupdate : NULL;
+		$status->authornotice 	= $reviewStatus->message;
 
 		if ($status->updated && isset($reviewStatus->updated_by) && $reviewStatus->updated_by)
 		{
 			$profile = \Hubzero\User\Profile::getInstance($reviewStatus->updated_by);
 			$by 	 = ' ' . JText::_('COM_PUBLICATIONS_CURATION_BY') . ' ' . $profile->get('name');
 
-			$status->updatenotice 	= JText::_('COM_PUBLICATIONS_CURATION_UPDATED') . ' '
-				. JHTML::_('date', $status->updated, 'M d, Y H:i') . $by;
-
-			if ($reviewStatus->message)
+			if ($status->status != 3)
 			{
-				$status->authornotice = $reviewStatus->message;
+				$status->updatenotice 	= JText::_('COM_PUBLICATIONS_CURATION_UPDATED') . ' '
+					. JHTML::_('date', $status->updated, 'M d, Y H:i') . $by;
+			}
+			else
+			{
+				$status->updatenotice 	= JText::_('COM_PUBLICATIONS_CURATION_SKIPPED') . ' ' . $by;
 			}
 		}
 
@@ -1468,12 +1530,13 @@ class PublicationsCuration extends JObject
 	public function drawCurationNotice( $curatorStatus, $props, $viewer = 'author', $elName = '' )
 	{
 		?>
-		<?php if ($viewer == 'curator' && !$curatorStatus->updatenotice) { ?>
+		<?php if ($viewer == 'curator') { ?>
 		<span class="edit-notice">[<a href="#">edit</a>]</span>
 		<?php } ?>
+		<?php if (($viewer == 'author' && (!$curatorStatus->curatornotice && $curatorStatus->status == 3)) ) { return; } ?>
 		<div class="status-notice">
 			<span class="update-notice"><?php if ($viewer == 'curator') { echo  $curatorStatus->updatenotice; }
-			else {
+			elseif ($curatorStatus->status != 3) {
 				if ($curatorStatus->authornotice && $curatorStatus->updated)
 				{
 					?>
@@ -1494,14 +1557,13 @@ class PublicationsCuration extends JObject
 
 			<span class="fail-notice"><?php echo $viewer == 'curator' ? JText::_('COM_PUBLICATIONS_CURATION_NOTICE_TO_AUTHORS') : JText::_('COM_PUBLICATIONS_CURATION_CHANGE_REQUEST'); ?></span>
 			<span class="notice-text"><?php echo $curatorStatus->curatornotice; ?></span>
-			<?php if ($curatorStatus->authornotice && $curatorStatus->updated && $viewer == 'curator') { ?>
+			<?php if ($curatorStatus->authornotice && $viewer == 'curator') { ?>
 			<span class="dispute-notice">
 				<strong><?php echo JText::_('COM_PUBLICATIONS_CURATION_DISPUTE_NOTICE'); ?></strong>
 				<?php echo $curatorStatus->authornotice; ?>
 			</span>
 			<?php } ?>
 		</div>
-
 	<?php }
 
 	/**
@@ -1664,6 +1726,9 @@ class PublicationsCuration extends JObject
 	 */
 	public function saveHistory( $pub, $actor = 0, $oldStatus = 0, $newStatus = 0, $curator = 0 )
 	{
+		// Incoming
+		$comment = JRequest::getVar('comment', '', 'post');
+
 		// Collect details
 		$changelog = $this->getChangeLog($pub, $oldStatus, $newStatus, $curator);
 
@@ -1682,6 +1747,7 @@ class PublicationsCuration extends JObject
 		$obj->curator					= $curator;
 		$obj->newstatus					= $newStatus;
 		$obj->oldstatus					= $oldStatus;
+		$obj->comment					= \Hubzero\Utility\Sanitize::clean(htmlspecialchars($comment));
 
 		if ($obj->store())
 		{
@@ -1707,6 +1773,21 @@ class PublicationsCuration extends JObject
 		return $history;
 	}
 
+	/**
+	 * Get last
+	 *
+	 * @param   integer  $elementId		Element ID
+	 * @param   string   $name			Block name
+	 * @param   object   $pub			Publication object
+	 * @param   integer  $sequence		Block order in curation
+	 * @return boolean
+	 */
+	public function getLastUpdate( $elementId, $name, $pub, $sequence )
+	{
+		$curation = new PublicationCuration($this->_db);
+		return $curation->getRecord($pub->id, $pub->version_id, $name, $sequence, $elementId);
+	}
+
 	/**
 	 * Save update
 	 *
@@ -1967,4 +2048,149 @@ class PublicationsCuration extends JObject
 
 		return true;
 	}
+
+	/**
+	 * Conversion for publications created in a non-curated flow
+	 *
+	 * @param   object $pub
+	 * @return  boolean
+	 */
+	public function convertToCuration( $pub = NULL, $uid = 0 )
+	{
+		$pub = $pub ? $pub : $this->_pub;
+		$oldFlow = false;
+
+		if (!isset($pub->_attachments)
+			|| !isset($pub->_attachments['elements'])
+			|| empty($pub->_attachments['elements']))
+		{
+			// Nothing to convert
+			return false;
+		}
+
+		// Get attachment type model
+		$attModel = new PublicationsModelAttachments($this->_db);
+		$fileAttach = $attModel->loadAttach('file');
+
+		// Get supporting docs element element manifest
+		$sElements = self::getElements(2);
+		$sElement  = $sElements ? $sElements[0] : NULL;
+
+		// Loop through attachments
+		foreach ($pub->_attachments['elements'] as $elementId => $elementAttachments)
+		{
+			if (empty($elementAttachments))
+			{
+				continue;
+			}
+			// Check if any attachments are missing element id
+			foreach ($elementAttachments as $elAttach)
+			{
+				if ($elAttach->element_id == 0)
+				{
+					$oldFlow = true; // will need to make further checks
+
+					// Save elementid
+					$row = new PublicationAttachment( $this->_db );
+					if ($row->load($elAttach->id))
+					{
+						$markId = $elAttach->role != 1 && $sElement ? $sElement->id : $elementId;
+						$row->element_id = $markId;
+						$row->store();
+					}
+				}
+			}
+		}
+
+		if ($oldFlow == false)
+		{
+			// Nothing to convert
+			return false;
+		}
+
+		// Get gallery element manifest
+		$elements = self::getElements(3);
+		$element = $elements ? $elements[0] : NULL;
+
+		// Retrieve screenshots
+		$pScreenshot = new PublicationScreenshot( $this->_db );
+		$shots = $pScreenshot->getScreenshots( $pub->version_id );
+
+		// Transfer gallery files to the right location
+		if ($element && $shots && isset($pub->_helpers))
+		{
+			// Set configs
+			$configs  = $fileAttach->getConfigs(
+				$element->manifest->params,
+				$element->id,
+				$pub,
+				$element->block
+			);
+
+			// Get gallery path
+			$galleryPath 	= $pub->_helpers->pubHelper->buildPath(
+				$pub->id,
+				$pub->version_id,
+				'',
+				'gallery',
+				1
+			);
+
+			if (is_dir($galleryPath))
+			{
+				$objPA = new PublicationAttachment( $this->_db );
+				foreach ($shots as $shot)
+				{
+					if (is_file($galleryPath . DS . $shot->srcfile)
+					&& !$objPA->loadElementAttachment($pub->version_id, array( 'path' => $shot->filename),
+						$element->id, 'file', $element->manifest->params->role))
+					{
+						$objPA = new PublicationAttachment( $this->_db );
+						$objPA->publication_id 			= $pub->id;
+						$objPA->publication_version_id 	= $pub->version_id;
+						$objPA->path 					= $shot->filename;
+						$objPA->type 					= 'file';
+						$objPA->created_by 				= $uid;
+						$objPA->created 				= JFactory::getDate()->toSql();
+						$objPA->role 					= $element->manifest->params->role;
+						$objPA->element_id 				= $element->id;
+						$objPA->ordering 				= $shot->ordering;
+						if (!$objPA->store())
+						{
+							continue;
+						}
+						// Check if names is already used
+						$suffix = $fileAttach->checkForDuplicate(
+							$configs->path . DS . $objPA->path,
+							$objPA,
+							$configs
+						);
+						// Save params if applicable
+						if ($suffix)
+						{
+							$pa = new PublicationAttachment( $this->_db );
+							$pa->saveParam($objPA, 'suffix', $suffix);
+						}
+						// Copy file into the right spot
+						$fileAttach->publishAttachment($objPA, $pub, $configs);
+					}
+				}
+			}
+		}
+
+		// Check if published version has curation manifest saved
+		$row = new PublicationVersion( $this->_db );
+		if ($pub->state == 1 && !$pub->curation)
+		{
+			if ($row->load($pub->version_id))
+			{
+				$row->curation = json_encode($this->_manifest);
+				$row->store();
+			}
+		}
+		// Mark as curated
+		$row->saveParam($row->id, 'curated', 1);
+
+		return true;
+	}
 }
\ No newline at end of file
