@@ -240,7 +240,7 @@ class typeFiles extends JObject
 				$mt = new \Hubzero\Content\Mimetypes();
 				$mimetypes = array();
 
-				foreach ($selections['files'] as $file)
+				foreach($selections['files'] as $file)
 				{
 					$mtype = $mt->getMimeType(urldecode($file));
 					$parts = explode('/', $mtype);
@@ -357,7 +357,12 @@ class typeFiles extends JObject
 		$old  			= $this->__get('old');
 		$secret  		= $this->__get('secret');
 
-		if ((empty($selections) || !isset($selections['files'])) || !in_array(trim($old->path), $selections['files']))
+		if (empty($selections) || !isset($selections['files']))
+		{
+			return false;
+		}
+
+		if (!in_array(trim($old->path), $selections['files']))
 		{
 			$objPA = new PublicationAttachment( $this->_database );
 			$objPA->deleteAttachment($vid, $old->path, $old->type);
@@ -602,7 +607,7 @@ class typeFiles extends JObject
 		}
 
 		$html = '<img src="' . ProjectsHtml::getFileIcon($ext) . '" alt="' . $ext . '" /> ' . ProjectsHtml::shortenFileName($file, 50);
-		if ($canedit && $pid) {
+		if($canedit && $pid) {
 		$html .= '<span class="c-edit"><a href="' . $url . '?vid=' . $vid
 		. '&item=file::'.urlencode($file) . '&move=' . $move . '&action=edititem&role=' . $role . '" class="showinbox">' . ucfirst(JText::_('PLG_PROJECTS_PUBLICATIONS_EDIT')) . '</a></span>';
 		}
