@@ -31,12 +31,6 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die( 'Restricted access' );
 
-if (JPluginHelper::isEnabled('system', 'jquery')) 
-{
-	$doc = JFactory::getDocument();
-	$doc->addScript('/components/com_resources/assets/js/tags.js');
-}
-
 if (!function_exists('stem')) {
 	function stem($str) {
 		return preg_replace('/^(?:a[bdcfglnpst]?|ant[ei]?|be|co[mlnr]?|de|di[as]?|e[nmxf]|extra|hemi|hyper|hypo|over|peri|post|pr[eo]|re|semi|su[bcfgprs]|sy[nm]|trans|ultra|un|under)+/', '', preg_replace('/(?:e[dr]|ing|e?s|or|ator|able|ible|acious|ary|ate|ation|cy|eer|or|escent|fic|fy|iferous|ile?|ism|ist|ity|ive|ise|ize|oid|ose|osis|ous|tude)+$/', '', $str));
@@ -60,7 +54,7 @@ class RecommendedTags
 		$dbh = JFactory::getDBO();
 
 		$dbh->setQuery(
-			'SELECT t.raw_tag, fa.* 
+			'SELECT t.raw_tag, fa.*
 			FROM #__focus_areas fa
 			INNER JOIN #__tags t ON t.id = fa.tag_id'
 		);
@@ -96,8 +90,8 @@ class RecommendedTags
 			}
 		}
 
-		$dbh->setQuery('SELECT lower(raw_tag) AS raw_tag, CASE WHEN to1.id IS NULL THEN 0 ELSE 1 END AS is_endorsed 
-			FROM #__tags t 
+		$dbh->setQuery('SELECT lower(raw_tag) AS raw_tag, CASE WHEN to1.id IS NULL THEN 0 ELSE 1 END AS is_endorsed
+			FROM #__tags t
 			LEFT JOIN #__tags_object to1 ON to1.tbl = \'tags\' AND to1.objectid = t.id AND to1.label = \'label\' AND to1.tagid = (SELECT id FROM #__tags WHERE tag = \'endorsed\')');
 
 		$tags = array();
@@ -107,9 +101,9 @@ class RecommendedTags
 		}
 
 		$dbh->setQuery(
-			'SELECT body FROM #__resource_assoc ra 
+			'SELECT body FROM #__resource_assoc ra
 			LEFT JOIN #__document_resource_rel drr ON drr.resource_id = ra.child_id
-			INNER JOIN #__document_text_data dtd ON dtd.id = drr.document_id 
+			INNER JOIN #__document_text_data dtd ON dtd.id = drr.document_id
 			WHERE ra.parent_id = '.$rid
 		);
 		$words = preg_split('/\W+/', join(' ', $dbh->loadResultArray()));
@@ -164,47 +158,47 @@ class RecommendedTags
 
 	private static function is_stop_word($word, $word_min_len) {
 		static $stop_words = array(
-			"a"=>       true, "able"=>    true, "about"=>     true, "across"=>    true, "after"=>   true, 
-			"akin"=>    true, "all"=>     true, "almost"=>    true, "also"=>      true, "am"=>      true,    
-			"among"=>   true, "an"=>      true, "and"=>       true, "any"=>       true, "are"=>     true,    
-			"as"=>      true, "at"=>      true, "be"=>        true, "because"=>   true, "been"=>    true,   
-			"between"=> true, "but"=>     true, "by"=>        true, "can"=>       true, "cannot"=>  true,  
-			"could"=>   true, "dear"=>    true, "did"=>       true, "do"=>        true, "does"=>    true,    
-			"each"=>    true, "either"=>  true, "else"=>      true, "ever"=>      true, "every"=>   true, 
-			"for"=>     true, "from"=>    true, "get"=>       true, "got"=>       true, "had"=>     true, 
-			"has"=>     true, "have"=>    true, "he"=>        true, "her"=>       true, "hers"=>    true, 
-			"him"=>     true, "his"=>     true, "how"=>       true, "however"=>   true, "i"=>       true, 
-			"if"=>      true, "in"=>      true, "into"=>      true, "is"=>        true, "it"=>      true, 
-			"its"=>     true, "just"=>    true, "least"=>     true, "let"=>       true, "like"=>    true, 
-			"likely"=>  true, "may"=>     true, "me"=>        true, "might"=>     true, "more"=>    true, 
-			"most"=>    true, "must"=>    true, "my"=>        true, "neither"=>   true, "no"=>      true, 
-			"nor"=>     true, "not"=>     true, "of"=>        true, "off"=>       true, "often"=>   true, 
-			"on"=>      true, "once"=>    true, "only"=>      true, "or"=>        true, "other"=>   true, 
-			"our"=>     true, "own"=>     true, "rather"=>    true, "said"=>      true, "say"=>     true, 
-			"says"=>    true, "she"=>     true, "should"=>    true, "since"=>     true, "so"=>      true, 
-			"some"=>    true, "than"=>    true, "that"=>      true, "the"=>       true, "their"=>   true, 
-			"them"=>    true, "then"=>    true, "there"=>     true, "therefore"=> true, "these"=>   true, 
-			"they"=>    true, "this"=>    true, "those"=>     true, "though"=>    true, "through"=> true, 
-			"tis"=>     true, "to"=>      true, "too"=>       true, "twas"=>      true, "twice"=>   true, 
-			"us"=>      true, "wants"=>   true, "was"=>       true, "we"=>        true, "were"=>    true, 
-			"what"=>    true, "when"=>    true, "where"=>     true, "which"=>     true, "while"=>   true, 
-			"who"=>     true, "whoever"=> true, "whom"=>      true, "whomever"=>  true, "why"=>     true, 
-			"well"=>    true, "will"=>    true, "with"=>      true, "would"=>     true, "yet"=>     true, 
-			"you"=>     true, "your"=>    true, "one"=>       true, "two"=>       true, "three"=>   true, 
-			"four"=>    true, "five"=>    true, "six"=>       true, "seven"=>     true, "eight"=>   true, 
+			"a"=>       true, "able"=>    true, "about"=>     true, "across"=>    true, "after"=>   true,
+			"akin"=>    true, "all"=>     true, "almost"=>    true, "also"=>      true, "am"=>      true,
+			"among"=>   true, "an"=>      true, "and"=>       true, "any"=>       true, "are"=>     true,
+			"as"=>      true, "at"=>      true, "be"=>        true, "because"=>   true, "been"=>    true,
+			"between"=> true, "but"=>     true, "by"=>        true, "can"=>       true, "cannot"=>  true,
+			"could"=>   true, "dear"=>    true, "did"=>       true, "do"=>        true, "does"=>    true,
+			"each"=>    true, "either"=>  true, "else"=>      true, "ever"=>      true, "every"=>   true,
+			"for"=>     true, "from"=>    true, "get"=>       true, "got"=>       true, "had"=>     true,
+			"has"=>     true, "have"=>    true, "he"=>        true, "her"=>       true, "hers"=>    true,
+			"him"=>     true, "his"=>     true, "how"=>       true, "however"=>   true, "i"=>       true,
+			"if"=>      true, "in"=>      true, "into"=>      true, "is"=>        true, "it"=>      true,
+			"its"=>     true, "just"=>    true, "least"=>     true, "let"=>       true, "like"=>    true,
+			"likely"=>  true, "may"=>     true, "me"=>        true, "might"=>     true, "more"=>    true,
+			"most"=>    true, "must"=>    true, "my"=>        true, "neither"=>   true, "no"=>      true,
+			"nor"=>     true, "not"=>     true, "of"=>        true, "off"=>       true, "often"=>   true,
+			"on"=>      true, "once"=>    true, "only"=>      true, "or"=>        true, "other"=>   true,
+			"our"=>     true, "own"=>     true, "rather"=>    true, "said"=>      true, "say"=>     true,
+			"says"=>    true, "she"=>     true, "should"=>    true, "since"=>     true, "so"=>      true,
+			"some"=>    true, "than"=>    true, "that"=>      true, "the"=>       true, "their"=>   true,
+			"them"=>    true, "then"=>    true, "there"=>     true, "therefore"=> true, "these"=>   true,
+			"they"=>    true, "this"=>    true, "those"=>     true, "though"=>    true, "through"=> true,
+			"tis"=>     true, "to"=>      true, "too"=>       true, "twas"=>      true, "twice"=>   true,
+			"us"=>      true, "wants"=>   true, "was"=>       true, "we"=>        true, "were"=>    true,
+			"what"=>    true, "when"=>    true, "where"=>     true, "which"=>     true, "while"=>   true,
+			"who"=>     true, "whoever"=> true, "whom"=>      true, "whomever"=>  true, "why"=>     true,
+			"well"=>    true, "will"=>    true, "with"=>      true, "would"=>     true, "yet"=>     true,
+			"you"=>     true, "your"=>    true, "one"=>       true, "two"=>       true, "three"=>   true,
+			"four"=>    true, "five"=>    true, "six"=>       true, "seven"=>     true, "eight"=>   true,
 			"nine"=>    true, "ten"=>     true
 		);
 		return isset($stop_words[$word]) || strlen($word) < $word_min_len;
 	}
 
-	public function get_tags() { 
-		return $this->tags; 
+	public function get_tags() {
+		return $this->tags;
 	}
-	public function get_existing_tags() { 
-		return $this->existing_tags; 
+	public function get_existing_tags() {
+		return $this->existing_tags;
 	}
-	public function get_existing_tags_map() { 
-		return $this->existing_map; 
+	public function get_existing_tags_map() {
+		return $this->existing_map;
 	}
 	public function get_existing_tags_value_list() {
 		static $val_list = array();
@@ -215,59 +209,66 @@ class RecommendedTags
 		}
 		return implode(',', $val_list);
 	}
-	public function get_focus_areas() { 
-		return $this->focus_areas; 
+	public function get_focus_areas() {
+		return $this->focus_areas;
 	}
-	public function get_focus_areas_map() { 
-		return $this->focus_areas_map; 
+	public function get_focus_areas_map() {
+		return $this->focus_areas_map;
 	}
 	public function get_existing_focus_areas_map() {
 		return $this->existing_fa_map;
 	}
-	public function get_focus_area_properties() { 
-		return $this->fa_properties; 
+	public function get_focus_area_properties() {
+		return $this->fa_properties;
 	}
 }
 
+$this->css('create.css')
+     ->js('create.js')
+     ->js('tags.js');
 ?>
-<div id="content-header">
+<header id="content-header">
 	<h2><?php echo $this->title; ?></h2>
-</div><!-- / #content-header -->
 
-<div id="content-header-extra">
-	<p>
-		<a class="icon-add add btn" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&task=draft'); ?>">
-			<?php echo JText::_('New submission'); ?>
-		</a>
-	</p>
-</div><!-- / #content-header -->
+	<div id="content-header-extra">
+		<p>
+			<a class="icon-add add btn" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&task=draft'); ?>">
+				<?php echo JText::_('New submission'); ?>
+			</a>
+		</p>
+	</div><!-- / #content-header -->
+</header><!-- / #content-header -->
+
+<section class="main section">
+	<?php
+		$this->view('steps')
+		     ->set('option', $this->option)
+		     ->set('step', $this->step)
+		     ->set('steps', $this->steps)
+		     ->set('id', $this->id)
+		     ->set('resource', $this->row)
+		     ->set('progress', $this->progress)
+		     ->display();
 
-<div class="main section">
-<?php
-	$view = new JView( array('name'=>'steps','layout'=>'steps') );
-	$view->option = $this->option;
-	$view->step = $this->step;
-	$view->steps = $this->steps;
-	$view->id = $this->id;
-	$view->resource = $this->row;
-	$view->progress = $this->progress;
-	$view->display();
 	$recommended = new RecommendedTags($this->id, $this->existing);
-	
-	function fa_controls($idx, $fas, $fa_props, $existing, $parent = NULL, $depth = 1) {
-		foreach ($fas as $fa) {
+
+	function fa_controls($idx, $fas, $fa_props, $existing, $parent = NULL, $depth = 1)
+	{
+		foreach ($fas as $fa)
+		{
 			$props = $fa_props[$fa['label']];
 			$multiple = !is_null($props['multiple_depth']) && $props['multiple_depth'] <= $depth;
 			echo '<div class="fa'.($depth === 1 ? ' top-level' : '').'">';
 			echo '<input class="option" class="'.($multiple ? 'checkbox' : 'radio').'" type="'.($multiple ? 'checkbox' : 'radio').'" '.(isset($existing[strtolower($fa['raw_tag'])]) ? 'checked="checked" ' : '' ).'id="tagfa-'.$idx.'-'.$fa['tag'].'" name="tagfa-'.$idx.($parent ? '-'.$parent : '').'[]" value="' . $fa['tag'] . '"';
 			echo ' /><label style="display: inline;" for="tagfa-'.$idx.'-'.$fa['tag'].'">'.$fa['raw_tag'].'</label>';
-			if ($fa['children']) {
+			if ($fa['children'])
+			{
 				echo fa_controls($idx, $fa['children'], $fa_props, $existing, $fa['tag'], $depth + 1);
 			}
 			echo '</div>';
 		}
 	}
-?>
+	?>
 <?php if ($this->getError()) { ?>
 	<p class="warning"><?php echo $this->getError(); ?></p>
 <?php } ?>
@@ -284,21 +285,21 @@ class RecommendedTags
 			<input type="hidden" name="id" value="<?php echo $this->id; ?>" />
 
 			<legend><?php echo JText::_('COM_CONTRIBUTE_TAGS_ADD'); ?></legend>
-<?php 
-	if (count($this->fas) > 0): 
-		$fa_existing = $recommended->get_existing_focus_areas_map();
-		$fa_props = $recommended->get_focus_area_properties();
-		$idx = 0;
-		foreach ($this->fas as $label=>$fas):
-?>
-			<fieldset>
-				<legend><?php echo 'Select '.$label.': '.($fa_props[$label]['mandatory_depth'] ? '<span class="required">required</span>' : ''); ?></legend>
-				<?php fa_controls(++$idx, $fas, $fa_props, $fa_existing); ?>
-			</fieldset>
-<?php 
-		endforeach;
-	endif;
- ?>
+			<?php
+				if (count($this->fas) > 0):
+					$fa_existing = $recommended->get_existing_focus_areas_map();
+					$fa_props = $recommended->get_focus_area_properties();
+					$idx = 0;
+					foreach ($this->fas as $label=>$fas):
+					?>
+						<fieldset>
+							<legend><?php echo 'Select '.$label.': '.($fa_props[$label]['mandatory_depth'] ? '<span class="required">required</span>' : ''); ?></legend>
+							<?php fa_controls(++$idx, $fas, $fa_props, $fa_existing); ?>
+						</fieldset>
+					<?php
+					endforeach;
+				endif;
+			?>
 			<label>
 				<?php echo JText::_('COM_CONTRIBUTE_TAGS_ASSIGNED'); ?>:
 				<?php
@@ -318,7 +319,7 @@ class RecommendedTags
 			<p><?php echo JText::_('COM_CONTRIBUTE_TAGS_NEW_EXPLANATION'); ?></p>
 			<?php if (($rec = $recommended->get_tags())): ?>
 			<p>Suggested tags: <span class="js-only">(click to add to your contribution)</span></p>
-			<ul class="suggested tags" style="margin-bottom: 2em;">
+			<ul class="suggested tags">
 				<?php foreach ($rec as $tag): ?>
 				<li><a class="suggested-tag" href=""><?php echo $tag['text']; ?></a></li>
 				<?php endforeach; ?>
@@ -326,9 +327,9 @@ class RecommendedTags
 			<div class="clear"></div>
 			<?php endif; ?>
 		</fieldset><div class="clear"></div>
-		
+
 		<p class="submit">
-			<input type="submit" value="<?php echo JText::_('COM_CONTRIBUTE_NEXT'); ?>" />
+			<input class="btn btn-success" type="submit" value="<?php echo JText::_('COM_CONTRIBUTE_NEXT'); ?>" />
 		</p>
 	</form>
-</div><!-- / .main section -->
+</section><!-- / .main section -->
