@@ -33,7 +33,7 @@ defined('_JEXEC') or die( 'Restricted access' );
 
 /**
  * Short description for 'ContribtoolHtml'
- * 
+ *
  * Long description (if any) ...
  */
 class ContribtoolHtml
@@ -41,84 +41,84 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'error'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      string $msg Parameter description (if any) ...
 	 * @param      string $tag Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public function error( $msg, $tag='p' )
+	public static function error( $msg, $tag='p' )
 	{
 		return '<'.$tag.' class="error">'.$msg.'</'.$tag.'>'."\n";
 	}
 
 	/**
 	 * Short description for 'warning'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      string $msg Parameter description (if any) ...
 	 * @param      string $tag Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public function warning( $msg, $tag='p' )
+	public static function warning( $msg, $tag='p' )
 	{
 		return '<'.$tag.' class="warning">'.$msg.'</'.$tag.'>'."\n";
 	}
 
 	/**
 	 * Short description for 'passed'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      string $msg Parameter description (if any) ...
 	 * @param      string $tag Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public function passed( $msg, $tag='p' )
+	public static function passed( $msg, $tag='p' )
 	{
 		return '<'.$tag.' class="passed">'.$msg.'</'.$tag.'>'."\n";
 	}
 
 	/**
 	 * Short description for 'alert'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      string $msg Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public function alert( $msg )
+	public static function alert( $msg )
 	{
 		return "<script type=\"text/javascript\"> alert('".$msg."'); window.history.go(-1); </script>\n";
 	}
 
 	/**
 	 * Short description for 'hed'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      string $level Parameter description (if any) ...
 	 * @param      string $txt Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public function hed($level, $txt)
+	public static function hed($level, $txt)
 	{
 		return '<h'.$level.'>'.$txt.'</h'.$level.'>';
 	}
 
 	/**
 	 * Short description for 'div'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      string $txt Parameter description (if any) ...
 	 * @param      string $cls Parameter description (if any) ...
 	 * @param      string $id Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public function div($txt, $cls='', $id='')
+	public static function div($txt, $cls='', $id='')
 	{
 		$html  = '<div';
 		$html .= ($cls) ? ' class="'.$cls.'"' : '';
@@ -138,15 +138,15 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'mkt'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      unknown $stime Parameter description (if any) ...
 	 * @return     unknown Return description (if any) ...
 	 */
-	public function mkt($stime)
+	public static function mkt($stime)
 	{
-		if ($stime && preg_match("/([0-9]{4})-([0-9]{2})-([0-9]{2})[ ]([0-9]{2}):([0-9]{2}):([0-9]{2})/", $stime, $regs )) 
+		if ($stime && preg_match("/([0-9]{4})-([0-9]{2})-([0-9]{2})[ ]([0-9]{2}):([0-9]{2}):([0-9]{2})/", $stime, $regs ))
 		{
 			$stime = mktime( $regs[4], $regs[5], $regs[6], $regs[2], $regs[3], $regs[1] );
 		}
@@ -155,13 +155,13 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'timeAgoo'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      number $timestamp Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public function timeAgoo($timestamp)
+	public static function timeAgoo($timestamp)
 	{
 		// Store the current time
 		$current_time = time();
@@ -171,13 +171,13 @@ class ContribtoolHtml
 
 		// Set the periods of time
 		$periods = array(
-			JText::_('COM_TOOLS_SECOND'), 
-			JText::_('COM_TOOLS_MINUTE'), 
-			JText::_('COM_TOOLS_HOUR'), 
-			JText::_('COM_TOOLS_DAY'), 
-			JText::_('COM_TOOLS_WEEK'), 
-			JText::_('COM_TOOLS_MONTH'), 
-			JText::_('COM_TOOLS_YEAR'), 
+			JText::_('COM_TOOLS_SECOND'),
+			JText::_('COM_TOOLS_MINUTE'),
+			JText::_('COM_TOOLS_HOUR'),
+			JText::_('COM_TOOLS_DAY'),
+			JText::_('COM_TOOLS_WEEK'),
+			JText::_('COM_TOOLS_MONTH'),
+			JText::_('COM_TOOLS_YEAR'),
 			JText::_('COM_TOOLS_DECADE')
 		);
 
@@ -199,7 +199,7 @@ class ContribtoolHtml
 		for ($val = sizeof($lengths) - 1; ($val >= 0) && (($number = $difference / $lengths[$val]) <= 1); $val--);
 
 		// Ensure the script has found a match
-		if ($val < 0) 
+		if ($val < 0)
 		{
 			$val = 0;
 		}
@@ -214,13 +214,13 @@ class ContribtoolHtml
 		if ($number != 1)
 		{
 			$periods = array(
-				JText::_('COM_TOOLS_SECONDS'), 
-				JText::_('COM_TOOLS_MINUTES'), 
-				JText::_('COM_TOOLS_HOURS'), 
-				JText::_('COM_TOOLS_DAYS'), 
-				JText::_('COM_TOOLS_WEEKS'), 
-				JText::_('COM_TOOLS_MONTHS'), 
-				JText::_('COM_TOOLS_YEARS'), 
+				JText::_('COM_TOOLS_SECONDS'),
+				JText::_('COM_TOOLS_MINUTES'),
+				JText::_('COM_TOOLS_HOURS'),
+				JText::_('COM_TOOLS_DAYS'),
+				JText::_('COM_TOOLS_WEEKS'),
+				JText::_('COM_TOOLS_MONTHS'),
+				JText::_('COM_TOOLS_YEARS'),
 				JText::_('COM_TOOLS_DECADES')
 			);
 		}
@@ -239,13 +239,13 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'timeAgo'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      unknown $timestamp Parameter description (if any) ...
 	 * @return     unknown Return description (if any) ...
 	 */
-	public function timeAgo($timestamp)
+	public static function timeAgo($timestamp)
 	{
 		$timestamp = ContribtoolHtml::mkt($timestamp);
 		$text = ContribtoolHtml::timeAgoo($timestamp);
@@ -259,9 +259,9 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'formSelect'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      string $name Parameter description (if any) ...
 	 * @param      string $idname Parameter description (if any) ...
 	 * @param      array $array Parameter description (if any) ...
@@ -270,7 +270,7 @@ class ContribtoolHtml
 	 * @param      string $jscall Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public function formSelect($name, $idname, $array, $value, $class='', $jscall='')
+	public static function formSelect($name, $idname, $array, $value, $class='', $jscall='')
 	{
 		$out  = '<select name="'.$name.'" id="'.$idname.'"';
 		$out .= ($class)  ? ' class="'.$class.'"'           : ''."";
@@ -288,9 +288,9 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'primaryButton'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      string $class Parameter description (if any) ...
 	 * @param      string $href Parameter description (if any) ...
 	 * @param      string $msg Parameter description (if any) ...
@@ -299,7 +299,7 @@ class ContribtoolHtml
 	 * @param      string $action Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public function primaryButton($class, $href, $msg, $xtra='', $title='', $action='')
+	public static function primaryButton($class, $href, $msg, $xtra='', $title='', $action='')
 	{
 		//$title = str_replace('"', '&quot;', $title);
 		$html  = '<span id="test-document"><a class="'.$class.'" style="padding:0.1em 1em 0 1em;"  href="'.$href.'" title="'.htmlentities($title).'" '.$action.'>'.$msg.'</a>';
@@ -310,20 +310,20 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'getNumofTools'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      array $status Parameter description (if any) ...
 	 * @param      string $toolnum Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public function getNumofTools($status, $toolnum='')
+	public static function getNumofTools($status, $toolnum='')
 	{
 		// get hub parameters
-		$jconfig =& JFactory::getConfig();
+		$jconfig = JFactory::getConfig();
 		$live_site = rtrim(JURI::base(),'/');
 		$sitename = $jconfig->getValue('config.sitename');
-		
+
 		$toolnum = ($status['state']!=9) ? JText::_('COM_TOOLS_THIS_TOOL').'  ': '';
 		if (!$status['published'] && ContribtoolHtml::toolActive($status['state']) ) {
 			$toolnum .= JText::_('COM_TOOLS_IS_ONE_OF').' '.$status['ntoolsdev'].' '.strtolower(JText::_('COM_TOOLS_TOOLS')). ' '.strtolower(JText::_('COM_TOOLS_UNDER_DEVELOPMENT')).' '.JText::_('COM_TOOLS_ON').' '.$sitename;
@@ -340,15 +340,15 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'toolActive'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      integer $stateNum Parameter description (if any) ...
 	 * @return     boolean Return description (if any) ...
 	 */
-	public function toolActive($stateNum) 
+	public static function toolActive($stateNum)
 	{
-		if ($stateNum == 8 || $stateNum == 9) 
+		if ($stateNum == 8 || $stateNum == 9)
 		{
 			return false;
 		}
@@ -357,15 +357,15 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'toolWIP'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      integer $stateNum Parameter description (if any) ...
 	 * @return     boolean Return description (if any) ...
 	 */
-	public function toolWIP($stateNum) 
+	public static function toolWIP($stateNum)
 	{
-		if ($stateNum == 2 || $stateNum == 9 || $stateNum == 1) 
+		if ($stateNum == 2 || $stateNum == 9 || $stateNum == 1)
 		{
 			return false;
 		}
@@ -374,15 +374,15 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'toolEstablished'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      integer $stateNum Parameter description (if any) ...
 	 * @return     boolean Return description (if any) ...
 	 */
-	public function toolEstablished($stateNum) 
+	public static function toolEstablished($stateNum)
 	{
-		if ($stateNum == 1 || $stateNum == 9) 
+		if ($stateNum == 1 || $stateNum == 9)
 		{
 			return false;
 		}
@@ -391,14 +391,14 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'getStatusClass'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      unknown $statusNum Parameter description (if any) ...
 	 * @param      string &$statusClass Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public function getStatusClass($statusNum, &$statusClass) 
+	public static function getStatusClass($statusNum, &$statusClass)
 	{
 		switch ($statusNum)
 		{
@@ -413,14 +413,14 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'getStatusName'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      unknown $statusNum Parameter description (if any) ...
 	 * @param      unknown &$statusName Parameter description (if any) ...
 	 * @return     integer Return description (if any) ...
 	 */
-	public function getStatusName($statusNum, &$statusName) 
+	public static function getStatusName($statusNum, &$statusName)
 	{
 		switch ($statusNum)
 		{
@@ -440,14 +440,14 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'getStatusNum'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      unknown $statusName Parameter description (if any) ...
 	 * @param      integer $statusNum Parameter description (if any) ...
 	 * @return     integer Return description (if any) ...
 	 */
-	public function getStatusNum($statusName, $statusNum=1)
+	public static function getStatusNum($statusName, $statusNum=1)
 	{
 		switch (strtolower($statusName))
 		{
@@ -466,14 +466,14 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'getPriority'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      unknown $int Parameter description (if any) ...
 	 * @param      string $priority Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public function getPriority($int, $priority='')
+	public static function getPriority($int, $priority='')
 	{
 		switch ($int)
 		{
@@ -489,34 +489,34 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'getDevTeam'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      array $members Parameter description (if any) ...
 	 * @param      integer $obj Parameter description (if any) ...
 	 * @param      string $team Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public function getDevTeam($members, $obj = 1, $team='') 
+	public static function getDevTeam($members, $obj = 1, $team='')
 	{
-		if ($members && count($members) > 0) 
+		if ($members && count($members) > 0)
 		{
-			foreach ($members as $member) 
+			foreach ($members as $member)
 			{
 				$uid = ($obj) ? $member->uidNumber : $member;
-				$juser =& JUser::getInstance($uid);
-				if (is_object($juser)) 
+				$juser = JUser::getInstance($uid);
+				if (is_object($juser))
 				{
 					$login = $juser->get('username');
-				} 
-				else 
+				}
+				else
 				{
 					$login = JText::_('COM_TOOLS_UNKNOWN');
 				}
 				$team .= ($member != end($members)) ? $login . ', ' : $login;
 			}
 		}
-		else 
+		else
 		{
 			$team .= JText::_('COM_TOOLS_N/A');
 		}
@@ -525,19 +525,19 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'getGroups'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      array $groups Parameter description (if any) ...
 	 * @param      integer $obj Parameter description (if any) ...
 	 * @param      string $list Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public function getGroups($groups, $obj = 1, $list='') 
+	public static function getGroups($groups, $obj = 1, $list='')
 	{
-		if ($groups && count($groups) > 0) 
+		if ($groups && count($groups) > 0)
 		{
-			foreach ($groups as $group) 
+			foreach ($groups as $group)
 			{
 				$cn = ($obj) ? $group->cn : $group;
 				$list .= ($group != end($groups)) ? $cn . ', ' : $cn;
@@ -548,29 +548,29 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'getToolAccess'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      unknown $access Parameter description (if any) ...
 	 * @param      array $groups Parameter description (if any) ...
 	 * @param      string $toolaccess Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public function getToolAccess($access, $groups, $toolaccess='')
+	public static function getToolAccess($access, $groups, $toolaccess='')
 	{
 		switch ($access)
 		{
 			case '@GROUP':
-				if (count($groups)>0) 
+				if (count($groups)>0)
 				{
 					$toolaccess = JText::_('COM_TOOLS_RESTRICTED') . ' ' . JText::_('COM_TOOLS_TO') . ' ' . JText::_('COM_TOOLS_GROUP_OR_GROUPS') . ' ';
-					foreach ($groups as $group) 
+					foreach ($groups as $group)
 					{
 						$toolaccess .= ($group != end($groups)) ? $group->cn . ', ' : $group->cn;
 					}
 				}
-				else 
-				{ 
+				else
+				{
 					$toolaccess = JText::_('COM_TOOLS_RESTRICTED') . ' ' . JText::_('COM_TOOLS_TO') . ' ' . JText::_('COM_TOOLS_UNSPECIFIED') . ' ' . JText::_('COM_TOOLS_GROUP_OR_GROUPS');
 				}
 			break;
@@ -586,14 +586,14 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'getCodeAccess'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      unknown $access Parameter description (if any) ...
 	 * @param      string $codeaccess Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public function getCodeAccess($access, $codeaccess = '')
+	public static function getCodeAccess($access, $codeaccess = '')
 	{
 		switch ($access)
 		{
@@ -607,14 +607,14 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'getWikiAccess'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      unknown $access Parameter description (if any) ...
 	 * @param      string $wikiaccess Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public function getWikiAccess($access, $wikiaccess = '')
+	public static function getWikiAccess($access, $wikiaccess = '')
 	{
 		switch ($access)
 		{
@@ -628,13 +628,13 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'writeApproval'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      unknown $active_stage Parameter description (if any) ...
 	 * @return     void
 	 */
-	public function writeApproval($active_stage)
+	public static function writeApproval($active_stage)
 	{
 		//$stages = array(JText::_('COM_TOOLS_CONTRIBTOOL_STEP_CONFIRM_VERSION'),JText::_('COM_TOOLS_CONTRIBTOOL_STEP_CONFIRM_LICENSE'), JText::_('COM_TOOLS_CONTRIBTOOL_STEP_APPEND_NOTES'), JText::_('COM_TOOLS_CONTRIBTOOL_STEP_CONFIRM_APPROVE'));
 		$stages = array(JText::_('COM_TOOLS_CONTRIBTOOL_STEP_CONFIRM_VERSION'),JText::_('COM_TOOLS_CONTRIBTOOL_STEP_CONFIRM_LICENSE'), JText::_('COM_TOOLS_CONTRIBTOOL_STEP_CONFIRM_APPROVE'));
@@ -668,22 +668,22 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'selectAccess'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      array $as Parameter description (if any) ...
 	 * @param      unknown $value Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public function selectAccess($as, $value)
+	public static function selectAccess($as, $value)
 	{
 		$html  = '<select name="access">';
 		for ($i=0, $n=count( $as ); $i < $n; $i++)
 		{
-			if ($as[$i] != 'Registered' && $as[$i] != 'Special') 
+			if ($as[$i] != 'Registered' && $as[$i] != 'Special')
 			{
 				$html .= '<option value="' . $i . '"';
-				if ($value == $i) 
+				if ($value == $i)
 				{
 					$html .= ' selected="selected"';
 				}
@@ -696,21 +696,21 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'selectGroup'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      array $groups Parameter description (if any) ...
 	 * @param      unknown $value Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public function selectGroup($groups, $value)
+	public static function selectGroup($groups, $value)
 	{
 		$html  = '<select name="group_owner">'."\n";
 		$html .= '<option value="">'.JText::_('COM_TOOLS_SELECT_GROUP').'</option>'."\n";
 		foreach ($groups as $group)
 		{
 			$html .= '<option value="'.$group->cn.'"';
-			if ($value == $group->cn) 
+			if ($value == $group->cn)
 			{
 				$html .= ' selected="selected"';
 			}
@@ -722,9 +722,9 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'writeNotesArea'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      array $notes Parameter description (if any) ...
 	 * @param      unknown $option Parameter description (if any) ...
 	 * @param      string $type Parameter description (if any) ...
@@ -732,15 +732,15 @@ class ContribtoolHtml
 	 * @param      integer $addnew Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public function writeNotesArea($notes, $option, $type='', $edititem = 0, $addnew = 1)
+	public static function writeNotesArea($notes, $option, $type='', $edititem = 0, $addnew = 1)
 	{
 
 		$out ='';
 		$i = 0;
-		if (count($notes) > 0 ) 
+		if (count($notes) > 0 )
 		{
 			$out .= '<ul class="features">'."\n";
-			for ($i=0, $n=count( $notes ); $i < $n; $i++) 
+			for ($i=0, $n=count( $notes ); $i < $n; $i++)
 			{
 				$note = $notes[$i];
 				$out .= ' <li>'."\n";
@@ -751,7 +751,7 @@ class ContribtoolHtml
 			$out .= '</ul>'."\n";
 		}
 
-		if ($addnew) 
+		if ($addnew)
 		{
 			$out .= ContribtoolHtml::addNoteArea($i, $option, $type);
 		}
@@ -761,15 +761,15 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'addNoteArea'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      string $i Parameter description (if any) ...
 	 * @param      unknown $option Parameter description (if any) ...
 	 * @param      string $type Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public function addNoteArea($i, $option, $type = 'item')
+	public static function addNoteArea($i, $option, $type = 'item')
 	{
 		$out  = '';
 	 	$out .= '<label>'."\n";
@@ -784,14 +784,14 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'parseTag'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      unknown $text Parameter description (if any) ...
 	 * @param      string $tag Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public function parseTag($text, $tag)
+	public static function parseTag($text, $tag)
 	{
 		preg_match("#<nb:".$tag.">(.*?)</nb:".$tag.">#s", $text, $matches);
 		if (count($matches) > 0) {
@@ -806,13 +806,13 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'txt_unpee'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      unknown $pee Parameter description (if any) ...
 	 * @return     unknown Return description (if any) ...
 	 */
-	public function txt_unpee($pee)
+	public static function txt_unpee($pee)
 	{
 		$pee = str_replace("\t", '', $pee);
 		$pee = str_replace('</p><p>', '', $pee);
@@ -825,13 +825,13 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'niceidformat'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      integer $someid Parameter description (if any) ...
 	 * @return     integer Return description (if any) ...
 	 */
-	public function niceidformat($someid)
+	public static function niceidformat($someid)
 	{
 		while (strlen($someid) < 5)
 		{
@@ -842,14 +842,14 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'getFileAttribs'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      string $path Parameter description (if any) ...
 	 * @param      string $base_path Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public function getFileAttribs( $path, $base_path='' )
+	public static function getFileAttribs( $path, $base_path='' )
 	{
 		// Return nothing if no path provided
 		if (!$path) {
@@ -913,13 +913,13 @@ class ContribtoolHtml
 
 	/**
 	 * Short description for 'formatsize'
-	 * 
+	 *
 	 * Long description (if any) ...
-	 * 
+	 *
 	 * @param      mixed $file_size Parameter description (if any) ...
 	 * @return     mixed Return description (if any) ...
 	 */
-	public function formatsize($file_size)
+	public static function formatsize($file_size)
 	{
 		if ($file_size >= 1073741824) {
 			$file_size = round($file_size / 1073741824 * 100) / 100 . ' <abbr title="gigabytes">Gb</abbr>';
