@@ -31,23 +31,26 @@ $toolaccess = ToolsHelperHtml::getToolAccess($this->status['exec'], $this->statu
 $codeaccess = ToolsHelperHtml::getCodeAccess($this->status['code']);
 // get wiki access text
 $wikiaccess = ToolsHelperHtml::getWikiAccess($this->status['wiki']);
+
+$this->css('pipeline.css')
+     ->js('pipeline.js');
 ?>
-<div id="content-header">
+<header id="content-header">
 	<h2><?php echo $this->escape($this->title); ?></h2>
-</div><!-- / #content-header -->
 
-<div id="content-header-extra">
-	<ul id="useroptions">
-		<li><a class="idon-status status btn" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=status&app=' . $this->status['toolname']); ?>"><?php echo JText::_('COM_TOOLS_TOOL_STATUS'); ?></a></li>
-		<li class="last"><a class="icon-add add btn" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=create'); ?>"><?php echo JText::_('COM_TOOLS_CONTRIBTOOL_NEW_TOOL'); ?></a></li>
-	</ul>
-</div><!-- / #content-header-extra -->
+	<div id="content-header-extra">
+		<ul id="useroptions">
+			<li><a class="idon-status status btn" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=status&app=' . $this->status['toolname']); ?>"><?php echo JText::_('COM_TOOLS_TOOL_STATUS'); ?></a></li>
+			<li class="last"><a class="icon-add add btn" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=create'); ?>"><?php echo JText::_('COM_TOOLS_CONTRIBTOOL_NEW_TOOL'); ?></a></li>
+		</ul>
+	</div><!-- / #content-header-extra -->
+</header><!-- / #content-header -->
 
-<div class="main section">
+<section class="main section">
 	<?php ToolsHelperHtml::writeApproval('Approve'); ?>
 
 	<?php if ($this->getError()) { ?>
-	<p class="error"><?php echo implode('<br />', $this->getErrors()); ?></p>
+		<p class="error"><?php echo implode('<br />', $this->getErrors()); ?></p>
 	<?php } ?>
 
 	<h4><?php echo JText::_('COM_TOOLS_CONTRIBTOOL_FINAL_REVIEW'); ?>:</h4>
@@ -79,7 +82,7 @@ $wikiaccess = ToolsHelperHtml::getWikiAccess($this->status['wiki']);
 				<?php if ($this->status['license']) { ?>
 				<div class="col span-half omega">
 					<h4>
-						<?php echo JText::_('COM_TOOLS_TOOL_LICENSE'); ?> 
+						<?php echo JText::_('COM_TOOLS_TOOL_LICENSE'); ?>
 						<span class="actionlink">
 							[<a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=license&app=' . $this->status['toolname'] . '&action=confirm'); ?>"><?php echo JText::_('COM_TOOLS_EDIT'); ?></a>]
 						</span>
@@ -93,4 +96,4 @@ $wikiaccess = ToolsHelperHtml::getWikiAccess($this->status['wiki']);
 			</div>
 		</fieldset>
 	</form>
-</div>
\ No newline at end of file
+</section>
\ No newline at end of file
