@@ -22,6 +22,7 @@ function UsersBuildRoute(&$query)
 	static $default;
 	static $registration;
 	static $profile;
+	static $link;
 	static $login;
 	static $logout;
 	static $remind;
@@ -55,6 +56,11 @@ function UsersBuildRoute(&$query)
 				$remind = $items[$i]->id;
 			}
 
+			// Check to see if we have found the link menu item.
+			if (empty($link) && !empty($items[$i]->query['view']) && ($items[$i]->query['view'] == 'link')) {
+				$link = $items[$i]->id;
+			}
+
 			// Check to see if we have found the login menu item.
 			if (empty($login) && !empty($items[$i]->query['view']) && ($items[$i]->query['view'] == 'login')) {
 				$login = $items[$i]->id;
@@ -115,6 +121,9 @@ function UsersBuildRoute(&$query)
 			case 'endsinglesignon':
 				break;
 
+			case 'link':
+				break;
+
 			case 'logout':
 				if ($query['Itemid'] = $logout) {
 					unset ($query['view']);
