@@ -117,7 +117,7 @@ class UsersViewLogin extends JViewLegacy
 			{
 				$pparams = new JRegistry($p->params);
 				$display = $pparams->get('display_name', ucfirst($p->name));
-				$authenticators[] = array('name' => $p->name, 'display' => $display);
+				$authenticators[$p->name] = array('name' => $p->name, 'display' => $display);
 				$multiAuth = true;
 			}
 			else if ($p->name == 'hubzero')
