@@ -146,14 +146,15 @@ class Git
 				'modified'  => array(),
 				'deleted'   => array(),
 				'untracked' => array(),
+				'unmerged'  => array(),
 				'merged'    => array()
 			);
 			foreach ($lines as $line)
 			{
 				$line  = trim($line);
-				preg_match('/([A|D|M|?]{1,2})[ ]{1,2}([[:alnum:]_\-\.\/]*)/', $line, $parts);
+				preg_match('/([A|D|M|U|?]{1,2})[ ]{1,2}([[:alnum:]_\-\.\/]*)/', $line, $parts);
 
-				if (strlen($parts[1]) == 2 && $parts[1] != '??')
+				if (strlen($parts[1]) == 2 && $parts[1] != '??' && $parts[1] != 'UU')
 				{
 					$parts[1] = 'merged';
 				}
@@ -169,6 +170,9 @@ class Git
 					case 'M':
 						$response['modified'][] = $parts[2];
 						break;
+					case 'UU':
+						$response['unmerged'][] = $parts[2];
+						break;
 					case '??':
 						$response['untracked'][] = $parts[2];
 						break;
@@ -313,8 +317,6 @@ class Git
 	/**
 	 * Pull the latest updates
 	 *
-	 * You should probably call isEligibleForUpdate beforehand, althought it isn't required.
-	 *
 	 * @param  (bool)   $dryRun     - whether or not to do the run, or just check what's incoming
 	 * @param  (bool)   $allowNonFf - whether or not to allow non fast forward pulls (i.e. merges)
 	 * @param  (string) $source     - where this repository should pull from (this should be a valid git remote/branch)
@@ -536,15 +538,40 @@ class Git
 	}
 
 	/**
-	 * Check to see if the repo is clear and eligible for an update
+	 * Check to see if the repo is clean, at least as far as this mechanism is concerned
 	 *
 	 * @return boolean
 	 **/
-	public function isEligibleForUpdate()
+	public function isClean()
 	{
-		$status = $this->status();
+		$status   = $this->status();
+		$eligible = true;
 
-		return (empty($status)) ? true : false;
+		if (!empty($status) && is_array($status))
+		{
+			foreach ($status as $type => $files)
+			{
+				if ($type != 'untracked' && !empty($files))
+				{
+					$eligible = false;
+					break;
+				}
+			}
+		}
+
+		return $eligible;
+	}
+
+	/**
+	 * Stash local changes
+	 *
+	 * @return boolean
+	 **/
+	public function stash()
+	{
+		$this->call('stash');
+
+		return true;
 	}
 
 	/**
