@@ -40,26 +40,22 @@ class Truncate extends AbstractHelper
 	/**
 	 * Truncate some text
 	 *
-	 * @param  string  $text    Text to truncate
-	 * @param  integer $length  Length to truncate to
-	 * @param  array   $options Options
-	 * @return string
-	 * @throws \InvalidArgumentException If no text is passed or length isn't a positive integer
+	 * @param   string   $text     Text to truncate
+	 * @param   integer  $length   Length to truncate to
+	 * @param   array    $options  Options
+	 * @return  string
+	 * @throws  \InvalidArgumentException If no text is passed or length isn't a positive integer
 	 */
 	public function __invoke($text = null, $length = null, $options = array())
 	{
 		if (null === $text)
 		{
-			throw new \InvalidArgumentException(
-				__CLASS__ .'::' . __METHOD__ . '(); No text passed.'
-			);
+			throw new \InvalidArgumentException(__METHOD__ . '(); No text passed.');
 		}
 
 		if (!$length || !is_numeric($length))
 		{
-			throw new \InvalidArgumentException(
-				__CLASS__ .'::' . __METHOD__ . '(); Length must be an integer'
-			);
+			throw new \InvalidArgumentException(__METHOD__ . '(); Length must be an integer');
 		}
 
 		return String::truncate($text, $length, $options);
