@@ -688,7 +688,7 @@ abstract class JHtmlBehavior
 					onChange:function(hsb, hex, rgb, el, bySetColor) {
 						//$(el).css('border-color','#' + hex);
 						// Fill the text box just if the color was set using the picker, and not the colpickSetColor function.
-						if (!bySetColor) $(el).val(hex);
+						if (!bySetColor) $(el).val('#' + hex);
 					}
 				}).keyup(function(){
 					$(this).colpickSetColor(this.value);
