@@ -55,8 +55,9 @@ class Migration20140305142845Core extends Base
 
 		if (!$need_to_run)
 		{
-			$this->setError('The timezone conversion appears to have already run. You should confirm this and mark this migration as run if necessary (muse migration -fm --file=Migration20140305142845Core.php)', 'fatal');
-			return false;
+			//$this->setError('The timezone conversion appears to have already run. You should confirm this and mark this migration as run if necessary (muse migration -fm --file=Migration20140305142845Core.php)', 'fatal');
+			//return false;
+			return;
 		}
 
 		$updates = array(
@@ -323,4 +324,4 @@ class Migration20140305142845Core extends Base
 		$configuration = preg_replace('/(var \$offset[\s]*=[\s]*[\'"]*)UTC([\'"]*)/', '$1'.$tz.'$2', $configuration);
 		file_put_contents(JPATH_ROOT . DS . 'configuration.php', $configuration);
 	}
-}
\ No newline at end of file
+}
