@@ -30,11 +30,10 @@
 
 namespace Plugins\Content\Akismet\Service;
 
-use Plugins\Content\Akismet\Service\SocketWriteRead;
 use Hubzero\Antispam\Adapter\AbstractAdapter;
 use Exception;
 
-require_once __DIR__ . '/SocketWriteRead.php';
+require_once __DIR__ . DS . 'SocketWriteRead.php';
 
 /**
  * Akismet anti-comment spam service
@@ -302,11 +301,11 @@ class Provider extends AbstractAdapter
 			return false;
 		}
 
-		$response = $this->_sendRequest($this->_getQueryString(), $this->apiKey . '.rest.akismet.com', '/' . $this->akismetVersion . '/comment-check');
+		$response = $this->_sendRequest('blog=' . \JURI::base() . '&' . $this->_getQueryString(), $this->apiKey . '.rest.akismet.com', '/' . $this->akismetVersion . '/comment-check');
 
 		if ($response[1] == 'invalid' && !$this->isKeyValid())
 		{
-			throw new Exception('The Wordpress API key passed to the Akismet adapter is invalid. Please obtain a valid one from http://wordpress.com/api-keys/');
+			throw new Exception('The API key passed to the Akismet adapter is invalid. Please obtain a valid one from http://wordpress.com/api-keys/');
 		}
 
 		return ($response[1] == 'true');
