@@ -39,105 +39,105 @@ class CoursesTableMemberNote extends JTable
 	/**
 	 * ID, primary key for course asset grouping table
 	 * int(11)
-	 * 
+	 *
 	 * @var integer
 	 */
 	var $id = NULL;
 
 	/**
 	 * varchar(255)
-	 * 
+	 *
 	 * @var text
 	 */
 	var $scope = NULL;
 
 	/**
 	 * int(11)
-	 * 
+	 *
 	 * @var integer
 	 */
 	var $scope_id = NULL;
 
 	/**
 	 * datetime(0000-00-00 00:00:00)
-	 * 
+	 *
 	 * @var string
 	 */
 	var $created = NULL;
 
 	/**
 	 * int(11)
-	 * 
+	 *
 	 * @var integer
 	 */
 	var $created_by = NULL;
 
 	/**
 	 * text
-	 * 
+	 *
 	 * @var string
 	 */
 	var $content = NULL;
 
 	/**
 	 * int(11)
-	 * 
+	 *
 	 * @var integer
 	 */
 	var $pos_x = NULL;
 
 	/**
 	 * int(11)
-	 * 
+	 *
 	 * @var integer
 	 */
 	var $pos_y = NULL;
 
 	/**
 	 * int(11)
-	 * 
+	 *
 	 * @var integer
 	 */
 	var $width = NULL;
 
 	/**
 	 * int(11)
-	 * 
+	 *
 	 * @var integer
 	 */
 	var $height = NULL;
 
 	/**
 	 * 00:00:00
-	 * 
+	 *
 	 * @var integer
 	 */
 	var $timestamp = NULL;
 
 	/**
 	 * tinyint(2)
-	 * 
+	 *
 	 * @var integer
 	 */
 	var $state = NULL;
 
 	/**
 	 * int(11)
-	 * 
+	 *
 	 * @var integer
 	 */
 	var $section_id = NULL;
 
 	/**
 	 * tinyint(2)
-	 * 
+	 *
 	 * @var integer
 	 */
 	var $access = NULL;
 
 	/**
 	 * Constructor method for JTable class
-	 * 
+	 *
 	 * @param  database object
 	 * @return void
 	 */
@@ -148,38 +148,33 @@ class CoursesTableMemberNote extends JTable
 
 	/**
 	 * Override the check function to do a little input cleanup
-	 * 
+	 *
 	 * @return return true
 	 */
 	public function check()
 	{
 		$this->scope_id = intval($this->scope_id);
-		if (!$this->scope_id) 
+		if (!$this->scope_id)
 		{
 			$this->setError(JText::_('Missing scope ID'));
 			return false;
 		}
 
 		$this->scope = trim($this->scope);
-		if (!$this->scope) 
+		if (!$this->scope)
 		{
 			$this->setError(JText::_('Missing scope'));
 			return false;
 		}
 
 		$this->section_id = intval($this->section_id);
-		if (!$this->section_id) 
+		if (!$this->section_id)
 		{
 			$this->setError(JText::_('Missing section ID'));
 			return false;
 		}
 
 		$this->content = trim($this->content);
-		/*if (!$this->content) 
-		{
-			$this->setError(JText::_('Missing content'));
-			return false;
-		}*/
 
 		$this->pos_x  = intval($this->pos_x);
 		$this->pos_y  = intval($this->pos_y);
@@ -189,8 +184,8 @@ class CoursesTableMemberNote extends JTable
 
 		if (!$this->id)
 		{
-			$juser =& JFactory::getUser();
-			$this->created = date('Y-m-d H:i:s', time());
+			$juser = JFactory::getUser();
+			$this->created = JFactory::getDate()->toSql();
 			$this->created_by = $juser->get('id');
 			$this->state = 1;
 		}
@@ -200,7 +195,7 @@ class CoursesTableMemberNote extends JTable
 
 	/**
 	 * Build query method
-	 * 
+	 *
 	 * @param  array $filters
 	 * @return $query database query
 	 */
@@ -251,7 +246,7 @@ class CoursesTableMemberNote extends JTable
 			}
 			else
 			{
-				$where[] = "(LOWER(a.content) LIKE '%" . $this->_db->getEscaped(strtolower($filters['search'])) . "%')";
+				$where[] = "(LOWER(a.content) LIKE " . $this->_db->quote('%' . strtolower($filters['search']) . '%') . ")";
 			}
 		}
 
@@ -265,7 +260,7 @@ class CoursesTableMemberNote extends JTable
 
 	/**
 	 * Get a count of records
-	 * 
+	 *
 	 * @param     array $filters
 	 * @return    integer
 	 */
@@ -280,7 +275,7 @@ class CoursesTableMemberNote extends JTable
 
 	/**
 	 * Get an object list of records
-	 * 
+	 *
 	 * @param     array $filters
 	 * @return    array
 	 */
