@@ -40,30 +40,22 @@ class plgEditorWikiwyg extends JPlugin
 {
 	/**
 	 * Flag for if scripts need to be pushed to the document or not
-	 * 
+	 *
 	 * @var boolean
 	 */
 	private $_pushscripts = true;
 
 	/**
 	 * Initiate the editor. Push scripts to document if needed
-	 * 
+	 *
 	 * @return     string
 	 */
 	public function onInit()
 	{
-		if ($this->_pushscripts) 
+		if ($this->_pushscripts)
 		{
-			$app = JFactory::getApplication();
-
-			$script = '';
-			if ($app->isAdmin()) 
-			{
-				$script = $this->_name . '.mootools';
-			}
-
 			\Hubzero\Document\Assets::addPluginStylesheet('editors', $this->_name);
-			\Hubzero\Document\Assets::addPluginScript('editors', $this->_name, $script);
+			\Hubzero\Document\Assets::addPluginScript('editors', $this->_name);
 
 			$this->_pushscripts = false;
 		}
@@ -89,7 +81,7 @@ class plgEditorWikiwyg extends JPlugin
 	 */
 	public function onDisplay($name, $content, $width, $height, $col, $row, $buttons = true, $id = null, $asset = null, $author = null, $params = array())
 	{
-		if (empty($id)) 
+		if (empty($id))
 		{
 			$id = $name;
 		}
@@ -99,11 +91,11 @@ class plgEditorWikiwyg extends JPlugin
 		$row = $row ? (int) $row : 35;
 
 		// Only add "px" to width and height if they are not given as a percentage
-		if (is_numeric($width)) 
+		if (is_numeric($width))
 		{
 			$width .= 'px';
 		}
-		if (is_numeric($height)) 
+		if (is_numeric($height))
 		{
 			$height .= 'px';
 		}
