@@ -40,21 +40,36 @@ $base = 'index.php?option=' . $this->option . '&cn=' . $this->group->get('cn') .
 <div class="post full <?php echo $item->type(); ?>" id="b<?php echo $this->post->get('id'); ?>" data-id="<?php echo $this->post->get('id'); ?>" data-closeup-url="<?php echo JRoute::_($base . '&scope=post/' . $this->post->get('id')); ?>" data-width="600" data-height="350">
 	<div class="content">
 		<div class="creator attribution clearfix">
-			<a href="<?php echo JRoute::_('index.php?option=com_members&id=' . $item->get('created_by')); ?>" title="<?php echo $this->escape(stripslashes($item->creator('name'))); ?>" class="img-link">
-				<img src="<?php echo $item->creator()->getPicture(); ?>" alt="Profile picture of <?php echo $this->escape(stripslashes($item->creator('name'))); ?>" />
-			</a>
-			<p>
-				<a href="<?php echo JRoute::_('index.php?option=com_members&id=' . $item->get('created_by')); ?>">
-					<?php echo $this->escape(stripslashes($item->creator('name'))); ?>
-				</a> created this post
-				<br />
-				<span class="entry-date">
-					<span class="entry-date-at">@</span>
-					<span class="time"><time datetime="<?php echo $item->created(); ?>"><?php echo $item->created('time'); ?></time></span>
-					<span class="entry-date-on">on</span>
-					<span class="date"><time datetime="<?php echo $item->created(); ?>"><?php echo $item->created('date'); ?></time></span>
-				</span>
-			</p>
+			<?php if ($item->get('type') == 'file' || $item->get('type') == 'collection') { ?>
+				<?php
+				$name = $this->escape(stripslashes($item->creator('name')));
+
+				if ($item->creator('public')) { ?>
+					<a href="<?php echo JRoute::_($item->creator()->getLink()); ?>" title="<?php echo $name; ?>" class="img-link">
+						<img src="<?php echo $item->creator()->getPicture(); ?>" alt="<?php echo JText::_('PLG_GROUPS_COLLECTIONS_PROFILE_PICTURE', $name); ?>" />
+					</a>
+				<?php } else { ?>
+					<span class="img-link">
+						<img src="<?php echo $item->creator()->getPicture(); ?>" alt="<?php echo JText::_('PLG_GROUPS_COLLECTIONS_PROFILE_PICTURE', $name); ?>" />
+					</span>
+				<?php } ?>
+				<p>
+					<a href="<?php echo JRoute::_($item->creator()->getLink()); ?>">
+						<?php echo $this->escape(stripslashes($item->creator('name'))); ?>
+					</a> created this post
+					<br />
+					<span class="entry-date">
+						<span class="entry-date-at">@</span>
+						<span class="time"><time datetime="<?php echo $item->created(); ?>"><?php echo $item->created('time'); ?></time></span>
+						<span class="entry-date-on">on</span>
+						<span class="date"><time datetime="<?php echo $item->created(); ?>"><?php echo $item->created('date'); ?></time></span>
+					</span>
+				</p>
+			<?php } else { ?>
+				<p class="typeof <?php echo $item->get('type'); ?>">
+					<?php echo $this->escape($item->type('title')); ?>
+				</p>
+			<?php } ?>
 		</div><!-- / .attribution -->
 		<?php
 		$this->view('default_' . $item->type(), 'post')
@@ -113,11 +128,11 @@ $base = 'index.php?option=' . $this->option . '&cn=' . $this->group->get('cn') .
 		</div><!-- / .meta -->
 <?php //if ($this->post->created_by != $this->post->created_by) { ?>
 		<div class="convo attribution clearfix">
-			<a href="<?php echo JRoute::_('index.php?option=com_members&id=' . $this->post->get('created_by')); ?>" title="<?php echo $this->escape(stripslashes($this->post->creator()->get('name'))); ?>" class="img-link">
-				<img src="<?php echo \Hubzero\User\Profile\Helper::getMemberPhoto($this->post->creator(), 0); ?>" alt="Profile picture of <?php echo $this->escape(stripslashes($this->post->creator()->get('name'))); ?>" />
+			<a href="<?php echo JRoute::_($this->post->creator()->getLink()); ?>" title="<?php echo $this->escape(stripslashes($this->post->creator()->get('name'))); ?>" class="img-link">
+				<img src="<?php echo $this->post->creator()->getPicture(); ?>" alt="Profile picture of <?php echo $this->escape(stripslashes($this->post->creator()->get('name'))); ?>" />
 			</a>
 			<p>
-				<a href="<?php echo JRoute::_('index.php?option=com_members&id=' . $this->post->get('created_by')); ?>">
+				<a href="<?php echo JRoute::_($this->post->creator()->getLink()); ?>">
 					<?php echo $this->escape(stripslashes($this->post->creator()->get('name'))); ?>
 				</a>
 				onto
