@@ -31,7 +31,7 @@ defined('_JEXEC') or die( 'Restricted access' );
 
 JPluginHelper::importPlugin( 'hubzero' );
 $dispatcher = JDispatcher::getInstance();
-$tf = $dispatcher->trigger( 'onGetMultiEntry', array(array('tags', 'tags', 'actags','',$this->entry->tags('string'))) );
+$tf = $dispatcher->trigger('onGetMultiEntry', array(array('tags', 'tags', 'actags','',$this->entry->tags('string'))));
 
 if ($this->entry->get('publish_down') && $this->entry->get('publish_down') == '0000-00-00 00:00:00')
 {
@@ -46,7 +46,7 @@ $this->css('jquery.datepicker.css', 'system')
 ?>
 <ul id="page_options">
 	<li>
-		<a class="icon-archive archive btn" href="<?php echo JRoute::_('index.php?option=com_members&id=' . $this->member->get('uidNumber') . '&active=blog'); ?>">
+		<a class="icon-archive archive btn" href="<?php echo JRoute::_($this->member->getLink() . '&active=blog'); ?>">
 			<?php echo JText::_('PLG_MEMBERS_BLOG_ARCHIVE'); ?>
 		</a>
 	</li>
@@ -56,7 +56,7 @@ $this->css('jquery.datepicker.css', 'system')
 	<p class="error"><?php echo $this->getError(); ?></p>
 <?php } ?>
 
-	<form action="<?php echo JRoute::_('index.php?option=' . $this->option . '&id=' . $this->member->get('uidNumber') . '&active=blog&task=save'); ?>" method="post" id="hubForm" class="full">
+	<form action="<?php echo JRoute::_($this->member->getLink() . '&active=blog&task=save'); ?>" method="post" id="hubForm" class="full">
 		<fieldset>
 			<legend><?php echo JText::_('PLG_MEMBERS_BLOG_EDIT_DETAILS'); ?></legend>
 
@@ -118,14 +118,14 @@ $this->css('jquery.datepicker.css', 'system')
 				<div class="col span6">
 					<label for="field-publish_up">
 						<?php echo JText::_('PLG_MEMBERS_BLOG_PUBLISH_UP'); ?>
-						<input type="text" name="entry[publish_up]" id="field-publish_up" size="35" value="<?php echo ($this->entry->get('publish_up') ? $this->escape(JHTML::_('date', $this->entry->get('publish_up'), 'Y-m-d H:i:s')) : ''); ?>" />
+						<input type="text" name="entry[publish_up]" id="field-publish_up" data-timezone="<?php echo (timezone_offset_get(new DateTimeZone(JFactory::getConfig()->get('offset')), JDate::getInstance('now')) / 60); ?>" value="<?php echo ($this->entry->get('publish_up') ? $this->escape(JHTML::_('date', $this->entry->get('publish_up'), 'Y-m-d H:i:s')) : ''); ?>" />
 						<span class="hint"><?php echo JText::_('PLG_MEMBERS_BLOG_FIELD_PUBLISH_HINT'); ?></span>
 					</label>
 				</div>
 				<div class="col span6 omega">
 					<label for="field-publish_down">
 						<?php echo JText::_('PLG_MEMBERS_BLOG_PUBLISH_DOWN'); ?>
-						<input type="text" name="entry[publish_down]" id="field-publish_down" size="35" value="<?php echo ($this->entry->get('publish_down') ?$this->escape(JHTML::_('date', $this->entry->get('publish_down'), 'Y-m-d H:i:s')) : ''); ?>" />
+						<input type="text" name="entry[publish_down]" id="field-publish_down" data-timezone="<?php echo (timezone_offset_get(new DateTimeZone(JFactory::getConfig()->get('offset')), JDate::getInstance('now')) / 60); ?>" value="<?php echo ($this->entry->get('publish_down') ? $this->escape(JHTML::_('date', $this->entry->get('publish_down'), 'Y-m-d H:i:s')) : ''); ?>" />
 						<span class="hint"><?php echo JText::_('PLG_MEMBERS_BLOG_FIELD_PUBLISH_HINT'); ?></span>
 					</label>
 				</div>
@@ -139,6 +139,8 @@ $this->css('jquery.datepicker.css', 'system')
 		<input type="hidden" name="entry[created]" value="<?php echo $this->escape($this->entry->get('created')); ?>" />
 		<input type="hidden" name="entry[created_by]" value="<?php echo $this->escape($this->entry->get('created_by')); ?>" />
 		<input type="hidden" name="entry[scope]" value="member" />
+		<input type="hidden" name="entry[scope_id]" value="<?php echo $this->entry->get('scope_id'); ?>" />
+		<input type="hidden" name="entry[access]" value="0" />
 		<input type="hidden" name="option" value="<?php echo $this->option; ?>" />
 		<input type="hidden" name="active" value="blog" />
 		<input type="hidden" name="task" value="view" />
