@@ -92,8 +92,8 @@ class plgMembersCollections extends \Hubzero\Plugin\Plugin
 
 		$this->_authorize('collection');
 
-		include_once(JPATH_ROOT . DS . 'components' . DS . 'com_collections' . DS . 'models' . DS . 'collections.php');
-		$this->model = new CollectionsModel('member', $this->member->get('uidNumber'));
+		include_once(JPATH_ROOT . DS . 'components' . DS . 'com_collections' . DS . 'models' . DS . 'archive.php');
+		$this->model = new CollectionsModelArchive('member', $this->member->get('uidNumber'));
 
 		//are we returning html
 		if ($returnhtml)
@@ -665,7 +665,7 @@ class plgMembersCollections extends \Hubzero\Plugin\Plugin
 		if (JRequest::getInt('no_html', 0))
 		{
 			$response = new stdClass;
-			$response->href = JRoute::_('index.php?option=com_members&id=' . $this->member->get('uidNumber') . '&active=collections' . $sfx);
+			$response->href = JRoute::_($this->member->getLink() . '&active=collections' . $sfx);
 			$response->success = true;
 			if ($this->getError())
 			{
@@ -732,7 +732,7 @@ class plgMembersCollections extends \Hubzero\Plugin\Plugin
 		if (JRequest::getInt('no_html', 0))
 		{
 			$response = new stdClass;
-			$response->href = JRoute::_('index.php?option=com_members&id=' . $this->member->get('uidNumber') . '&active=collections' . $sfx);
+			$response->href = JRoute::_($this->member->getLink() . '&active=collections' . $sfx);
 			$response->success = true;
 			if ($this->getError())
 			{
@@ -1001,7 +1001,7 @@ class plgMembersCollections extends \Hubzero\Plugin\Plugin
 		{
 			$app = JFactory::getApplication();
 			$app->enqueueMessage(JText::_('You are not authorized to perform this action.'), 'error');
-			$app->redirect(JRoute::_('index.php?option=' . $this->option . '&id=' . $this->member->get('uidNumber') . '&active=' . $this->_name));
+			$app->redirect(JRoute::_($this->member->getLink() . '&active=' . $this->_name));
 			return;
 		}
 
@@ -1067,6 +1067,14 @@ class plgMembersCollections extends \Hubzero\Plugin\Plugin
 			}
 		}
 
+		if ($this->getError())
+		{
+			foreach ($this->getErrors() as $error)
+			{
+				$view->setError($error);
+			}
+		}
+
 		if ($no_html)
 		{
 			$view->display();
@@ -1101,11 +1109,9 @@ class plgMembersCollections extends \Hubzero\Plugin\Plugin
 
 		// Incoming
 		$fields = JRequest::getVar('fields', array(), 'post', 'none', 2);
-		$files  = JRequest::getVar('fls', '', 'files', 'array');
-		/*$descriptions = JRequest::getVar('description', array(), 'post');*/
 
 		// Get model
-		$row = new CollectionsModelItem(0);
+		$row = new CollectionsModelItem($fields['id']);
 
 		// Bind content
 		if (!$row->bind($fields))
@@ -1115,14 +1121,17 @@ class plgMembersCollections extends \Hubzero\Plugin\Plugin
 		}
 
 		// Add some data
-		if ($files)
+		if ($files  = JRequest::getVar('fls', '', 'files', 'array'))
 		{
 			$row->set('_files', $files);
 		}
-		$row->set('_assets', JRequest::getVar('assets', array(), 'post'));
+		$row->set('_assets', JRequest::getVar('assets', null, 'post'));
 		$row->set('_tags', trim(JRequest::getVar('tags', '')));
 		$row->set('state', 1);
-		$row->set('access', 0);
+		if (!$row->exists())
+		{
+			$row->set('access', 0);
+		}
 
 		// Store new content
 		if (!$row->store())
@@ -1170,7 +1179,7 @@ class plgMembersCollections extends \Hubzero\Plugin\Plugin
 		}
 
 		$app = JFactory::getApplication();
-		$app->redirect(JRoute::_('index.php?option=' . $this->option . '&id=' . $this->member->get('uidNumber') . '&active=' . $this->_name . '&task=' . $this->model->collection($p['collection_id'])->get('alias')));
+		$app->redirect(JRoute::_($this->member->getLink() . '&active=' . $this->_name . '&task=' . $this->model->collection($p['collection_id'])->get('alias')));
 	}
 
 	/**
@@ -1327,7 +1336,7 @@ class plgMembersCollections extends \Hubzero\Plugin\Plugin
 			$type = 'error';
 		}
 
-		$route = JRoute::_('index.php?option=' . $this->option . '&id=' . $this->member->get('uidNumber') . '&active=' . $this->_name . '&task=' . $collection->get('alias'));
+		$route = JRoute::_($this->member->getLink() . '&active=' . $this->_name . '&task=' . $collection->get('alias'));
 
 		if (($no_html = JRequest::getInt('no_html', 0)))
 		{
@@ -1367,7 +1376,7 @@ class plgMembersCollections extends \Hubzero\Plugin\Plugin
 			$this->setError($post->getError());
 		}
 
-		$route = JRoute::_('index.php?option=' . $this->option . '&id=' . $this->member->get('uidNumber') . '&active=' . $this->_name);
+		$route = JRoute::_($this->member->getLink() . '&active=' . $this->_name);
 
 		if (($no_html = JRequest::getInt('no_html', 0)))
 		{
@@ -1467,7 +1476,7 @@ class plgMembersCollections extends \Hubzero\Plugin\Plugin
 		}
 
 		// Redirect to collection
-		$route = JRoute::_('index.php?option=' . $this->option . '&id=' . $this->member->get('uidNumber') . '&active=' . $this->_name . '&task=' . $collection->get('alias'));
+		$route = JRoute::_($this->member->getLink() . '&active=' . $this->_name . '&task=' . $collection->get('alias'));
 
 		if ($no_html)
 		{
@@ -1587,7 +1596,7 @@ class plgMembersCollections extends \Hubzero\Plugin\Plugin
 
 		// Display the main listing
 		$app = JFactory::getApplication();
-		$app->redirect(JRoute::_('index.php?option=' . $this->option . '&id=' . $this->member->get('uidNumber') . '&active=' . $this->_name . '&task=' . $collection->get('alias')));
+		$app->redirect(JRoute::_($this->member->getLink() . '&active=' . $this->_name . '&task=' . $collection->get('alias')));
 	}
 
 	/**
@@ -1609,7 +1618,7 @@ class plgMembersCollections extends \Hubzero\Plugin\Plugin
 	{
 		$app = JFactory::getApplication();
 
-		$collection = JRoute::_('index.php?option=' . $this->option . '&id=' . $this->member->get('uidNumber') . '&active=' . $this->_name);
+		$collection = JRoute::_($this->member->getLink() . '&active=' . $this->_name);
 
 		// Login check
 		if ($this->juser->get('guest'))
@@ -1712,7 +1721,7 @@ class plgMembersCollections extends \Hubzero\Plugin\Plugin
 
 		// Redirect to collection
 		$app = JFactory::getApplication();
-		$app->redirect(JRoute::_('index.php?option=' . $this->option . '&id=' . $this->member->get('uidNumber') . '&active=' . $this->_name . '&task=all')); // . $row->get('alias')
+		$app->redirect(JRoute::_($this->member->getLink() . '&active=' . $this->_name . '&task=all')); // . $row->get('alias')
 	}
 
 	/**
@@ -1794,7 +1803,7 @@ class plgMembersCollections extends \Hubzero\Plugin\Plugin
 		}
 
 		// Redirect to main view
-		$route = JRoute::_('index.php?option=' . $this->option . '&id=' . $this->member->get('uidNumber') . '&active=' . $this->_name . '&task=all');
+		$route = JRoute::_($this->member->getLink() . '&active=' . $this->_name . '&task=all');
 
 		if ($no_html)
 		{
