@@ -31,7 +31,7 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-$base = 'index.php?option=' . $this->option . '&id=' . $this->member->get('uidNumber') . '&active=' . $this->name;
+$base = $this->member->getLink() . '&active=' . $this->name;
 
 $this->css()
      ->js('jquery.masonry', 'com_collections')
@@ -170,13 +170,25 @@ $this->css()
 				</div><!-- / .meta -->
 				<?php if ($row->get('object_type') == 'member' && $row->get('object_id') != $this->juser->get('id')) { ?>
 				<div class="convo attribution clearfix">
-					<a href="<?php echo JRoute::_('index.php?option=com_members&id=' . $row->get('created_by')); ?>" title="<?php echo $this->escape(stripslashes($row->creator()->get('name'))); ?>" class="img-link">
-						<img src="<?php echo \Hubzero\User\Profile\Helper::getMemberPhoto($row->creator(), 0); ?>" alt="<?php echo JText::sprintf('PLG_MEMBERS_COLLECTIONS_PROFILE_PICTURE', $this->escape(stripslashes($row->creator()->get('name')))); ?>" />
-					</a>
-					<p>
-						<a href="<?php echo JRoute::_('index.php?option=com_members&id=' . $row->get('created_by')); ?>">
-							<?php echo $this->escape(stripslashes($row->creator()->get('name'))); ?>
+					<?php
+					$name = $this->escape(stripslashes($row->creator('name')));
+					if ($row->creator('public')) { ?>
+						<a href="<?php echo JRoute::_($row->creator()->getLink()); ?>" title="<?php echo $name; ?>" class="img-link">
+							<img src="<?php echo $row->creator()->getPicture(); ?>" alt="<?php echo JText::sprintf('PLG_MEMBERS_COLLECTIONS_PROFILE_PICTURE', $name); ?>" />
 						</a>
+					<?php } else { ?>
+						<span class="img-link">
+							<img src="<?php echo $row->creator()->getPicture(); ?>" alt="<?php echo JText::sprintf('PLG_MEMBERS_COLLECTIONS_PROFILE_PICTURE', $name); ?>" />
+						</span>
+					<?php } ?>
+					<p>
+						<?php if ($row->creator('public')) { ?>
+							<a href="<?php echo JRoute::_($row->creator()->getLink()); ?>">
+								<?php echo $name; ?>
+							</a>
+						<?php } else { ?>
+							<?php echo $name; ?>
+						<?php } ?>
 						<br />
 						<span class="entry-date">
 							<span class="entry-date-at"><?php echo JText::_('PLG_MEMBERS_COLLECTIONS_AT'); ?></span>
