@@ -54,7 +54,7 @@ if ($type && !in_array($type, array('file', 'image', 'text', 'link')))
 	$type = 'link';
 }
 
-$base = 'index.php?option=' . $this->option . '&id=' . $this->member->get('uidNumber') . '&active=' . $this->name;
+$base = $this->member->getLink() . '&active=' . $this->name;
 
 $dir = $item->get('id');
 if (!$dir)
@@ -73,7 +73,7 @@ $this->css()
 <?php } ?>
 <form action="<?php echo JRoute::_($base . '&task=post/save' . ($this->no_html ? '&no_html=' . $this->no_html : '')); ?>" method="post" id="hubForm" class="full" enctype="multipart/form-data">
 	<fieldset>
-		<legend><?php echo $item->get('id') ? JText::_('Edit post') : JText::_('New post'); ?></legend>
+		<legend><?php echo $item->get('id') ? ($this->entry->get('original') ? JText::_('Edit post') : JText::_('Edit repost')) : JText::_('New post'); ?></legend>
 
 		<?php if ($this->entry->get('original')) { ?>
 			<div class="field-wrap">
@@ -149,23 +149,29 @@ $this->css()
 					</div><!-- / .field-wrap -->
 
 					<label for="field-title">
-						<?php echo JText::_('Title'); ?> <!-- <span class="optional">optional</span> -->
-						<input type="text" name="fields[title]" id="field-title" size="35" value="<?php echo $this->escape(stripslashes($item->get('title'))); ?>" />
+						<?php echo JText::_('Title'); ?>
+						<input type="text" name="fields[title]" id="field-title" value="<?php echo $this->escape(stripslashes($item->get('title'))); ?>" />
+					</label>
+					<input type="hidden" name="fields[type]" value="file" />
+				<?php } else { ?>
+					<label for="field-title">
+						<?php echo JText::_('Title'); ?>
+						<input type="text" name="fieldstitle" id="field-title" class="disabled" disabled="disabled" value="<?php echo $this->escape(stripslashes($item->get('title'))); ?>" />
 					</label>
 				<?php } ?>
 
 				<label for="field_description">
-					<?php echo JText::_('Description'); ?> <!-- <span class="optional">optional</span> -->
-				<?php if ($this->entry->get('original')) { ?>
-					<?php echo \JFactory::getEditor()->display('fields[description]', $this->escape(stripslashes($item->description('raw'))), '', '', 35, 5, false, 'field_description', null, null, array('class' => 'minimal no-footer')); ?>
-				<?php } else { ?>
-					<?php echo \JFactory::getEditor()->display('post[description]', $this->escape(stripslashes($this->entry->description('raw'))), '', '', 35, 5, false, 'field_description', null, null, array('class' => 'minimal no-footer')); ?>
-				<?php } ?>
+					<?php echo JText::_('Description'); ?>
+					<?php if ($this->entry->get('original')) { ?>
+						<?php echo \JFactory::getEditor()->display('fields[description]', $this->escape(stripslashes($item->description('raw'))), '', '', 35, 5, false, 'field_description', null, null, array('class' => 'minimal no-footer')); ?>
+					<?php } else { ?>
+						<?php echo \JFactory::getEditor()->display('post[description]', $this->escape(stripslashes($this->entry->description('raw'))), '', '', 35, 5, false, 'field_description', null, null, array('class' => 'minimal no-footer')); ?>
+					<?php } ?>
 				</label>
-			<?php if ($this->task == 'save' && !$item->get('description')) { ?>
-				<p class="error"><?php echo JText::_('PLG_MEMBERS_' . strtoupper($this->name) . '_ERROR_PROVIDE_CONTENT'); ?></p>
-			<?php } ?>
-				<input type="hidden" name="fields[type]" value="file" />
+				<?php if ($this->task == 'save' && !$item->get('description')) { ?>
+					<p class="error"><?php echo JText::_('PLG_MEMBERS_' . strtoupper($this->name) . '_ERROR_PROVIDE_CONTENT'); ?></p>
+				<?php } ?>
+
 			</div><!-- / #post-file -->
 		</div><!-- / #post-type-form -->
 
@@ -201,12 +207,14 @@ $this->css()
 					if (count($tf) > 0) {
 						echo $tf[0];
 					} else { ?>
-						<input type="text" name="tags" value="<?php echo $item->tags('string'); ?>" />
+						<input type="text" name="tags" value="<?php echo $this->escape($item->tags('string')); ?>" />
 					<?php } ?>
 					<span class="hint"><?php echo JText::_('PLG_MEMBERS_' . strtoupper($this->name) . '_FIELD_TAGS_HINT'); ?></span>
 				</label>
 			</div>
 		</div>
+	<?php } else { ?>
+		<input type="hidden" name="tags" value="<?php echo $this->escape($item->tags('string')); ?>" />
 	<?php } ?>
 	</fieldset>
 
@@ -214,7 +222,7 @@ $this->css()
 	<input type="hidden" name="fields[created]" value="<?php echo $item->get('created'); ?>" />
 	<input type="hidden" name="fields[created_by]" value="<?php echo $item->get('created_by'); ?>" />
 	<input type="hidden" name="fields[dir]" id="field-dir" value="<?php echo $dir; ?>" />
-	<input type="hidden" name="fields[access]" id="field-dir" value="<?php echo $item->get('access', 0); ?>" />
+	<input type="hidden" name="fields[access]" id="field-access" value="<?php echo $item->get('access', 0); ?>" />
 
 	<input type="hidden" name="post[id]" value="<?php echo $this->entry->get('id'); ?>" />
 	<input type="hidden" name="post[item_id]" id="post-item_id" value="<?php echo $this->entry->get('item_id'); ?>" />
